Type: Package
Package: StatisticTeach1
Title: Interactive Tool for Statistics and Probability
Version: 0.1.2
Depends: R (>= 4.1.0)
Authors@R: c(
    person("Javier", "De La Hoz Maestre",
           email = "jdelahoz@unimagdalena.edu.co",
           role = c("cre", "aut"),
           comment = c(ORCID = "0000-0001-7779-0803")),
    person("Humberto", "Llinas Solano",
           email = "hllinas@uninorte.edu.co",
           role = "aut",
           comment = c(ORCID = "0000-0002-5530-6416"),
           ),
    person("Alexander", "Rangel Vizcaino",
           email = "Alexanderrangel@uninorte.edu.co",
           role = "aut")
  )
Description: A Shiny application designed to support the learning of basic
    concepts in statistics and probability. The tool provides an interactive
    interface that allows students to explore and visualize different
    statistical concepts intuitively, including descriptive statistics for
    continuous and qualitative variables, and probability distributions.
License: GPL-3
Imports: descriptr, DescTools, dplyr, ggplot2, magrittr, mixdist,
        RColorBrewer, readxl, rlang, shiny, shinyBS, shinydashboard,
        shinyjs, shinyWidgets, tibble, tidyr, colourpicker, DT, stats
Suggests: testthat (>= 3.0.0)
Encoding: UTF-8
Config/testthat/edition: 3
Config/roxygen2/version: 8.0.0
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-06-08 20:37:28 UTC; Javier_de_la_Hoz
Author: Javier De La Hoz Maestre [cre, aut] (ORCID:
    <https://orcid.org/0000-0001-7779-0803>),
  Humberto Llinas Solano [aut] (ORCID:
    <https://orcid.org/0000-0002-5530-6416>),
  Alexander Rangel Vizcaino [aut]
Maintainer: Javier De La Hoz Maestre <jdelahoz@unimagdalena.edu.co>
Repository: CRAN
Date/Publication: 2026-06-08 21:00:02 UTC
Built: R 4.6.0; ; 2026-06-08 23:19:23 UTC; unix

# Generated by roxygen2: do not edit by hand

export(ST_freq_factor)
export(ST_freq_numeric)
export(runStatisticTeach1)
import(DescTools)
import(RColorBrewer)
import(descriptr)
import(dplyr)
import(ggplot2)
import(mixdist)
import(shiny)
import(shinydashboard)
import(tibble)
import(tidyr)
importFrom(DT,datatable)
importFrom(DT,formatRound)
importFrom(DT,formatStyle)
importFrom(DT,renderDT)
importFrom(DT,styleEqual)
importFrom(colourpicker,colourInput)
importFrom(colourpicker,colourWidget)
importFrom(dplyr,pull)
importFrom(dplyr,select)
importFrom(magrittr,"%<>%")
importFrom(readxl,excel_sheets)
importFrom(readxl,read_excel)
importFrom(rlang,enquo)
importFrom(rlang,sym)
importFrom(rlang,syms)
importFrom(shinyBS,bsModal)
importFrom(shinyWidgets,actionBttn)
importFrom(shinyWidgets,animateOptions)
importFrom(shinyWidgets,dropdown)
importFrom(shinyWidgets,pickerInput)
importFrom(shinyWidgets,prettyCheckbox)
importFrom(shinyWidgets,switchInput)
importFrom(shinyjs,disable)
importFrom(shinyjs,enable)
importFrom(shinyjs,useShinyjs)
importFrom(stats,na.omit)

# StatisticTeach1

**StatisticTeach1** is an R package that provides an interactive Shiny application for teaching and learning basic concepts in statistics and probability.

## Features

- Descriptive statistics for continuous variables (univariate and bivariate)
- Descriptive statistics for qualitative variables
- Multivariate analysis
- Discrete and continuous probability distributions
- Load and analyse your own data (CSV or Excel)

## Installation

```r
# Install from CRAN
install.packages("StatisticTeach1")

# Or install the development version from GitHub
# install.packages("remotes")
remotes::install_github("JavierDeLaHoz/StatisticTeach1")
```

## Usage

```r
library(StatisticTeach1)

# Launch the interactive app
runStatisticTeach1()

# Standalone frequency table functions
ST_freq_factor(iris, Species)
ST_freq_numeric(mtcars, mpg, bins = 5)
```

## License

GPL-3

tabular_summary <- tabPanel("Tabular summary",
                     div(style="display: inline-block;vertical-align:top;
                        width: 150px;",shinyWidgets::pickerInput(
                          inputId = "Selectrule",
                          label = "Select rule :",
                          choices = c("",
                                      "Sturges",
                                      "Sqrt",
                                      "Scott",
                                      "Freedman–Diaconis",
                                      "Number of bin"),
                          options = list(
                            style = "btn-primary")),

                     ),
                     conditionalPanel(
                       condition = "input.Selectrule == 'Number of bin'",
                       sliderInput("intervalnum",
                                   "",
                                   min = 4,
                                   max = 50,
                                   value = 5,
                                   step = 1)
                     ),
                     br(),
                     actionButton(
                       inputId = "getTable",
                       label="Get table"), br(),br(),

                     DT::DTOutput("tablefreq")
                     )

graphic_summaries <- tabPanel("Graphic summary",
                    div(style="display: inline-block;vertical-align:top;
                        width: 150px;",shinyWidgets::pickerInput(
                          inputId = "SelecQu",
                          label = "Select:",
                          choices = c("",
                                      "Barplot",
                                      "Pie"),
                          options = list(
                            style = "btn-primary")), prettySwitch(
        inputId = "horizontal_plot_qualitative",
        label = "Horizontal", 
        status = "primary",
        slim = TRUE
      )),
                    conditionalPanel( condition = "input.SelecQu == 'Barplot'& input.GrupoQuali == 0",
                      br(),
                      strong(h3("Barplot")),
                      br(),
                      plotOutput("plotQu"),
                      br(),
                      downloadButton("QualitativeBarplotDownloadGrupo", "Download Graph", class = "btn-primary"),
                      br(), br(),
                      shinyWidgets::dropdown(
                        label = "Customize graph",
                        tags$h3("Customize"),
                        div(
        style = "display: inline-block;vertical-align:top; width: 100%; text-align: center; margin-bottom: 10px;",
        shinyWidgets::actionBttn(
          inputId = "resetBarplotQualiNoGrupo",
          label = "Reset to Initial State",
          style = "bordered",
          color = "warning",
          size = "sm",
          icon = icon("refresh")
        )
      ),
                        div(style="display: inline-block;vertical-align:top;
        width: 150px;",selectInput("themeQu", " Theme",
                                   choices = names(themesb))),
        div(style="display: inline-block;vertical-align:top;
        width: 150px;",selectInput("fontQu", " Font", choices = fuentes)),
        div(style="display: inline-block;vertical-align:top;width: 150px;",
            textInput("ylabQu",
                      label = "ylab",
                      value = "Write ylab...")),
        div(style="display: inline-block;vertical-align:top; width: 150px;",
            textInput("xlabQu",
                      label = "xlab",
                      value = "Write xlab...")),
        div(style="display: inline-block;
        vertical-align:top; width: 150px;",
        colourInput("linecolorQu",
                  label = "Color",
                  value = "red")),
        div(style="display: inline-block;vertical-align:top;width: 150px;",
            textInput("fillQu",
                      label = "Color fill",
                      value = "#0095ff")),
        div(style="display: inline-block;vertical-align:top; width: 150px;",
            sliderInput(inputId = "lwdQu",
                        label = "Line width",
                        min = 0.1,
                        max =10 ,
                        value = 1.5)),
        div(style="display: inline-block;vertical-align:top;width: 150px;",
            sliderInput(inputId = "fontqu",
                        label = "Size font" ,
                        min = 1  ,
                        max =50 ,
                        value = 12)),
        div(style="display: inline-block;vertical-align:top; width: 150px;",
            sliderInput(inputId = "alphaQu",
                        label = "alpha",
                        min = 0.001 ,
                        max =1 ,
                        value = 0.5)),
        style = "unite",
        icon = icon("fish"),
        status = "primary",
        width = "500px",
        animate = shinyWidgets::animateOptions(
          enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
          exit = shinyWidgets::animations$fading_exits$fadeOutRightBig))
        ),
        conditionalPanel(condition = "input.SelecQu == 'Barplot'& input.GrupoQuali == 1",
          br(),
          helpText("Barplot"),
          br(),
          plotOutput("plotQu2"),
          br(),
          downloadButton("QualitativeBarplotDownloadNoGrupo", "Download Graph", class = "btn-primary"),
          br(), br(),
          shinyWidgets::dropdown(
            label = "Customize graph",tags$h3("Customize"), div(
        style = "display: inline-block;vertical-align:top; width: 100%; text-align: center; margin-bottom: 10px;",
        shinyWidgets::actionBttn(
          inputId = "resetBarplotQualiGrupo",
          label = "Reset to Initial State",
          style = "bordered",
          color = "warning",
          size = "sm",
          icon = icon("refresh")
        )
      ),
            div(style="display: inline-block;vertical-align:top;
        width: 150px;",selectInput("themeQu2", " Theme",
                                   choices = names(themesb))),
        div(style="display: inline-block;vertical-align:top;
        width: 150px;",selectInput("fontQu2", " Font", choices = fuentes)),
        div(style="display: inline-block;vertical-align:top;width: 150px;",
            textInput("ylabQu2",
                      label = "ylab",
                      value = "Write ylab...")),
        div(style="display: inline-block;vertical-align:top; width: 150px;",
            textInput("xlabQu2",
                      label = "xlab",
                      value = "Write xlab...")),
        div(style="display: inline-block;
        vertical-align:top; width: 150px;",
        colourInput("linecolorQu2",
                  label = "Color line",
                  value = "red")),
        div(
          style="display: inline-block;vertical-align:top; width: 150px;",
          selectInput("paletasQu2",
                      "Palletes",
                      choices = paletas)),
        div(style="display: inline-block;vertical-align:top; width: 150px;",
            sliderInput(inputId = "lwdQu2",
                        label = "Line width",
                        min = 0.1,
                        max =10 ,
                        value = 1.5)),
        div(style="display: inline-block;vertical-align:top;width: 150px;",
            sliderInput(inputId = "fontqu2",
                        label = "Size font" ,
                        min = 1  ,
                        max =50 ,
                        value = 12)),
        div(style="display: inline-block;vertical-align:top; width: 150px;",
            sliderInput(inputId = "alphaQu2",
                        label = "alpha",
                        min = 0.001 ,
                        max =1 ,
                        value = 0.7)),
        div(style="display: inline-block;vertical-align:top; width: 150px;",
            sliderInput(inputId = "angleQu",
                        label = "angle",
                        min = 0,
                        max =90 ,value = 1)),
        style = "unite",
        icon = icon("fish"),
        status = "primary",
        width = "500px",
        animate = shinyWidgets::animateOptions(
          enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
          exit = shinyWidgets::animations$fading_exits$fadeOutRightBig))
        ),
        conditionalPanel( condition = "input.SelecQu == 'Pie'",
          br(),
          strong(h3("Pie")),
          conditionalPanel( condition = "input.GrupoQuali == 0", plotOutput("pieplot")),
          br(),
          downloadButton("QualitativePieDownload", "Download Graph", class = "btn-primary"),
          br(), br(),
          shinyWidgets::dropdown(
            label = "Customize graph",tags$h3("Customize"),div(
        style = "display: inline-block;vertical-align:top; width: 100%; text-align: center; margin-bottom: 10px;",
        shinyWidgets::actionBttn(
          inputId = "resetPieplot",
          label = "Reset to Initial State",
          style = "bordered",
          color = "warning",
          size = "sm",
          icon = icon("refresh")
        )
      ),
            div(style="display: inline-block;vertical-align:top;
        width: 150px;",selectInput("fontPie", " Font", choices = fuentes)),
        div(style="display: inline-block;vertical-align:top;width: 150px;",
            textInput("labelfill",
                      label = "Label",
                      value = "Write...")),
        div(
          style="display: inline-block;vertical-align:top; width: 150px;",
          selectInput("paletaspie",
                      "Palletes",
                      choices = paletas)),
        div(style="display: inline-block;vertical-align:top;width: 150px;",
            sliderInput(inputId = "fontpie",
                        label = "Size font" ,
                        min = 1  ,
                        max =50 ,
                        value = 12)),
        div(style="display: inline-block;vertical-align:top; width: 150px;",
            sliderInput(inputId = "alphapie",
                        label = "alpha",
                        min = 0.001 ,
                        max =1 ,
                        value = 0.7)),
        style = "unite",
        icon = icon("fish"),
        status = "primary",
        width = "500px",
        animate = shinyWidgets::animateOptions(
          enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
          exit = shinyWidgets::animations$fading_exits$fadeOutRightBig))))

tabular_summary <- tabPanel("Tabular summary",
                    br(),
                    conditionalPanel(condition = "input.GrupoQuali == 0",
                      strong(h2("Frequency table")),
                      br(),
                      DT::DTOutput("TfreqQuali")
                    ),
                    conditionalPanel(condition = "input.GrupoQuali == 1",
                      strong(h2("Two-way table")),
                      br(),
                      DT::DTOutput("TwofreqQuali") 
                  )
)

source("pages/qualitative_tabular_summary.R", local = TRUE)
source("pages/qualitative_graphic_summaries.R", local = TRUE)
qualitative_variables <- shinydashboard::tabItem( tabName = "Qualitative_variables",
     shinydashboard::box(   height =  "100%",   width = 12,  title = "Qualitative variables",
       status = "primary",
       solidHeader = TRUE,
       collapsible = TRUE,
       sidebarPanel(
         shinyWidgets::actionBttn(
           "helpquali",
           "Help",
           icon = icon("question-circle"),
           style = "stretch",
           block = FALSE,
           color = "primary"
         ),
         shinyBS::bsModal(
           id = "modalHelpQuali",
           title = "Help: Qualitative Variables",
           trigger = "helpquali",
           size = "large",
           tags$iframe(src = "qualitative_variables.html", width = "100%", height = "600px", frameborder = 0)
         ),
         selectizeInput('selvarcuali',
                        'Qualitative variable',
                        choices = NULL,
                        multiple = FALSE),
         shinyWidgets::prettyCheckbox(
           inputId = "GrupoQuali",
           label = "Statistics by group?",
           value = FALSE,
           status = "success"
         ),
         conditionalPanel(
           condition = "input.GrupoQuali == 1",
           selectizeInput('selgrupoQuali',
                          'Group by',
                          choices = NULL,
                          multiple = TRUE,
                      
                          )
           )
       ),
       mainPanel(
         tabsetPanel(
           tabular_summary,
           graphic_summaries))
       )
     )

multivariate <- shinydashboard::tabItem( tabName = "Multivariate",
     shinydashboard::box( height =  "100%", width = 12,title = "Multivariate",
       status = "primary",
       solidHeader = TRUE,
       collapsible = TRUE,
       sidebarPanel(
          shinyWidgets::actionBttn(
            "helpmulti",
            "Help",
            icon = icon("question-circle"),
            style = "stretch",
            block = FALSE,
            color = "primary"
          ),
          shinyBS::bsModal(
            id = "modalHelpMulti",
            title = "Help: Multivariate",
            trigger = "helpmulti",
            size = "large",
            tags$iframe(src = "multivariate.html", width = "100%", height = "600px", frameborder = 0)
          ),
         selectizeInput('selmulti',
                        'Variables',
                        choices = NULL,
                        multiple = TRUE),
         shinyWidgets::prettyCheckbox(
           inputId = "Grupomulti",
           label = "Statistics by group?",
           value = FALSE,
           status = "success"
         )

         ),
       mainPanel(
         tabsetPanel(
           tabPanel("Summaries",
                    br(), strong(h2("Correlation matrix")),
                    DT::DTOutput("cormat"),
                    br(), strong(h2("Variances and covariances matrix")),
                    DT::DTOutput("covmat"),br()
                     ),
       
                    
         )
       )
     )
   )

graphic_summaries <- tabPanel("Graphic summary",
                    div(style="display: inline-block;vertical-align:top;
                        width: 150px;",shinyWidgets::pickerInput(
                          inputId = "SelecQu",
                          label = "Select:",
                          choices = c("",
                                      "Barplot",
                                      "Pie"),
                          options = list(
                            style = "btn-primary")), prettySwitch(
        inputId = "horizontal_plot_qualitative",
        label = "Horizontal", 
        status = "primary",
        slim = TRUE
      )),
                    conditionalPanel( condition = "input.SelecQu == 'Barplot'& input.GrupoQuali == 0",
                      br(),
                      strong(h3("Barplot")),
                      br(),
                      plotOutput("plotQu"),
                      br(),
                      downloadButton("QualitativeBarplotDownloadGrupo", "Download Graph", class = "btn-primary"),
                      br(), br(),
                      shinyWidgets::dropdown(
                        label = "Customize graph",
                        tags$h3("Customize"),
                        div(
        style = "display: inline-block;vertical-align:top; width: 100%; text-align: center; margin-bottom: 10px;",
        shinyWidgets::actionBttn(
          inputId = "resetBarplotQualiNoGrupo",
          label = "Reset to Initial State",
          style = "bordered",
          color = "warning",
          size = "sm",
          icon = icon("refresh")
        )
      ),
                        div(style="display: inline-block;vertical-align:top;
        width: 150px;",selectInput("themeQu", " Theme",
                                   choices = names(themesb))),
        div(style="display: inline-block;vertical-align:top;
        width: 150px;",selectInput("fontQu", " Font", choices = fuentes)),
        div(style="display: inline-block;vertical-align:top;width: 150px;",
            textInput("ylabQu",
                      label = "ylab",
                      value = "Write ylab...")),
        div(style="display: inline-block;vertical-align:top; width: 150px;",
            textInput("xlabQu",
                      label = "xlab",
                      value = "Write xlab...")),
        div(style="display: inline-block;
        vertical-align:top; width: 150px;",
        colourInput("linecolorQu",
                  label = "Color",
                  value = "red")),
        div(style="display: inline-block;vertical-align:top;width: 150px;",
            textInput("fillQu",
                      label = "Color fill",
                      value = "#0095ff")),
        div(style="display: inline-block;vertical-align:top; width: 150px;",
            sliderInput(inputId = "lwdQu",
                        label = "Line width",
                        min = 0.1,
                        max =10 ,
                        value = 1.5)),
        div(style="display: inline-block;vertical-align:top;width: 150px;",
            sliderInput(inputId = "fontqu",
                        label = "Size font" ,
                        min = 1  ,
                        max =50 ,
                        value = 12)),
        div(style="display: inline-block;vertical-align:top; width: 150px;",
            sliderInput(inputId = "alphaQu",
                        label = "alpha",
                        min = 0.001 ,
                        max =1 ,
                        value = 0.5)),
        style = "unite",
        icon = icon("fish"),
        status = "primary",
        width = "500px",
        animate = shinyWidgets::animateOptions(
          enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
          exit = shinyWidgets::animations$fading_exits$fadeOutRightBig))
        ),
        conditionalPanel(condition = "input.SelecQu == 'Barplot'& input.GrupoQuali == 1",
          br(),
          helpText("Barplot"),
          br(),
          plotOutput("plotQu2"),
          br(),
          downloadButton("QualitativeBarplotDownloadNoGrupo", "Download Graph", class = "btn-primary"),
          br(), br(),
          shinyWidgets::dropdown(
            label = "Customize graph",tags$h3("Customize"), div(
        style = "display: inline-block;vertical-align:top; width: 100%; text-align: center; margin-bottom: 10px;",
        shinyWidgets::actionBttn(
          inputId = "resetBarplotQualiGrupo",
          label = "Reset to Initial State",
          style = "bordered",
          color = "warning",
          size = "sm",
          icon = icon("refresh")
        )
      ),
            div(style="display: inline-block;vertical-align:top;
        width: 150px;",selectInput("themeQu2", " Theme",
                                   choices = names(themesb))),
        div(style="display: inline-block;vertical-align:top;
        width: 150px;",selectInput("fontQu2", " Font", choices = fuentes)),
        div(style="display: inline-block;vertical-align:top;width: 150px;",
            textInput("ylabQu2",
                      label = "ylab",
                      value = "Write ylab...")),
        div(style="display: inline-block;vertical-align:top; width: 150px;",
            textInput("xlabQu2",
                      label = "xlab",
                      value = "Write xlab...")),
        div(style="display: inline-block;
        vertical-align:top; width: 150px;",
        colourInput("linecolorQu2",
                  label = "Color line",
                  value = "red")),
        div(
          style="display: inline-block;vertical-align:top; width: 150px;",
          selectInput("paletasQu2",
                      "Palletes",
                      choices = paletas)),
        div(style="display: inline-block;vertical-align:top; width: 150px;",
            sliderInput(inputId = "lwdQu2",
                        label = "Line width",
                        min = 0.1,
                        max =10 ,
                        value = 1.5)),
        div(style="display: inline-block;vertical-align:top;width: 150px;",
            sliderInput(inputId = "fontqu2",
                        label = "Size font" ,
                        min = 1  ,
                        max =50 ,
                        value = 12)),
        div(style="display: inline-block;vertical-align:top; width: 150px;",
            sliderInput(inputId = "alphaQu2",
                        label = "alpha",
                        min = 0.001 ,
                        max =1 ,
                        value = 0.7)),
        div(style="display: inline-block;vertical-align:top; width: 150px;",
            sliderInput(inputId = "angleQu",
                        label = "angle",
                        min = 0,
                        max =90 ,value = 1)),
        style = "unite",
        icon = icon("fish"),
        status = "primary",
        width = "500px",
        animate = shinyWidgets::animateOptions(
          enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
          exit = shinyWidgets::animations$fading_exits$fadeOutRightBig))
        ),
        conditionalPanel( condition = "input.SelecQu == 'Pie'",
          br(),
          strong(h3("Pie")),
          conditionalPanel( condition = "input.GrupoQuali == 0", plotOutput("pieplot")),
          br(),
          downloadButton("QualitativePieDownload", "Download Graph", class = "btn-primary"),
          br(), br(),
          shinyWidgets::dropdown(
            label = "Customize graph",tags$h3("Customize"),div(
        style = "display: inline-block;vertical-align:top; width: 100%; text-align: center; margin-bottom: 10px;",
        shinyWidgets::actionBttn(
          inputId = "resetPieplot",
          label = "Reset to Initial State",
          style = "bordered",
          color = "warning",
          size = "sm",
          icon = icon("refresh")
        )
      ),
            div(style="display: inline-block;vertical-align:top;
        width: 150px;",selectInput("fontPie", " Font", choices = fuentes)),
        div(style="display: inline-block;vertical-align:top;width: 150px;",
            textInput("labelfill",
                      label = "Label",
                      value = "Write...")),
        div(
          style="display: inline-block;vertical-align:top; width: 150px;",
          selectInput("paletaspie",
                      "Palletes",
                      choices = paletas)),
        div(style="display: inline-block;vertical-align:top;width: 150px;",
            sliderInput(inputId = "fontpie",
                        label = "Size font" ,
                        min = 1  ,
                        max =50 ,
                        value = 12)),
        div(style="display: inline-block;vertical-align:top; width: 150px;",
            sliderInput(inputId = "alphapie",
                        label = "alpha",
                        min = 0.001 ,
                        max =1 ,
                        value = 0.7)),
        style = "unite",
        icon = icon("fish"),
        status = "primary",
        width = "500px",
        animate = shinyWidgets::animateOptions(
          enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
          exit = shinyWidgets::animations$fading_exits$fadeOutRightBig))))

numerical_summary <- tabPanel("Numerical summary",
              div(style="display: inline-block;vertical-align:top;
                        width: 180px;",
                  shinyWidgets::pickerInput(
                    inputId = "NumSu",
                    label = "Select measures of:",
                    choices = c("",
                                "Central tendency",
                                "Dispersion or variability",
                                "Relative position",
                                "Shape"),
                    options = list(
                      style = "btn-primary"))),
              conditionalPanel(
                condition = "input.NumSu == 'Central tendency'",
                DT::DTOutput("central"),
              ),
              conditionalPanel(
                condition = "input.NumSu == 'Dispersion or variability'",
                DT::DTOutput("variability"),
              ),
              conditionalPanel(
                condition = "input.NumSu == 'Relative position'",
                div(style="display: inline-block;vertical-align:top;
                        width: 180px;",
                    shinyWidgets::pickerInput(
                      inputId = "relpos",
                      label = "Select measures of:",
                      choices = c("Quartiles","Percentiles"),
                      options = list(
                        style = "btn-default")))
              ),
              conditionalPanel( condition = "input.relpos == 'Quartiles' && input.NumSu == 'Relative position'",
                div(style="display: inline-block;vertical-align:top;
                        width: 180px;",
                    numericInput(inputId= "nquartiles", "Number of quartiles to calculate:",
                                 value = 3, min = 2, max = 10, step = 1, width = "90%")),
                DT::DTOutput("quart")
              ),
              conditionalPanel(
                condition = "input.relpos == 'Percentiles'",
                div(style="display: inline-block;vertical-align:top;
                        width: 180px;",
                numericInput(inputId= "npercent", "Enter the desired percentile (between 1 and 99):",
                             value = 90, min = 1, max = 99, step = 1, width = "90%")),
                   verbatimTextOutput("perc"),
                DT::DTOutput("perct")
              ),
              conditionalPanel( condition = "input.NumSu == 'Shape'",
                DT::DTOutput("shape")
              )
              )

# Load custom functions
kurtosis <- function(x) {
  m4 <- mean((x - mean(x))^4)
  kurtosis <- m4/(sd(x)^4) - 3
  kurtosis
}

kurtosis_standardized <- function(x) {
  n <- length(x)
  m4 <- mean((x - mean(x))^4)
  kurtosis_standardized <- (m4/(sd(x)^4)) - 3 * ((n-1)/((n-2)*(n-3)))
  kurtosis_standardized
}


skewness <-  function(x) {
  m3 <- mean((x - mean(x))^3)
  skewness <- m3/(sd(x)^3)
  skewness
}
skewness_standardized <- function(x) {
  m3 <- mean((x - mean(x))^3)
  s3 <- sd(x)^3
  n <- length(x)
  skewness <- m3/s3
  asimetria_estandarizada <- skewness * sqrt(n * (n-1)) / (n-2)
  asimetria_estandarizada
}




geometric.mean <-
  function(x,na.rm=TRUE){ if (is.null(nrow(x))) {exp(mean(log(x),na.rm=na.rm)) } else {
    exp(apply(log(x),2,mean,na.rm=na.rm))} }

bsModalNoClose <- function(...) {
  b <- shinyBS::bsModal(...)
  b[[2]]$`data-backdrop` <- "static"
  b[[2]]$`data-keyboard` <- "false"
  return(b)
}

# temas ggplot
themesb <- list(
  "grey" = ggplot2::theme_grey(),
  "minimal" = ggplot2::theme_minimal(),
  "bw" = ggplot2::theme_bw(),
  "classic" = ggplot2::theme_classic(),
  "linedraw" = ggplot2::theme_linedraw(),
  "light" = ggplot2::theme_light(),
  "dark" = ggplot2::theme_dark(),
  "test" = ggplot2::theme_test(),
  "void" = ggplot2::theme_void()
)

fuentes <- list(
  "mono" ="mono",
  "sans" = "sans",
  "serif" = "serif",
  "Courier"= "Courier" ,
  "Helvetica"="Helvetica",
  "Times"= "Times",
  "Palatino" ="Palatino"
   )

fuentes <- list(
  "mono" ="mono",
  "sans" = "sans",
  "serif" = "serif",
  "Courier"= "Courier" ,
  "Helvetica"="Helvetica",
  "Times"= "Times",
  "Palatino" ="Palatino"
)

paletas <- c("Accent",
             "Dark2",
             "Paired",
             "Pastel1",
             "Pastel2",
             "Set1",
             "Set2",
  "Blues", "BuGn", "BuPu", "GnBu", "Greens", "Greys",
  "Oranges", "OrRd", "PuBu", "PuBuGn", "PuRd", "Purples",
  "RdPu" ,"Reds" ,"YlGn", "YlGnBu","YlOrBr", "YlOrRd",
  "BrBG" ,"PiYG", "PRGn", "PuOr", "RdBu", "RdGy", "RdYlBu",
  "RdYlGn", "Spectral","Set3")


Multiva <-function(datos){
  n<-nrow(datos)
  n
  p<-ncol(datos)
  p
  #vector de unos
  vector.uno<-matrix(rep(1,n),ncol=1)
  vector.uno

  ## a.- EL VECTOR DE MEDIAS(xprom) = (x'1n)/n
  vector.media<-(t(datos)%*%vector.uno)/n
  vector.media

  ## b.- Matriz de covarianza S=1/n(x'*x)-((vector.media)(vector.media)')
  matriz.covarianza<-S<-cov(datos)*(n-1)/n
  matriz.covarianza

  #Inversa de la matriz de covarianzas
  SI<-solve(S)
  SI

  ##c.-Matriz de Correlación R=D^-1/2*S*D^-1/2
  DN<-diag(c(1/sqrt(diag(S))))
  DN
  matriz.correlacion<-DN%*%S%*%DN

  ##d.-Medidas Globales de variabilidad

  ##d.1.-Varianza total : VT=traza(S)
  VT<-sum(diag(S))
  VT

  ##d.2.-Varianza media : VM=VT/p
  VM<-VT/p
  VM

  ##d.3.- varianza generalizada : VG = det(S)
  VG<-det(S)
  VG

  ##d.4.-Varianza efectiva : VE=[det(S)]^1/p
  VE<-(det(S))^(1/p)
  VE

  ##e.- Distancia de Mahalanobis
  x<-as.matrix(datos)
  media<-colMeans(datos)
  matriz.media<-matrix(media,nrow = n,ncol=p,byrow = TRUE)
  distm<-((x-matriz.media)%*%SI)%*%t((x-matriz.media))

  cat("----------------------------------------------------------------","\n")
  cat("-Global measures of variability","\n",
      "1.- Total variance =", VT, "\n",
      "2.- Mean variance =",VM, "\n",
      "3.- Generalized Variance=",VG, "\n",
      "4.- Effective Variance =",VE, "\n")
  cat("----------------------------------------------------------------","\n")

}


# Función para encontrar el valor de a correspondiente a una probabilidad dada para diferentes distribuciones
# distribución: cadena de texto que indica la distribución ("Normal", "t-Student", "Chi^2", "F-Fisher", "Exponential", "Logistics", "Log-Normal", "Gamma", "Weibull" o "Beta")
# probabilidad: probabilidad deseada (0 < probabilidad < 1)
# grados_libertad: número de grados de libertad para la distribución t-Student o la chi cuadrada
# param1, param2: parámetros de forma y escala para las distribuciones exponencial, log-normal, gamma, weibull y beta
# Retorna el valor de a correspondiente a la probabilidad deseada

valor_x_lower <- function(distr, prob, df = NULL, param1 = NULL, param2 = NULL) {
  if(distr == "Normal") {
    return(qnorm(prob))
  } else if(distr == "t-Student") {
    return(qt(prob, df = df,lower.tail = TRUE))
  } else if(distr == "Chi^2") {
    return(qchisq(prob, df = df,lower.tail = TRUE))
  } else if(distr == "F-Fisher") {
    return(qf(prob, df1 = param1, df2 = param2,lower.tail = TRUE))
  } else if(distr == "Exponential") {
    return(qexp(prob, rate = param1,lower.tail = TRUE))
  } else if(distr == "Logistics") {
    return(qlogis(prob, location = param1, scale = param2,lower.tail = TRUE))
  } else if(distr == "Log-Normal") {
    return(qlnorm(prob, meanlog = param1, sdlog = param2,lower.tail = TRUE))
  } else if(distr == "Gamma") {
    return(qgamma(prob, shape = param1, rate = param2,lower.tail = TRUE))
  } else if(distr == "Weibull") {
    return(qweibull(prob, shape = param1, scale = param2,lower.tail = TRUE))
  } else if(distr == "Beta") {
    return(qbeta(prob, shape1 = param1, shape2 = param2,lower.tail = TRUE))
  } else {
    stop("Distribución no soportada.")
  }
}

tab0_about <- shinydashboard::tabItem(
  tabName = "tab0",
  shiny::fluidPage(
    tags$iframe(
      src = "about.html",
      width = "80%",
      height = "800px",
      frameborder = 0,
      scrolling = "auto"
    )
  )
)

# header.R

header <- dashboardHeader(
  title = "StatisticTeach1",
  titleWidth = 280,
  tags$li(
    class = "dropdown",
    actionLink(
      "stop_radiant",
      "Stop",
      icon = icon("power-off"),
      onclick = "setTimeout(function(){window.close();}, 100);")
  )
)

discrete_probability_distributions  <-   shinydashboard::tabItem(
      tabName = "Discrete",
      shinydashboard::box(width = "100%",
          height = "100%",
          title = "Discrete Probability Distributions",
          status = "primary",
          solidHeader = TRUE,
          collapsible = TRUE,
         sidebarPanel(width = 3, helpText(h5("Discrete Probability Distributions")),
                      shinyWidgets::actionBttn("helploadD",
                                               "",
                                               icon = icon("question-circle"),
                                               style = "stretch",
                                               block = FALSE,
                                               color = "primary"
                      ),
                      shinyBS::bsModal(id="helpD",
                                       title = "",
                                       trigger = "helploadD",
                                       size="large",
                                       tags$iframe(
                                         src = "discretas.html",
                                         width = "100%",
                                         height = "1000px",
                                         frameborder = 0,
                                         scrolling = "auto"
                                       )
                      ),
                      shinyWidgets::pickerInput(
                         inputId = "discretas",
                         label = "Distribution",
                         choices = c("Select distribution",
                                     "Binomial",
                                     "Geometric",
                                     #"Geometric (II)",
                                     "Hypergeometric",
                                     "Negative Binomial",
                                     #"Negative Binomial (II)",
                                     "Poisson"),
                         options = list(style = "btn-primary")),
                      conditionalPanel(
                        condition = "input.discretas != 'Select distribution'",
                        radioButtons(
                          inputId = "tipo",
                          label = NULL,
                          inline = TRUE,
                          choices = c("Values", "Probabilities"))
                      ),

                      conditionalPanel(
                        condition = "input.discretas == 'Binomial'",
                        numericInput("n_binomial",
                                     "Trial \\(n\\):",
                                      value = 20, min = 0, step = 1),
                         numericInput("p_binomial",
                                      "Probability of success \\(p\\):",
                                      value = 0.5, min = 0, max = 1,
                                      step = 0.01)
                        ),
                       conditionalPanel(
                         condition = "input.discretas == 'Geometric'",
                         numericInput("p_geometric",
                                      "Probability of success \\(p\\):",
                                      value = 0.5, min = 0,
                                      max = 1, step = 0.01)
                       ),
                      conditionalPanel(
                         condition = "input.discretas == 'Hypergeometric'",
                         numericInput("n_hypergeometric",
                                      "Sample size \\(n\\):",
                                      value = 20, min = 0, step = 1),
                         numericInput("N_hypergeometric",
                                      "Population size  \\(N\\):",
                                      value = 50, min = 0, step = 1),
                         numericInput("M_hypergeometric", "
                                     Number of successes \\(M\\):",
                                      value = 15, min = 0, step = 1)
                       ),
                       conditionalPanel(
                         condition = "input.discretas == 'Negative Binomial'",
                         numericInput("r_negativebinomial",
                                      "Number of successes \\(r\\):",
                                      value = 5, min = 1, step = 1 ),
                         numericInput("p_negativebinomial",
                                      "Probability of success \\(p\\):",
                                      value = 0.5, min = 0,
                                      max = 1, step = 0.01 )
                       ),
                    conditionalPanel(
                         condition = "input.discretas == 'Poisson'",
                         numericInput("lambda_poisson",
                                      "Rate \\(\\lambda\\):",
                                      value = 4, min = 1, step = 1)
                       ),
                       conditionalPanel(
                         condition = "input.discretas == 'Binomial'&& input.tipo== 'Values'",
                         radioButtons(
                           inputId = "lower_tail_binomial",
                           label = NULL,
                           choices = c(
                             "Exact value: \\(P(X = x)\\)" = "exact",
                             "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                             "Upper tail : \\(P(X \\geq x)\\)" = "upper.tail",
                             "Interval : \\(P(a \\leq X \\leq b)\\)" = "interval",
                             "Tails : \\(P(X \\leq a )+ P(X \\geq b)\\)" = "tails"

                           )
                         )
                       ),
                    conditionalPanel(
                      condition = "input.discretas == 'Binomial'&& input.tipo == 'Probabilities'",
                      numericInput(inputId = "probB", label = "Probability of interest:",
                                   value = 0.5, step = 0.01),
                      radioButtons(
                        inputId = "lower_tail_binomialP",
                        label = "Type of desired outcome",
                        choices = c(
                          #"Exact value: \\(P(X = x)\\)" = "exact",
                          "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                          "Upper tail : \\(P(X \\geq x)\\)" = "upper.tail"
                        )
                      )
                    ),
                       conditionalPanel(
                         condition = "input.discretas == 'Geometric'&& input.tipo== 'Values'",

                         radioButtons(
                           inputId = "lower_tail_geometric",
                           label = NULL,
                           choices = c(
                             "Exact value: \\(P(X = x)\\)" = "exact",
                             "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                             "Upper tail : \\(P(X \\geq x)\\)" = "upper.tail",
                             "Interval : \\(P(a \\leq X \\leq b)\\)" = "interval",
                             "Tails : \\(P(X \\leq a )+ P(X \\geq b)\\)" = "tails"
                           )
                         )
                       ),
                    conditionalPanel(
                      condition = "input.discretas == 'Geometric'&& input.tipo== 'Probabilities'",
                      numericInput(inputId = "probG", label = "Probability of interest:",
                                   value = 0.25, step = 0.01),
                      radioButtons(
                        inputId = "lower_tail_geometricP",
                        label = "Type of desired outcome",
                        choices = c(
                         # "Exact value: \\(P(X = x)\\)" = "exact",
                          "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                          "Upper tail : \\(P(X \\geq x)\\)" = "upper.tail"
                        )
                      )
                    ),







                    conditionalPanel(
                      condition = "input.discretas == 'Hypergeometric'&& input.tipo== 'Probabilities'",
                      numericInput(inputId = "probH", label = "Probability of interest:",
                                   value = 0.15, step = 0.01),
                      radioButtons(
                        inputId = "lower_tail_hyperP",
                        label = "Type of desired outcome",
                        choices = c(
                         # "Exact value: \\(P(X = x)\\)" = "exact",
                          "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                          "Upper tail : \\(P(X \\geq x)\\)" = "upper.tail"
                        )
                      )
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Negative Binomial'&& input.tipo == 'Probabilities'",
                      numericInput(inputId = "probN", label = "Probability of interest:",
                                   value = 0.05, step = 0.01),
                      radioButtons(
                        inputId = "lower_tail_negativeP",
                        label = "Type of desired outcome",
                        choices = c(
                          #"Exact value: \\(P(X = x)\\)" = "exact",
                          "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                          "Upper tail : \\(P(X \\geq x)\\)" = "upper.tail"
                        )
                      )),
                    conditionalPanel(
                      condition = "input.discretas == 'Poisson'&& input.tipo == 'Probabilities'",
                      numericInput(inputId = "probP", label = "Probability of interest:",
                                   value = 0.05, step = 0.01),
                      radioButtons(
                        inputId = "lower_tail_poissonP",
                        label = "Type of desired outcome",
                        choices = c(
                          #"Exact value: \\(P(X = x)\\)" = "exact",
                          "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                          "Upper tail : \\(P(X \\geq x)\\)" = "upper.tail"
                        )
                      )),

                    conditionalPanel(
                         condition = "input.discretas == 'Hypergeometric'&& input.tipo== 'Values'",
                         radioButtons(
                           inputId = "lower_tail_hypergeometric",
                           label = NULL,
                           choices = c(
                             "Exact value: \\(P(X = x)\\)" = "exact",
                             "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                             "Upper tail : \\(P(X \\geq x)\\)" = "upper.tail",
                             "Interval : \\(P(a \\leq X \\leq b)\\)" = "interval",
                             "Tails : \\(P(X \\leq a )+ P(X \\geq b)\\)" = "tails"
                           )
                         )
                       ),
                       conditionalPanel(
                         condition = "input.discretas == 'Negative Binomial'&& input.tipo== 'Values'",
                         radioButtons(
                           inputId = "lower_tail_negativebinomial",
                           label = NULL,
                           choices = c(
                             "Exact value: \\(P(X = x)\\)" = "exact",
                             "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                             "Upper tail : \\(P(X \\geq x)\\)" = "upper.tail",
                             "Interval : \\(P(a \\leq X \\leq b)\\)" = "interval",
                             "Tails : \\(P(X \\leq a )+ P(X \\geq b)\\)" = "tails"
                           )
                         )
                       ),
                    conditionalPanel(
                         condition = "input.discretas == 'Poisson'&& input.tipo== 'Values'",
                         radioButtons(
                           inputId = "lower_tail_poisson",
                           label = NULL,
                           choices = c(
                             "Exact value: \\(P(X = x)\\)" = "exact",
                             "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                             "Upper tail : \\(P(X \\geq x)\\)" = "upper.tail",
                             "Interval : \\(P(a \\leq X \\leq b)\\)" = "interval",
                             "Tails : \\(P(X \\leq a )+ P(X \\geq b)\\)" = "tails"
                           )
                         )
                       ),
                      conditionalPanel(
                        condition = "input.discretas == 'Binomial' && input.lower_tail_binomial == 'exact'&& input.tipo== 'Values'",
                        numericInput("x_binomial", "x:",
                                     value = 9, min = 1, step = 1
                        )
                      ),
                       conditionalPanel(
                         condition = "input.discretas == 'Binomial' && input.lower_tail_binomial == 'lower.tail'&& input.tipo== 'Values'",
                         numericInput("x1_binomial", "x:",
                                      value = 8, min = 0, step = 1
                         )
                       ),
                       conditionalPanel(
                         condition = "input.discretas == 'Binomial' && input.lower_tail_binomial == 'upper.tail'&& input.tipo== 'Values'",
                         numericInput("x2_binomial", "x:",
                                      value = 8, min = 0, step = 1
                         )
                       ),
                       conditionalPanel(
                         condition = "input.discretas == 'Binomial' && input.lower_tail_binomial == 'interval'&& input.tipo== 'Values'",
                         numericInput("a_binomial", "a:",
                                      value = 8, min = 0, step = 1
                         ),
                         numericInput("b_binomial", "b: \\( (a \\leq b) \\)",
                                      value = 12, min = 0, step = 1
                         )
                       ),
                      conditionalPanel(
                        condition = "input.discretas == 'Binomial' && input.lower_tail_binomial == 'tails'&& input.tipo== 'Values'",
                        numericInput("at_binomial", "a:",
                                     value = 5, min = 0, step = 1
                        ),
                        numericInput("bt_binomial", "b: ",
                                     value = 15, min = 0, step = 1
                        )
                      ),
                      conditionalPanel(
                        condition = "input.discretas == 'Geometric' && input.lower_tail_geometric == 'exact'&& input.tipo== 'Values'",
                        helpText("Number of failures before  \\(1^{st}\\) success"),
                        numericInput("x_geometric", "x:",
                                     value = 1, min = 0, step = 1
                        )
                      ),
                       conditionalPanel(
                         condition = "input.discretas == 'Geometric' && input.lower_tail_geometric == 'lower.tail'&& input.tipo== 'Values'",

                         numericInput("x1_geometric", "x:",
                                      value = 5, min = 0, step = 1
                         )
                       ),
                       conditionalPanel(
                         condition = "input.discretas == 'Geometric' && input.lower_tail_geometric == 'upper.tail'&& input.tipo== 'Values'",

                         numericInput("x2_geometric", "x:",
                                      value = 1, min = 0, step = 1
                         )
                       ),
                       conditionalPanel(
                         condition = "input.discretas == 'Geometric' && input.lower_tail_geometric == 'interval'&& input.tipo== 'Values'",

                         numericInput("a_geometric", "a:",
                                      value = 1, min = 0, step = 1
                         ),
                         numericInput("b_geometric", "b: ",
                                      value = 3, min = 0, step = 1
                         )
                       ),
                      conditionalPanel(
                        condition = "input.discretas == 'Geometric' && input.lower_tail_geometric == 'tails'&& input.tipo== 'Values'",

                        numericInput("at_geometric", "a:",
                                     value = 1, min = 0, step = 1
                        ),
                        numericInput("bt_geometric", "b: ",
                                     value = 3, min = 0, step = 1
                        )
                      ),
                      conditionalPanel(
                        condition = "input.discretas == 'Hypergeometric' && input.lower_tail_hypergeometric == 'exact'&& input.tipo== 'Values'",
                        numericInput("x_hypergeometric", "x:",
                                     value = 8, min = 0, step = 1
                        )
                      ),
                       conditionalPanel(
                         condition = "input.discretas == 'Hypergeometric' && input.lower_tail_hypergeometric == 'lower.tail'&& input.tipo== 'Values'",
                         numericInput("x1_hypergeometric", "x:",
                                      value = 8, min = 0, step = 1
                         )
                       ),
                       conditionalPanel(
                         condition = "input.discretas == 'Hypergeometric' && input.lower_tail_hypergeometric == 'upper.tail'&& input.tipo== 'Values'",
                         numericInput("x2_hypergeometric", "x:",
                                      value = 8, min = 0, step = 1
                         )
                       ),
                       conditionalPanel(
                         condition = "input.discretas == 'Hypergeometric' && input.lower_tail_hypergeometric == 'interval'&& input.tipo== 'Values'",
                         numericInput("a_hypergeometric", "a:",
                                      value = 8, min = 0, step = 1
                         ),
                         numericInput("b_hypergeometric", "b: \\( (a \\leq b) \\)",
                                      value = 12, min = 0, step = 1
                         )
                       ),
                      conditionalPanel(
                        condition = "input.discretas == 'Hypergeometric' && input.lower_tail_hypergeometric == 'tails'&& input.tipo== 'Values'",
                        numericInput("at_hypergeometric", "a:",
                                     value = 8, min = 0, step = 1
                        ),
                        numericInput("bt_hypergeometric", "b:",
                                     value = 12, min = 0, step = 1
                        )
                      ),
                      conditionalPanel(
                        condition = "input.discretas == 'Negative Binomial' && input.lower_tail_negativebinomial == 'exact'&& input.tipo== 'Values'",
                        helpText("Número de fallas antes del  \\(r^{th}\\) success"),
                        numericInput("x_negativebinomial", "x:",
                                     value = 2, min = 0, step = 1
                        )
                      ),
                       conditionalPanel(
                         condition = "input.discretas == 'Negative Binomial' && input.lower_tail_negativebinomial == 'lower.tail'&& input.tipo== 'Values'",
                         helpText("Número de fallas antes del  \\(r^{th}\\) success"),
                         numericInput("x1_negativebinomial", "x:",
                                      value = 2, min = 0, step = 1
                         )
                       ),
                       conditionalPanel(
                         condition = "input.discretas == 'Negative Binomial' && input.lower_tail_negativebinomial == 'upper.tail'&& input.tipo== 'Values'",
                         helpText("Number of failures before  \\(r^{th}\\) success"),
                         numericInput("x2_negativebinomial", "x:",
                                      value = 2, min = 0, step = 1
                         )
                       ),
                       conditionalPanel(
                         condition = "input.discretas == 'Negative Binomial' && input.lower_tail_negativebinomial == 'interval'&& input.tipo== 'Values'",
                         helpText("Number of failures before  \\(r^{th}\\) success"),
                         numericInput("a_negativebinomial", "a:",
                                      value = 2, min = 0, step = 1
                         ),
                         numericInput("b_negativebinomial", "b: \\( (a \\leq b) \\)",
                                      value = 4, min = 0, step = 1
                         )
                       ),
                      conditionalPanel(
                        condition = "input.discretas == 'Negative Binomial' && input.lower_tail_negativebinomial == 'tails'&& input.tipo== 'Values'",
                        helpText("Number of failures before  \\(r^{th}\\) success"),
                        numericInput("at_negativebinomial", "a:",
                                     value = 2, min = 0, step = 1
                        ),
                        numericInput("bt_negativebinomial", "b:",
                                     value = 4, min = 0, step = 1
                        )
                      ),
                    conditionalPanel(
                        condition = "input.discretas == 'Poisson' && input.lower_tail_poisson == 'exact'&& input.tipo== 'Values'",
                        numericInput("x_poisson", "x:",
                                     value = 6, min = 0, step = 1
                        )
                      ),
                       conditionalPanel(
                         condition = "input.discretas == 'Poisson' && input.lower_tail_poisson == 'lower.tail'&& input.tipo== 'Values'",
                         numericInput("x1_poisson", "x:",
                                      value = 6, min = 0, step = 1
                         )
                       ),
                       conditionalPanel(
                         condition = "input.discretas == 'Poisson' && input.lower_tail_poisson == 'upper.tail'&& input.tipo== 'Values'",
                         numericInput("x2_poisson", "x:",
                                      value = 6, min = 0, step = 1
                         )
                       ),
                       conditionalPanel(
                         condition = "input.discretas == 'Poisson' && input.lower_tail_poisson == 'interval'&& input.tipo== 'Values'",
                         numericInput("a_poisson", "a:",
                                      value = 6, min = 0, step = 1
                         ),
                         numericInput("b_poisson", "b: \\( (a \\leq b) \\)",
                                      value = 10, min = 0, step = 1
                         )
                       ),
                      conditionalPanel(
                        condition = "input.discretas == 'Poisson' && input.lower_tail_poisson == 'tails'&& input.tipo== 'Values'",
                        numericInput("at_poisson", "a:",
                                     value = 6, min = 0, step = 1
                        ),
                        numericInput("bt_poisson", "b:",
                                     value = 10, min = 0, step = 1
                        )
                      ),
                    actionButton("refresh1" ,"Refresh")
          ),
          mainPanel(height = "100%",
                    tags$b("Distribution details:"),
                    uiOutput("parameters_distribution1"),
                    br(),
                    tags$b("Solution:"),
                    uiOutput("results_distribution2"),
                    fluidRow(
                      column(width = 9,

                    conditionalPanel(
                     condition = "input.discretas == 'Binomial' && input.tipo == 'Probabilities' && input.lower_tail_binomialP == 'upper.tail'",
                     plotOutput("binomialPlot_Probabilities_upper")
                             ),
                    conditionalPanel(
                             condition = "input.discretas == 'Binomial' && input.tipo == 'Probabilities' && input.lower_tail_binomialP == 'lower.tail'",
                             plotOutput("binomialPlot_Probabilities_lower")
                             ),

                    conditionalPanel(
                      condition = "input.discretas == 'Binomial' && input.tipo == 'Values' && input.lower_tail_binomial == 'exact'",
                      plotOutput("binomialPlot_exact")

                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Binomial' && input.lower_tail_binomial == 'lower.tail'",
                      plotOutput("binomialPlot_lower")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Binomial' && input.lower_tail_binomial == 'upper.tail'",
                      plotOutput("binomialPlot_upper")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Binomial' && input.lower_tail_binomial == 'interval'",
                      plotOutput("binomialPlot_interval")
                    ),

                    conditionalPanel(
                      condition = "input.discretas == 'Binomial' && input.lower_tail_binomial == 'tails'",
                      plotOutput("binomialPlot_tails")
                    ),






                    conditionalPanel(
                      condition = "input.discretas == 'Geometric' && input.tipo == 'Probabilities' && input.lower_tail_geometricP=='lower.tail'",
                      plotOutput("geometricPlot_probabilities_lower")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Geometric' && input.tipo == 'Probabilities' && input.lower_tail_geometricP=='upper.tail'",
                      plotOutput("geometricPlot_probabilities_upper")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Geometric' && input.lower_tail_geometric == 'exact'",
                      plotOutput("geometricPlot_exact")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Geometric' && input.lower_tail_geometric == 'lower.tail'",
                      plotOutput("geometricPlot_lower")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Geometric' && input.lower_tail_geometric == 'upper.tail'",
                      plotOutput("geometricPlot_upper")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Geometric' && input.lower_tail_geometric == 'interval'",
                      plotOutput("geometricPlot_interval")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Geometric' && input.lower_tail_geometric == 'tails'",
                      plotOutput("geometricPlot_tails")
                    ),



                    conditionalPanel(
                      condition = "input.discretas == 'Hypergeometric' && input.tipo == 'Probabilities' && input.lower_tail_hyperP=='lower.tail'",
                      plotOutput("hypergeometricPlot_probabilities_lower")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Hypergeometric' && input.tipo == 'Probabilities' && input.lower_tail_hyperP=='upper.tail'",
                      plotOutput("hypergeometricPlot_probabilities_upper")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Hypergeometric' && input.lower_tail_hypergeometric == 'exact'",
                      plotOutput("hypergeometricPlot_exact")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Hypergeometric' && input.lower_tail_hypergeometric == 'lower.tail'",
                      plotOutput("hypergeometricPlot_lower")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Hypergeometric' && input.lower_tail_hypergeometric == 'upper.tail'",
                      plotOutput("hypergeometricPlot_upper")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Hypergeometric' && input.lower_tail_hypergeometric == 'interval'",
                      plotOutput("hypergeometricPlot_interval")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Hypergeometric' && input.lower_tail_hypergeometric == 'tails'",
                      plotOutput("hypergeometricPlot_tails")
                    ),







                    conditionalPanel(
                      condition = "input.discretas == 'Negative Binomial' && input.tipo == 'Probabilities' && input.lower_tail_negativeP == 'lower.tail'",
                      plotOutput("negativebinomialPlot_Probalities_lower")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Negative Binomial' && input.tipo == 'Probabilities' && input.lower_tail_negativeP == 'upper.tail'",
                      plotOutput("negativebinomialPlot_Probabilities_upper")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Negative Binomial' && input.lower_tail_negativebinomial == 'exact'",
                      plotOutput("negativebinomialPlot_exact")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Negative Binomial' && input.lower_tail_negativebinomial == 'lower.tail'",
                      plotOutput("negativebinomialPlot_lower")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Negative Binomial' && input.lower_tail_negativebinomial == 'upper.tail'",
                      plotOutput("negativebinomialPlot_upper")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Negative Binomial' && input.lower_tail_negativebinomial == 'interval'",
                      plotOutput("negativebinomialPlot_interval")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Negative Binomial' && input.lower_tail_negativebinomial == 'tails'",
                      plotOutput("negativebinomialPlot_tails")
                    ),


                    conditionalPanel(
                      condition = "input.discretas == 'Poisson'  && input.tipo == 'Probabilities' && input.lower_tail_poissonP == 'lower.tail'",
                      plotOutput("poissonPlot_Probabilities_lower")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Poisson'   && input.tipo == 'Probabilities' && input.lower_tail_poissonP == 'upper.tail'",
                      plotOutput("poissonPlot_Probabilities_upper")
                    ),

                    conditionalPanel(
                      condition = "input.discretas == 'Poisson' && input.lower_tail_poisson == 'exact'",
                      plotOutput("poissonPlot_exact")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Poisson' && input.lower_tail_poisson == 'lower.tail'",
                      plotOutput("poissonPlot_lower")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Poisson' && input.lower_tail_poisson == 'upper.tail'",
                      plotOutput("poissonPlot_upper")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Poisson' && input.lower_tail_poisson == 'interval'",
                      plotOutput("poissonPlot_interval"),
                      ),
                    conditionalPanel(
                      condition = "input.discretas == 'Poisson' && input.lower_tail_poisson == 'tails'",
                      plotOutput("poissonPlot_tails"),
                    )
                    ), column(width = 3, DT::DTOutput("table_discrete")),
                    ),
                    shinyjs::useShinyjs(),
                    downloadButton('downloadPlot', 'Download Plot'),
                    br()
                    #fluidRow(
                     # column(width = 9,
                                   # conditionalPanel(
                                     # condition = "input.discretas == 'Binomial' && input.lower_tail_binomial == 'lower.tail'",
                                     # plotOutput("binomialPlot_loweracum")
                                    # ),
                             #conditionalPanel(
                              # condition = "input.discretas == 'Binomial' && input.lower_tail_binomial == 'upper.tail'"#,
                               # plotOutput("binomialPlot_upperacum")
                            # ),
                             #conditionalPanel(
                              # condition = "input.discretas == 'Geometric' && input.lower_tail_geometric == 'lower.tail'",
                              # plotOutput("geometricPlot_loweracum"))
                          #  )#,
                      #column(width = 3,DT::DTOutput("table_discrete_acum"))

                   # )



          ) #finmainpanel
      )

    )

discrete_probability_distributions  <-   shinydashboard::tabItem(
      tabName = "Discrete",
      shinydashboard::box(width = "100%",
          height = "100%",
          title = "Discrete Probability Distributions",
          status = "primary",
          solidHeader = TRUE,
          collapsible = TRUE,
         sidebarPanel(width = 3, helpText(h5("Discrete Probability Distributions")),
                      shinyWidgets::actionBttn("helploadD",
                                               "",
                                               icon = icon("question-circle"),
                                               style = "stretch",
                                               block = FALSE,
                                               color = "primary"
                      ),
                      shinyBS::bsModal(id="helpD",
                                       title = "",
                                       trigger = "helploadD",
                                       size="large",
                                       tags$iframe(
                                         src = "discretas.html",
                                         width = "100%",
                                         height = "1000px",
                                         frameborder = 0,
                                         scrolling = "auto"
                                       )
                      ),
                      shinyWidgets::pickerInput(
                         inputId = "discretas",
                         label = "Distribution",
                         choices = c("Select distribution",
                                     "Binomial",
                                     "Geometric",
                                     #"Geometric (II)",
                                     "Hypergeometric",
                                     "Negative Binomial",
                                     #"Negative Binomial (II)",
                                     "Poisson"),
                         options = list(style = "btn-primary")),
                      conditionalPanel(
                        condition = "input.discretas != 'Select distribution'",
                        radioButtons(
                          inputId = "tipo",
                          label = NULL,
                          inline = TRUE,
                          choices = c("Values", "Probabilities"))
                      ),

                      conditionalPanel(
                        condition = "input.discretas == 'Binomial'",
                        numericInput("n_binomial",
                                     "Trial \\(n\\):",
                                      value = 20, min = 0, step = 1),
                         numericInput("p_binomial",
                                      "Probability of success \\(p\\):",
                                      value = 0.5, min = 0, max = 1,
                                      step = 0.01)
                        ),
                       conditionalPanel(
                         condition = "input.discretas == 'Geometric'",
                         numericInput("p_geometric",
                                      "Probability of success \\(p\\):",
                                      value = 0.5, min = 0,
                                      max = 1, step = 0.01)
                       ),
                      conditionalPanel(
                         condition = "input.discretas == 'Hypergeometric'",
                         numericInput("n_hypergeometric",
                                      "Sample size \\(n\\):",
                                      value = 20, min = 0, step = 1),
                         numericInput("N_hypergeometric",
                                      "Population size  \\(N\\):",
                                      value = 50, min = 0, step = 1),
                         numericInput("M_hypergeometric", "
                                     Number of successes \\(M\\):",
                                      value = 15, min = 0, step = 1)
                       ),
                       conditionalPanel(
                         condition = "input.discretas == 'Negative Binomial'",
                         numericInput("r_negativebinomial",
                                      "Number of successes \\(r\\):",
                                      value = 5, min = 1, step = 1 ),
                         numericInput("p_negativebinomial",
                                      "Probability of success \\(p\\):",
                                      value = 0.5, min = 0,
                                      max = 1, step = 0.01 )
                       ),
                    conditionalPanel(
                         condition = "input.discretas == 'Poisson'",
                         numericInput("lambda_poisson",
                                      "Rate \\(\\lambda\\):",
                                      value = 4, min = 1, step = 1)
                       ),
                       conditionalPanel(
                         condition = "input.discretas == 'Binomial'&& input.tipo== 'Values'",
                         radioButtons(
                           inputId = "lower_tail_binomial",
                           label = NULL,
                           choices = c(
                             "Exact value: \\(P(X = x)\\)" = "exact",
                             "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                             "Upper tail : \\(P(X \\geq x)\\)" = "upper.tail",
                             "Interval : \\(P(a \\leq X \\leq b)\\)" = "interval",
                             "Tails : \\(P(X \\leq a )+ P(X \\geq b)\\)" = "tails"

                           )
                         )
                       ),
                    conditionalPanel(
                      condition = "input.discretas == 'Binomial'&& input.tipo == 'Probabilities'",
                      numericInput(inputId = "probB", label = "Probability of interest:",
                                   value = 0.5, step = 0.01),
                      radioButtons(
                        inputId = "lower_tail_binomialP",
                        label = "Type of desired outcome",
                        choices = c(
                          #"Exact value: \\(P(X = x)\\)" = "exact",
                          "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                          "Upper tail : \\(P(X \\geq x)\\)" = "upper.tail"
                        )
                      )
                    ),
                       conditionalPanel(
                         condition = "input.discretas == 'Geometric'&& input.tipo== 'Values'",

                         radioButtons(
                           inputId = "lower_tail_geometric",
                           label = NULL,
                           choices = c(
                             "Exact value: \\(P(X = x)\\)" = "exact",
                             "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                             "Upper tail : \\(P(X \\geq x)\\)" = "upper.tail",
                             "Interval : \\(P(a \\leq X \\leq b)\\)" = "interval",
                             "Tails : \\(P(X \\leq a )+ P(X \\geq b)\\)" = "tails"
                           )
                         )
                       ),
                    conditionalPanel(
                      condition = "input.discretas == 'Geometric'&& input.tipo== 'Probabilities'",
                      numericInput(inputId = "probG", label = "Probability of interest:",
                                   value = 0.25, step = 0.01),
                      radioButtons(
                        inputId = "lower_tail_geometricP",
                        label = "Type of desired outcome",
                        choices = c(
                         # "Exact value: \\(P(X = x)\\)" = "exact",
                          "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                          "Upper tail : \\(P(X \\geq x)\\)" = "upper.tail"
                        )
                      )
                    ),







                    conditionalPanel(
                      condition = "input.discretas == 'Hypergeometric'&& input.tipo== 'Probabilities'",
                      numericInput(inputId = "probH", label = "Probability of interest:",
                                   value = 0.15, step = 0.01),
                      radioButtons(
                        inputId = "lower_tail_hyperP",
                        label = "Type of desired outcome",
                        choices = c(
                         # "Exact value: \\(P(X = x)\\)" = "exact",
                          "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                          "Upper tail : \\(P(X \\geq x)\\)" = "upper.tail"
                        )
                      )
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Negative Binomial'&& input.tipo == 'Probabilities'",
                      numericInput(inputId = "probN", label = "Probability of interest:",
                                   value = 0.05, step = 0.01),
                      radioButtons(
                        inputId = "lower_tail_negativeP",
                        label = "Type of desired outcome",
                        choices = c(
                          #"Exact value: \\(P(X = x)\\)" = "exact",
                          "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                          "Upper tail : \\(P(X \\geq x)\\)" = "upper.tail"
                        )
                      )),
                    conditionalPanel(
                      condition = "input.discretas == 'Poisson'&& input.tipo == 'Probabilities'",
                      numericInput(inputId = "probP", label = "Probability of interest:",
                                   value = 0.05, step = 0.01),
                      radioButtons(
                        inputId = "lower_tail_poissonP",
                        label = "Type of desired outcome",
                        choices = c(
                          #"Exact value: \\(P(X = x)\\)" = "exact",
                          "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                          "Upper tail : \\(P(X \\geq x)\\)" = "upper.tail"
                        )
                      )),

                    conditionalPanel(
                         condition = "input.discretas == 'Hypergeometric'&& input.tipo== 'Values'",
                         radioButtons(
                           inputId = "lower_tail_hypergeometric",
                           label = NULL,
                           choices = c(
                             "Exact value: \\(P(X = x)\\)" = "exact",
                             "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                             "Upper tail : \\(P(X \\geq x)\\)" = "upper.tail",
                             "Interval : \\(P(a \\leq X \\leq b)\\)" = "interval",
                             "Tails : \\(P(X \\leq a )+ P(X \\geq b)\\)" = "tails"
                           )
                         )
                       ),
                       conditionalPanel(
                         condition = "input.discretas == 'Negative Binomial'&& input.tipo== 'Values'",
                         radioButtons(
                           inputId = "lower_tail_negativebinomial",
                           label = NULL,
                           choices = c(
                             "Exact value: \\(P(X = x)\\)" = "exact",
                             "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                             "Upper tail : \\(P(X \\geq x)\\)" = "upper.tail",
                             "Interval : \\(P(a \\leq X \\leq b)\\)" = "interval",
                             "Tails : \\(P(X \\leq a )+ P(X \\geq b)\\)" = "tails"
                           )
                         )
                       ),
                    conditionalPanel(
                         condition = "input.discretas == 'Poisson'&& input.tipo== 'Values'",
                         radioButtons(
                           inputId = "lower_tail_poisson",
                           label = NULL,
                           choices = c(
                             "Exact value: \\(P(X = x)\\)" = "exact",
                             "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                             "Upper tail : \\(P(X \\geq x)\\)" = "upper.tail",
                             "Interval : \\(P(a \\leq X \\leq b)\\)" = "interval",
                             "Tails : \\(P(X \\leq a )+ P(X \\geq b)\\)" = "tails"
                           )
                         )
                       ),
                      conditionalPanel(
                        condition = "input.discretas == 'Binomial' && input.lower_tail_binomial == 'exact'&& input.tipo== 'Values'",
                        numericInput("x_binomial", "x:",
                                     value = 9, min = 1, step = 1
                        )
                      ),
                       conditionalPanel(
                         condition = "input.discretas == 'Binomial' && input.lower_tail_binomial == 'lower.tail'&& input.tipo== 'Values'",
                         numericInput("x1_binomial", "x:",
                                      value = 8, min = 0, step = 1
                         )
                       ),
                       conditionalPanel(
                         condition = "input.discretas == 'Binomial' && input.lower_tail_binomial == 'upper.tail'&& input.tipo== 'Values'",
                         numericInput("x2_binomial", "x:",
                                      value = 8, min = 0, step = 1
                         )
                       ),
                       conditionalPanel(
                         condition = "input.discretas == 'Binomial' && input.lower_tail_binomial == 'interval'&& input.tipo== 'Values'",
                         numericInput("a_binomial", "a:",
                                      value = 8, min = 0, step = 1
                         ),
                         numericInput("b_binomial", "b: \\( (a \\leq b) \\)",
                                      value = 12, min = 0, step = 1
                         )
                       ),
                      conditionalPanel(
                        condition = "input.discretas == 'Binomial' && input.lower_tail_binomial == 'tails'&& input.tipo== 'Values'",
                        numericInput("at_binomial", "a:",
                                     value = 5, min = 0, step = 1
                        ),
                        numericInput("bt_binomial", "b: ",
                                     value = 15, min = 0, step = 1
                        )
                      ),
                      conditionalPanel(
                        condition = "input.discretas == 'Geometric' && input.lower_tail_geometric == 'exact'&& input.tipo== 'Values'",
                        helpText("Number of failures before  \\(1^{st}\\) success"),
                        numericInput("x_geometric", "x:",
                                     value = 1, min = 0, step = 1
                        )
                      ),
                       conditionalPanel(
                         condition = "input.discretas == 'Geometric' && input.lower_tail_geometric == 'lower.tail'&& input.tipo== 'Values'",

                         numericInput("x1_geometric", "x:",
                                      value = 5, min = 0, step = 1
                         )
                       ),
                       conditionalPanel(
                         condition = "input.discretas == 'Geometric' && input.lower_tail_geometric == 'upper.tail'&& input.tipo== 'Values'",

                         numericInput("x2_geometric", "x:",
                                      value = 1, min = 0, step = 1
                         )
                       ),
                       conditionalPanel(
                         condition = "input.discretas == 'Geometric' && input.lower_tail_geometric == 'interval'&& input.tipo== 'Values'",

                         numericInput("a_geometric", "a:",
                                      value = 1, min = 0, step = 1
                         ),
                         numericInput("b_geometric", "b: ",
                                      value = 3, min = 0, step = 1
                         )
                       ),
                      conditionalPanel(
                        condition = "input.discretas == 'Geometric' && input.lower_tail_geometric == 'tails'&& input.tipo== 'Values'",

                        numericInput("at_geometric", "a:",
                                     value = 1, min = 0, step = 1
                        ),
                        numericInput("bt_geometric", "b: ",
                                     value = 3, min = 0, step = 1
                        )
                      ),
                      conditionalPanel(
                        condition = "input.discretas == 'Hypergeometric' && input.lower_tail_hypergeometric == 'exact'&& input.tipo== 'Values'",
                        numericInput("x_hypergeometric", "x:",
                                     value = 8, min = 0, step = 1
                        )
                      ),
                       conditionalPanel(
                         condition = "input.discretas == 'Hypergeometric' && input.lower_tail_hypergeometric == 'lower.tail'&& input.tipo== 'Values'",
                         numericInput("x1_hypergeometric", "x:",
                                      value = 8, min = 0, step = 1
                         )
                       ),
                       conditionalPanel(
                         condition = "input.discretas == 'Hypergeometric' && input.lower_tail_hypergeometric == 'upper.tail'&& input.tipo== 'Values'",
                         numericInput("x2_hypergeometric", "x:",
                                      value = 8, min = 0, step = 1
                         )
                       ),
                       conditionalPanel(
                         condition = "input.discretas == 'Hypergeometric' && input.lower_tail_hypergeometric == 'interval'&& input.tipo== 'Values'",
                         numericInput("a_hypergeometric", "a:",
                                      value = 8, min = 0, step = 1
                         ),
                         numericInput("b_hypergeometric", "b: \\( (a \\leq b) \\)",
                                      value = 12, min = 0, step = 1
                         )
                       ),
                      conditionalPanel(
                        condition = "input.discretas == 'Hypergeometric' && input.lower_tail_hypergeometric == 'tails'&& input.tipo== 'Values'",
                        numericInput("at_hypergeometric", "a:",
                                     value = 8, min = 0, step = 1
                        ),
                        numericInput("bt_hypergeometric", "b:",
                                     value = 12, min = 0, step = 1
                        )
                      ),
                      conditionalPanel(
                        condition = "input.discretas == 'Negative Binomial' && input.lower_tail_negativebinomial == 'exact'&& input.tipo== 'Values'",
                        helpText("Número de fallas antes del  \\(r^{th}\\) success"),
                        numericInput("x_negativebinomial", "x:",
                                     value = 2, min = 0, step = 1
                        )
                      ),
                       conditionalPanel(
                         condition = "input.discretas == 'Negative Binomial' && input.lower_tail_negativebinomial == 'lower.tail'&& input.tipo== 'Values'",
                         helpText("Número de fallas antes del  \\(r^{th}\\) success"),
                         numericInput("x1_negativebinomial", "x:",
                                      value = 2, min = 0, step = 1
                         )
                       ),
                       conditionalPanel(
                         condition = "input.discretas == 'Negative Binomial' && input.lower_tail_negativebinomial == 'upper.tail'&& input.tipo== 'Values'",
                         helpText("Number of failures before  \\(r^{th}\\) success"),
                         numericInput("x2_negativebinomial", "x:",
                                      value = 2, min = 0, step = 1
                         )
                       ),
                       conditionalPanel(
                         condition = "input.discretas == 'Negative Binomial' && input.lower_tail_negativebinomial == 'interval'&& input.tipo== 'Values'",
                         helpText("Number of failures before  \\(r^{th}\\) success"),
                         numericInput("a_negativebinomial", "a:",
                                      value = 2, min = 0, step = 1
                         ),
                         numericInput("b_negativebinomial", "b: \\( (a \\leq b) \\)",
                                      value = 4, min = 0, step = 1
                         )
                       ),
                      conditionalPanel(
                        condition = "input.discretas == 'Negative Binomial' && input.lower_tail_negativebinomial == 'tails'&& input.tipo== 'Values'",
                        helpText("Number of failures before  \\(r^{th}\\) success"),
                        numericInput("at_negativebinomial", "a:",
                                     value = 2, min = 0, step = 1
                        ),
                        numericInput("bt_negativebinomial", "b:",
                                     value = 4, min = 0, step = 1
                        )
                      ),
                    conditionalPanel(
                        condition = "input.discretas == 'Poisson' && input.lower_tail_poisson == 'exact'&& input.tipo== 'Values'",
                        numericInput("x_poisson", "x:",
                                     value = 6, min = 0, step = 1
                        )
                      ),
                       conditionalPanel(
                         condition = "input.discretas == 'Poisson' && input.lower_tail_poisson == 'lower.tail'&& input.tipo== 'Values'",
                         numericInput("x1_poisson", "x:",
                                      value = 6, min = 0, step = 1
                         )
                       ),
                       conditionalPanel(
                         condition = "input.discretas == 'Poisson' && input.lower_tail_poisson == 'upper.tail'&& input.tipo== 'Values'",
                         numericInput("x2_poisson", "x:",
                                      value = 6, min = 0, step = 1
                         )
                       ),
                       conditionalPanel(
                         condition = "input.discretas == 'Poisson' && input.lower_tail_poisson == 'interval'&& input.tipo== 'Values'",
                         numericInput("a_poisson", "a:",
                                      value = 6, min = 0, step = 1
                         ),
                         numericInput("b_poisson", "b: \\( (a \\leq b) \\)",
                                      value = 10, min = 0, step = 1
                         )
                       ),
                      conditionalPanel(
                        condition = "input.discretas == 'Poisson' && input.lower_tail_poisson == 'tails'&& input.tipo== 'Values'",
                        numericInput("at_poisson", "a:",
                                     value = 6, min = 0, step = 1
                        ),
                        numericInput("bt_poisson", "b:",
                                     value = 10, min = 0, step = 1
                        )
                      ),
                    actionButton("refresh1" ,"Refresh")
          ),
          mainPanel(height = "100%",
                    tags$b("Distribution details:"),
                    uiOutput("parameters_distribution1"),
                    br(),
                    tags$b("Solution:"),
                    uiOutput("results_distribution2"),
                    fluidRow(
                      column(width = 9,

                    conditionalPanel(
                     condition = "input.discretas == 'Binomial' && input.tipo == 'Probabilities' && input.lower_tail_binomialP == 'upper.tail'",
                     plotOutput("binomialPlot_Probabilities_upper")
                             ),
                    conditionalPanel(
                             condition = "input.discretas == 'Binomial' && input.tipo == 'Probabilities' && input.lower_tail_binomialP == 'lower.tail'",
                             plotOutput("binomialPlot_Probabilities_lower")
                             ),

                    conditionalPanel(
                      condition = "input.discretas == 'Binomial' && input.tipo == 'Values' && input.lower_tail_binomial == 'exact'",
                      plotOutput("binomialPlot_exact")

                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Binomial' && input.lower_tail_binomial == 'lower.tail'",
                      plotOutput("binomialPlot_lower")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Binomial' && input.lower_tail_binomial == 'upper.tail'",
                      plotOutput("binomialPlot_upper")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Binomial' && input.lower_tail_binomial == 'interval'",
                      plotOutput("binomialPlot_interval")
                    ),

                    conditionalPanel(
                      condition = "input.discretas == 'Binomial' && input.lower_tail_binomial == 'tails'",
                      plotOutput("binomialPlot_tails")
                    ),






                    conditionalPanel(
                      condition = "input.discretas == 'Geometric' && input.tipo == 'Probabilities' && input.lower_tail_geometricP=='lower.tail'",
                      plotOutput("geometricPlot_probabilities_lower")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Geometric' && input.tipo == 'Probabilities' && input.lower_tail_geometricP=='upper.tail'",
                      plotOutput("geometricPlot_probabilities_upper")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Geometric' && input.lower_tail_geometric == 'exact'",
                      plotOutput("geometricPlot_exact")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Geometric' && input.lower_tail_geometric == 'lower.tail'",
                      plotOutput("geometricPlot_lower")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Geometric' && input.lower_tail_geometric == 'upper.tail'",
                      plotOutput("geometricPlot_upper")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Geometric' && input.lower_tail_geometric == 'interval'",
                      plotOutput("geometricPlot_interval")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Geometric' && input.lower_tail_geometric == 'tails'",
                      plotOutput("geometricPlot_tails")
                    ),



                    conditionalPanel(
                      condition = "input.discretas == 'Hypergeometric' && input.tipo == 'Probabilities' && input.lower_tail_hyperP=='lower.tail'",
                      plotOutput("hypergeometricPlot_probabilities_lower")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Hypergeometric' && input.tipo == 'Probabilities' && input.lower_tail_hyperP=='upper.tail'",
                      plotOutput("hypergeometricPlot_probabilities_upper")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Hypergeometric' && input.lower_tail_hypergeometric == 'exact'",
                      plotOutput("hypergeometricPlot_exact")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Hypergeometric' && input.lower_tail_hypergeometric == 'lower.tail'",
                      plotOutput("hypergeometricPlot_lower")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Hypergeometric' && input.lower_tail_hypergeometric == 'upper.tail'",
                      plotOutput("hypergeometricPlot_upper")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Hypergeometric' && input.lower_tail_hypergeometric == 'interval'",
                      plotOutput("hypergeometricPlot_interval")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Hypergeometric' && input.lower_tail_hypergeometric == 'tails'",
                      plotOutput("hypergeometricPlot_tails")
                    ),







                    conditionalPanel(
                      condition = "input.discretas == 'Negative Binomial' && input.tipo == 'Probabilities' && input.lower_tail_negativeP == 'lower.tail'",
                      plotOutput("negativebinomialPlot_Probalities_lower")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Negative Binomial' && input.tipo == 'Probabilities' && input.lower_tail_negativeP == 'upper.tail'",
                      plotOutput("negativebinomialPlot_Probabilities_upper")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Negative Binomial' && input.lower_tail_negativebinomial == 'exact'",
                      plotOutput("negativebinomialPlot_exact")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Negative Binomial' && input.lower_tail_negativebinomial == 'lower.tail'",
                      plotOutput("negativebinomialPlot_lower")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Negative Binomial' && input.lower_tail_negativebinomial == 'upper.tail'",
                      plotOutput("negativebinomialPlot_upper")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Negative Binomial' && input.lower_tail_negativebinomial == 'interval'",
                      plotOutput("negativebinomialPlot_interval")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Negative Binomial' && input.lower_tail_negativebinomial == 'tails'",
                      plotOutput("negativebinomialPlot_tails")
                    ),


                    conditionalPanel(
                      condition = "input.discretas == 'Poisson'  && input.tipo == 'Probabilities' && input.lower_tail_poissonP == 'lower.tail'",
                      plotOutput("poissonPlot_Probabilities_lower")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Poisson'   && input.tipo == 'Probabilities' && input.lower_tail_poissonP == 'upper.tail'",
                      plotOutput("poissonPlot_Probabilities_upper")
                    ),

                    conditionalPanel(
                      condition = "input.discretas == 'Poisson' && input.lower_tail_poisson == 'exact'",
                      plotOutput("poissonPlot_exact")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Poisson' && input.lower_tail_poisson == 'lower.tail'",
                      plotOutput("poissonPlot_lower")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Poisson' && input.lower_tail_poisson == 'upper.tail'",
                      plotOutput("poissonPlot_upper")
                    ),
                    conditionalPanel(
                      condition = "input.discretas == 'Poisson' && input.lower_tail_poisson == 'interval'",
                      plotOutput("poissonPlot_interval"),
                      ),
                    conditionalPanel(
                      condition = "input.discretas == 'Poisson' && input.lower_tail_poisson == 'tails'",
                      plotOutput("poissonPlot_tails"),
                    )
                    ), column(width = 3, DT::DTOutput("table_discrete")),
                    ),
                    shinyjs::useShinyjs(),
                    downloadButton('downloadPlot', 'Download Plot'),
                    br()
                    #fluidRow(
                     # column(width = 9,
                                   # conditionalPanel(
                                     # condition = "input.discretas == 'Binomial' && input.lower_tail_binomial == 'lower.tail'",
                                     # plotOutput("binomialPlot_loweracum")
                                    # ),
                             #conditionalPanel(
                              # condition = "input.discretas == 'Binomial' && input.lower_tail_binomial == 'upper.tail'"#,
                               # plotOutput("binomialPlot_upperacum")
                            # ),
                             #conditionalPanel(
                              # condition = "input.discretas == 'Geometric' && input.lower_tail_geometric == 'lower.tail'",
                              # plotOutput("geometricPlot_loweracum"))
                          #  )#,
                      #column(width = 3,DT::DTOutput("table_discrete_acum"))

                   # )



          ) #finmainpanel
      )

    )

tabular_summary <- tabPanel("Tabular summary",
                    br(),
                    conditionalPanel(condition = "input.GrupoQuali == 0",
                      strong(h2("Frequency table")),
                      br(),
                      DT::DTOutput("TfreqQuali")
                    ),
                    conditionalPanel(condition = "input.GrupoQuali == 1",
                      strong(h2("Two-way table")),
                      br(),
                      DT::DTOutput("TwofreqQuali") 
                  )
)

# sidebar.R

sidebar <- dashboardSidebar(
  width = 280, 
  sidebarMenu(
    menuItem("About StatisticTeach1", tabName = "tab0"),
    menuItem("Descriptive statistics", tabName = "tab3", icon = icon("chart-bar"),
             menuItem("Load data", tabName = "Load_data", icon = icon("file-import")),
             menuSubItem("Continuous variables (univariate)", tabName = "Continuous_variables_univariate"),
             menuSubItem("Continuous variables (bivariate)", tabName = "Continuous_variables_bivariate"),
             menuSubItem("Qualitative variables", tabName = "Qualitative_variables"),
             menuSubItem("Multivariate", tabName = "Multivariate")
    ),
    menuItem("Probability distributions", tabName = "tab1", icon = icon("dice"),
             menuSubItem("Discrete", tabName = "Discrete", icon = icon("chart-bar")),
             menuSubItem("Continuous", tabName = "Continuous", icon = tags$img(src = "normal1.png", width = "35px"))
    )
  )
)

# =============================================================================
# Continuous Variables Univariate Analysis - Main Module
# =============================================================================
# This file serves as the main entry point for the continuous variables 
# univariate analysis module. It sources the individual tab components
# and assembles them into the complete UI.
# =============================================================================

# =============================================================================
# SOURCE INDIVIDUAL TAB COMPONENTS
# =============================================================================

# Load numerical summary tab component
source("pages/univariate_numerical_summary.R", local = TRUE)

# Load tabular summary tab component  
source("pages/univariate_tabular_summary.R", local = TRUE)

# Load graphical summary tab component
source("pages/univariate_graphical_summary.R", local = TRUE)

# =============================================================================
# MAIN UI COMPONENT
# =============================================================================

continuous_variables_univariate <- shinydashboard::tabItem(
  tabName = "Continuous_variables_univariate",
  
  # Main container box
  shinydashboard::box(
    height = "100%",
    width = 12,
    title = "Descriptive Statistics for Continuous Variables",
    status = "primary",
    solidHeader = TRUE,
    collapsible = TRUE,
    
    # =====================================================================
    # SIDEBAR PANEL - Controls and Options
    # =====================================================================
    sidebarPanel(
      
      # Help button and modal
      shinyWidgets::actionBttn(
        "helpuni",
        "Help",
        icon = icon("question-circle"),
        style = "stretch",
        block = FALSE,
        color = "primary"
      ),
      
      # Help modal with documentation
      shinyBS::bsModal(
        id = "modalHelpUni",
        title = "Help: Continuous Variables (Univariate)",
        trigger = "helpuni",
        size = "large",
        tags$iframe(
          src = "continuous_variables_univariate.html", 
          width = "100%", 
          height = "600px", 
          frameborder = 0
        )
      ),
      
      # Variable selection
      selectizeInput(
        'selvarcuanti',
        'Select Quantitative Variable',
        choices = NULL,
        multiple = FALSE
      ),
      
      # Group analysis option
      shinyWidgets::prettyCheckbox(
        inputId = "Grupo",
        label = "Statistics by group?",
        value = FALSE,
        status = "success"
      ),
      
      # Group variable selection (conditional)
      conditionalPanel(
        condition = "input.Grupo == 1",
        selectizeInput(
          'selgrupo',
          'Group by (max 2 variables)',
          choices = NULL,
          multiple = TRUE,
          options = list(maxItems = 2)
        )
      )
    ),
    
    # =====================================================================
    # MAIN PANEL - Content Tabs
    # =====================================================================
    mainPanel(
      
      # Tab navigation
      tabsetPanel(
        type = "tabs",
        
        # Numerical summary tab
        numerical_summary,
        
        # Tabular summary tab
        tabular_summary,
        
        # Graphical summary tab
        graphical_summary
      )
    )
  )
)

appDir <- system.file("StatisticTeach1App", package = "StatisticTeach1")

################################# Header #######################################
source(file.path(appDir, "R/header.R"))
#####################################Header Fin ################################
#######################################Sidebar #################################
source(file.path(appDir, "R/sidebar.R"))
source(file.path(appDir, "pages/tab0_about.R"), local = TRUE)
source(file.path(appDir, "pages/prob_dist/discrete_probability_distributions.R"), local = TRUE)
source(file.path(appDir, "pages/prob_dist/continuous_probability_distributions.r"), local = TRUE)
source(file.path(appDir, "pages/descriptive_statistics/load_data.r"), local=TRUE)
source(file.path(appDir, "pages/descriptive_statistics/cont_univ/main.r"),local=TRUE)
source(file.path(appDir, "pages/descriptive_statistics/qual_vars/main.r"), local = TRUE)
source(file.path(appDir, "pages/descriptive_statistics/cont_biv/main.r"), local = TRUE)
source(file.path(appDir, "pages/descriptive_statistics/multivariate.r"), local = TRUE)
##############<#######################Sidebar Fin ###############################
####################################Body #######################################
body <- shinydashboard::dashboardBody(
  height = "auto",
  width = "100p%",
 tags$head(
  tags$style(HTML(
  '/* logo when hovered */
  .skin-blue .main-header .logo:hover {
  background-color: #3991e3;}
  /* navbar (rest of the header) */
  .skin-blue .main-header .navbar {
  background-color: #3991e3;}
  /* main sidebar */
  .skin-blue .main-sidebar {
  background-color: #3991e3;}
  /* active selected tab in the sidebarmenu */
  .skin-blue .main-sidebar .sidebar .sidebar-menu .active a{
  background-color: #0091ff;}
  /* other links in the sidebarmenu */
  .skin-blue .main-sidebar .sidebar .sidebar-menu a{
  background-color: #ccdceb;
  color: #000000;}
  /* other links in the sidebarmenu when hovered */
  .skin-blue .main-sidebar .sidebar .sidebar-menu a:hover{
  background-color: #69c3ff;}
  /* toggle button when hovered  */
  .skin-blue .main-header .navbar .sidebar-toggle:hover{
  background-color: #9bc2e8;}
  /* body */
  .content-wrapper, .right-side {
  background-color: #7da2d1;}')
  )
  ),
 shinydashboard::tabItems(
  tab0_about,
  discrete_probability_distributions,
  continuous_probability_distribution,
   load_dataPage,
  continuous_variables_univariate,
  qualitative_variables,
  continuous_variables_bivariate,
  multivariate
  )#fintabItems
)
####################################Body Fin #################################
shinydashboard::dashboardPage(header, sidebar, body)

continuous_probability_distribution <- shinydashboard::tabItem(
     tabName = "Continuous",
     shinydashboard::box(width = "100%",
                height = "100%",
                title = "Continuous probability distributions",
                status = "primary",
                solidHeader = TRUE,
                collapsible = TRUE,
                sidebarPanel(helpText(h5("Continuous probability distributions")
                ),
                shinyWidgets::actionBttn("helpcontinuas",
                                         "",
                                         icon = icon("question-circle"),
                                         style = "stretch",
                                         block = FALSE,
                                         color = "primary"
                ),
                shinyBS::bsModal(id="dataset",
                                 title = "",
                                 trigger = "helpcontinuas",
                                 size="large",
                                 tags$iframe(
                                   src = "continuas.html",
                                   width = "100%",
                                  height = "100%",
                                   frameborder = 0,
                                   scrolling = "auto"
                                 ),

                                 # CSS para personalizar el tamaño del modal
                                 tags$style(HTML("
    #dataset .modal-dialog {
      width: 95%;  /* Adjusts the modal's width to 95% of the screen */
      height: 90%; /* Adjusts the modal's height to 90% of the screen */
      max-width: none; /* Removes the default max-width constraint */
    }
    #dataset .modal-content {
      height: 100%; /* Ensures that the content fills the modal */
      overflow: auto; /* Adds scrolling if the content exceeds the modal's height */
    }
    #dataset .modal-body {
      height: calc(100vh - 200px); /* Ensures the body takes full height with proper spacing */
      overflow-y: auto; /* Allows the body content to be scrollable */
    }
  "))
                ),
                shinyWidgets::pickerInput(
                  inputId = "continuas",
                  label = "Distribution",
                  choices = c("Select distribution",
                              "Normal",
                              "t-Student",
                              "Chi^2",
                              "F-Fisher",
                              "Exponential",
                              "Logistics",
                              "Log-Normal",
                              "Gamma",
                              "Weibull",
                              "Beta"),
                  options = list(
                    style = "btn-primary")
                ),
                conditionalPanel(
                  condition = "input.continuas != 'Select distribution'",
                  radioButtons(
                    inputId = "tipoC",
                    label = NULL,
                    inline = TRUE,
                    choices = c("Values", "Probabilities"))
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Normal'",
                  numericInput("mean_normal", "mean \\(\\mu\\):",
                               value = 0, step = 1
                  ),
                  radioButtons(
                    inputId = "variance_sd",
                    label = NULL,
                    choices = c(
                      "Variance \\(\\sigma^2\\)" = "variance_true",
                      "Standard deviation \\(\\sigma\\)" = "variance_false"
                    )
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Normal' && input.variance_sd == 'variance_true'",
                  numericInput("variance_normal", "Variance \\(\\sigma^2\\):",
                               value = 1, min = 0, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Normal' && input.variance_sd == 'variance_false'",
                  numericInput("sd_normal", "Standard deviation \\(\\sigma\\):",
                               value = 1, min = 0, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Normal'&& input.tipoC== 'Values'",
                  radioButtons(
                    inputId = "lower_tail_normal",
                    label = NULL,
                    choices = c(
                      "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                      "Upper tail : \\(P(X > x)\\)" = "upper.tail",
                      "Interval : \\(P(a \\leq X \\leq b)\\)" = "interval",
                      "Tails : \\(P(X \\leq a )+ P(X \\geq b)\\)" = "tails"
                    )
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Normal' && input.lower_tail_normal == 'lower.tail'&& input.tipoC == 'Values'",
                  numericInput("x1_normal", "x:",
                               value = 1, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Normal' && input.lower_tail_normal == 'upper.tail'&& input.tipoC == 'Values'",
                  numericInput("x2_normal", "x:",
                               value = 1, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Normal' && input.lower_tail_normal == 'interval'&& input.tipoC == 'Values'",
                  numericInput("a_normal", "a:",
                               value = -1, step = 1
                  ),
                  numericInput("b_normal", "b: \\( (a \\leq b) \\)",
                               value = 1, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Normal' && input.lower_tail_normal == 'tails'&& input.tipoC == 'Values'",
                  numericInput("at_normal", "a:",
                               value = -1, step = 1
                  ),
                  numericInput("bt_normal", "b:",
                               value = 1, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 't-Student'",
                  numericInput("df_student", "Degrees of freedom \\(gl\\):",
                               value = 10, min = 1, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 't-Student'&& input.tipoC== 'Values'",
                  radioButtons(
                    inputId = "lower_tail_student",
                    label = NULL,
                    choices = c(
                      "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                      "Upper tail : \\(P(X > x)\\)" = "upper.tail",
                      "Interval : \\(P(a \\leq X \\leq b)\\)" = "interval",
                      "Tails : \\(P(X \\leq a )+ P(X \\geq b)\\)" = "tails"
                    )
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Beta'",
                  numericInput("alpha_beta", "Shape \\(\\alpha\\):",
                               value = 1,
                               min = 0,
                               step = 1
                  ),
                  numericInput("beta_beta", "Shape \\(\\beta\\):",
                               value = 3,
                               min = 0,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Beta'&& input.tipoC== 'Values'",
                  radioButtons(
                    inputId = "lower_tail_beta",
                    label = NULL,
                    choices = c(
                      "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                      "Upper tail : \\(P(X > x)\\)" = "upper.tail",
                      "Interval : \\(P(a \\leq X \\leq b)\\)" = "interval",
                      "Tails : \\(P(X \\leq a )+ P(X \\geq b)\\)" = "tails"
                    )
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Chi^2'",
                  numericInput("df_chisquare", "Degrees of freedom \\(gl\\):",
                               value = 6,
                               min = 1,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Chi^2'&& input.tipoC== 'Values'",
                  radioButtons(
                    inputId = "lower_tail_chisquare",
                    label = NULL,
                    choices = c(
                      "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                      "Upper tail : \\(P(X > x)\\)" = "upper.tail",
                      "Interval : \\(P(a \\leq X \\leq b)\\)" = "interval",
                      "Tails : \\(P(X \\leq a )+ P(X \\geq b)\\)" = "tails"
                    )
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Exponential'",
                  numericInput("rate_exponential", "Rate \\(\\lambda\\):",
                               value = 1,
                               min = 0,
                               step = 0.5
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Exponential'&& input.tipoC== 'Values'",
                  radioButtons(
                    inputId = "lower_tail_exponential",
                    label = NULL,
                    choices = c(
                      "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                      "Upper tail : \\(P(X > x)\\)" = "upper.tail",
                      "Interval : \\(P(a \\leq X \\leq b)\\)" = "interval",
                      "Tails : \\(P(X \\leq a )+ P(X \\geq b)\\)" = "tails"
                    )
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'F-Fisher'",
                  numericInput("df1_fisher", "Degrees of freedom \\(gl_1\\):",
                               value = 10,
                               min = 1,
                               step = 1
                  ),
                  numericInput("df2_fisher", "Degrees of freedom \\(gl_2\\):",
                               value = 5,
                               min = 1,
                               step = 1
                  )
                ),

                conditionalPanel(
                  condition = "input.continuas == 'F-Fisher'&& input.tipoC== 'Values'",
                  radioButtons(
                    inputId = "lower_tail_fisher",
                    label = NULL,
                    choices = c(
                      "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                      "Upper tail : \\(P(X > x)\\)" = "upper.tail",
                      "Interval : \\(P(a \\leq X \\leq b)\\)" = "interval",
                      "Tails : \\(P(X \\leq a )+ P(X \\geq b)\\)" = "tails"
                    )
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Gamma'",
                  numericInput("alpha_gamma", "Shape \\(\\alpha\\):",
                               value = 3,
                               min = 0,
                               step = 1
                  ),
                  numericInput("beta_gamma", "Rate \\(\\beta\\):",
                               value = 2,
                               min = 0,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Gamma'&& input.tipoC== 'Values'",
                  radioButtons(
                    inputId = "lower_tail_gamma",
                    label = NULL,
                    choices = c(
                      "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                      "Upper tail : \\(P(X > x)\\)" = "upper.tail",
                      "Interval : \\(P(a \\leq X \\leq b)\\)" = "interval",
                      "Tails : \\(P(X \\leq a )+ P(X \\geq b)\\)" = "tails"
                    )
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Logistics'",
                  numericInput("location_logistic", "Location \\(\\mu\\):",
                               value = 0,
                               step = 1
                  ),
                  numericInput("scale_logistic", "Scale \\(s\\):",
                               value = 1,
                               min = 0,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Logistics'&& input.tipoC== 'Values'",
                  radioButtons(
                    inputId = "lower_tail_logistic",
                    label = NULL,
                    choices = c(
                      "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                      "Upper tail : \\(P(X > x)\\)" = "upper.tail",
                      "Interval : \\(P(a \\leq X \\leq b)\\)" = "interval",
                      "Tails : \\(P(X \\leq a )+ P(X \\geq b)\\)" = "tails"
                    )
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Log-Normal'",
                  numericInput("mean_lognormal",
                               "Mean \\(\\mu\\):",
                               value = 0,
                               step = 1
                  ),
                  radioButtons(
                    inputId = "variance_sd_lognormal",
                    label = NULL,
                    choices = c(
                      "Variance \\(\\sigma^2\\)" = "variance_true",
                      "Standard deviation \\(\\sigma\\)" = "variance_false"
                    )
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Log-Normal' && input.variance_sd_lognormal == 'variance_true'",
                  numericInput("variance_lognormal", "Variance \\(\\sigma^2\\):",
                               value = 1,
                               min = 0,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Log-Normal' && input.variance_sd_lognormal == 'variance_false'",
                  numericInput("sd_lognormal", "Standard deviation \\(\\sigma\\):",
                               value = 1,
                               min = 0,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Log-Normal'&& input.tipoC== 'Values'",
                  radioButtons(
                    inputId = "lower_tail_lognormal",
                    label = NULL,
                    choices = c(
                      "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                      "Upper tail : \\(P(X > x)\\)" = "upper.tail",
                      "Interval : \\(P(a \\leq X \\leq b)\\)" = "interval",
                      "Tails : \\(P(X \\leq a )+ P(X \\geq b)\\)" = "tails"
                    )
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Weibull'",
                  numericInput("alpha_weibull", "Shape \\(\\alpha\\):",
                               value = 5,
                               min = 0,
                               step = 1
                  ),
                  numericInput("beta_weibull", "Scale \\(\\beta\\):",
                               value = 1,
                               min = 0,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Weibull'&& input.tipoC== 'Values'",
                  radioButtons(
                    inputId = "lower_tail_weibull",
                    label = NULL,
                    choices = c(
                      "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                      "Upper tail : \\(P(X > x)\\)" = "upper.tail",
                      "Interval : \\(P(a \\leq X \\leq b)\\)" = "interval",
                      "Tails : \\(P(X \\leq a )+ P(X \\geq b)\\)" = "tails"
                    )
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 't-Student' && input.lower_tail_student == 'lower.tail'&& input.tipoC == 'Values'",
                  numericInput("x1_student", "x:",
                               value = 1,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 't-Student' && input.lower_tail_student == 'upper.tail'&& input.tipoC == 'Values'",
                  numericInput("x2_student", "x:",
                               value = 1,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 't-Student' && input.lower_tail_student == 'interval'&& input.tipoC == 'Values'",
                  numericInput("a_student", "a:",
                               value = -1,
                               step = 1
                  ),
                  numericInput("b_student", "b: \\( (a \\leq b) \\)",
                               value = 1,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 't-Student' && input.lower_tail_student == 'tails'&& input.tipoC == 'Values'",
                  numericInput("at_student", "a:",
                               value = -1,
                               step = 1
                  ),
                  numericInput("bt_student", "b: \\( (a \\leq b) \\)",
                               value = 1,
                               step = 1
                  )
                ),

                conditionalPanel(
                  condition = "input.continuas == 'Chi^2' && input.lower_tail_chisquare == 'lower.tail'&& input.tipoC == 'Values'",
                  numericInput("x1_chisquare", "x:",
                               value = 9.6,
                               min = 0, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Chi^2' && input.lower_tail_chisquare == 'upper.tail'&& input.tipoC == 'Values'",
                  numericInput("x2_chisquare", "x:",
                               value = 9.6,
                               min = 0,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Chi^2' && input.lower_tail_chisquare == 'interval'&& input.tipoC == 'Values'",
                  numericInput("a_chisquare", "a:",
                               value = 9.6,
                               min = 0,
                               step = 1
                  ),
                  numericInput("b_chisquare", "b: \\( (a \\leq b) \\)",
                               value = 14.4,
                               min = 0,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Chi^2' && input.lower_tail_chisquare == 'tails'&& input.tipoC == 'Values'",
                  numericInput("at_chisquare", "a:",
                               value = 9.6,
                               min = 0,
                               step = 1
                  ),
                  numericInput("bt_chisquare", "b: \\( (a \\leq b) \\)",
                               value = 14.4,
                               min = 0,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Beta' && input.lower_tail_beta == 'lower.tail'&& input.tipoC == 'Values'",
                  numericInput("x1_beta", "x:",
                               value = 0.45,
                               min = 0,
                               max = 1,
                               step = 0.01
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Beta' && input.lower_tail_beta == 'upper.tail'&& input.tipoC == 'Values'",
                  numericInput("x2_beta", "x:",
                               value = 0.45,
                               min = 0,
                               max = 1,
                               step = 0.01
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Beta' && input.lower_tail_beta == 'interval'&& input.tipoC == 'Values'",
                  numericInput("a_beta", "a:",
                               value = 0.25,
                               min = 0,
                               max = 1,
                               step = 0.01
                  ),
                  numericInput("b_beta", "b: \\( (a \\leq b) \\)",
                               value = 0.45,
                               min = 0,
                               max = 1,
                               step = 0.01
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Beta' && input.lower_tail_beta == 'tails'&& input.tipoC == 'Values'",
                  numericInput("at_beta", "a:",
                               value = 0.25,
                               min = 0,
                               max = 1,
                               step = 0.01
                  ),
                  numericInput("bt_beta", "b: \\( (a \\leq b) \\)",
                               value = 0.45,
                               min = 0,
                               max = 1,
                               step = 0.01
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Exponential' && input.lower_tail_exponential == 'lower.tail'&& input.tipoC == 'Values'",
                  numericInput("x1_exponential", "x:",
                               value = 2.24,
                               min = 0,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Exponential' && input.lower_tail_exponential == 'upper.tail'&& input.tipoC == 'Values'",
                  numericInput("x2_exponential", "x:",
                               value = 2.24,
                               min = 0,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Exponential' && input.lower_tail_exponential == 'interval'&& input.tipoC == 'Values'",
                  numericInput("a_exponential", "a:",
                               value = 2.24,
                               min = 0,
                               step = 1
                  ),
                  numericInput("b_exponential", "b: \\( (a \\leq b) \\)",
                               value = 3.36,
                               min = 0,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Exponential' && input.lower_tail_exponential == 'tails'&& input.tipoC == 'Values'",
                  numericInput("at_exponential", "a:",
                               value = 2.24,
                               min = 0,
                               step = 1
                  ),
                  numericInput("bt_exponential", "b: \\( (a \\leq b) \\)",
                               value = 3.36,
                               min = 0,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'F-Fisher' && input.lower_tail_fisher == 'lower.tail'&& input.tipoC == 'Values'",
                  numericInput("x1_fisher", "x:",
                               value = 4.14,
                               min = 0,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'F-Fisher' && input.lower_tail_fisher == 'upper.tail'&& input.tipoC == 'Values'",
                  numericInput("x2_fisher", "x:",
                               value = 4.14,
                               min = 0,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'F-Fisher' && input.lower_tail_fisher == 'interval'&& input.tipoC == 'Values'",
                  numericInput("a_fisher", "a:",
                               value = 2.76,
                               min = 0,
                               step = 1
                  ),
                  numericInput("b_fisher", "b: \\( (a \\leq b) \\)",
                               value = 4.14,
                               min = 0,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'F-Fisher' && input.lower_tail_fisher == 'tails'&& input.tipoC == 'Values'",
                  numericInput("at_fisher", "a:",
                               value = 2.76,
                               min = 0,
                               step = 1
                  ),
                  numericInput("bt_fisher", "b: \\( (a \\leq b) \\)",
                               value = 4.14,
                               min = 0,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Gamma' && input.lower_tail_gamma == 'lower.tail'&& input.tipoC == 'Values'",
                  numericInput("x1_gamma", "x:",
                               value = 2.4, min = 0, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Gamma' && input.lower_tail_gamma == 'upper.tail'&& input.tipoC == 'Values'",
                  numericInput("x2_gamma", "x:",
                               value = 2.4, min = 0, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Gamma' && input.lower_tail_gamma == 'interval'&& input.tipoC == 'Values'",
                  numericInput("a_gamma", "a:",
                               value = 0.8, min = 0, step = 1
                  ),
                  numericInput("b_gamma", "b: \\( (a \\leq b) \\)",
                               value = 2.4, min = 0, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Gamma' && input.lower_tail_gamma == 'tails'&& input.tipoC == 'Values'",
                  numericInput("at_gamma", "a:",
                               value = 0.8, min = 0, step = 1
                  ),
                  numericInput("bt_gamma", "b: \\( (a \\leq b) \\)",
                               value = 2.4, min = 0, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Logistics' && input.lower_tail_logistic == 'lower.tail'&& input.tipoC == 'Values'",
                  numericInput("x1_logistic", "x:",
                               value = 1.2, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Logistics' && input.lower_tail_logistic == 'upper.tail'&& input.tipoC == 'Values'",
                  numericInput("x2_logistic", "x:",
                               value = 1.2, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Logistics' && input.lower_tail_logistic == 'interval'&& input.tipoC == 'Values'",
                  numericInput("a_logistic", "a:",
                               value = -1.2, step = 1
                  ),
                  numericInput("b_logistic", "b: \\( (a \\leq b) \\)",
                               value = 1.2, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Logistics' && input.lower_tail_logistic == 'tails'&& input.tipoC == 'Values'",
                  numericInput("at_logistic", "a:",
                               value = -1.2, step = 1
                  ),
                  numericInput("bt_logistic", "b: \\( (a \\leq b) \\)",
                               value = 1.2, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Log-Normal' && input.lower_tail_lognormal == 'lower.tail'&& input.tipoC == 'Values'",
                  numericInput("x1_lognormal", "x:",
                               value = 1, min = 0, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Log-Normal' && input.lower_tail_lognormal == 'upper.tail'&& input.tipoC == 'Values'",
                  numericInput("x2_lognormal", "x:",
                               value = 1, min = 0, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Log-Normal' && input.lower_tail_lognormal == 'interval'&& input.tipoC == 'Values'",
                  numericInput("a_lognormal", "a:",
                               value = 1, min = 0, step = 1
                  ),
                  numericInput("b_lognormal", "b: \\( (a \\leq b) \\)",
                               value = 2, min = 0, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Log-Normal' && input.lower_tail_lognormal == 'tails'&& input.tipoC == 'Values'",
                  numericInput("at_lognormal", "a:",
                               value = 1, min = 0, step = 1
                  ),
                  numericInput("bt_lognormal", "b: \\( (a \\leq b) \\)",
                               value = 2, min = 0, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Weibull' && input.lower_tail_weibull == 'lower.tail'&& input.tipoC == 'Values'",
                  numericInput("x1_weibull", "x:",
                               value = 0.8, min = 0, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Weibull' && input.lower_tail_weibull == 'upper.tail'&& input.tipoC == 'Values'",
                  numericInput("x2_weibull", "x:",
                               value = 0.8, min = 0, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Weibull' && input.lower_tail_weibull == 'interval'&& input.tipoC == 'Values'",
                  numericInput("a_weibull", "a:",
                               value = 0.8, min = 0, step = 1
                  ),
                  numericInput("b_weibull", "b: \\( (a \\leq b) \\)",
                               value = 1.2, min = 0, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Weibull' && input.lower_tail_weibull == 'tails'&& input.tipoC == 'Values'",
                  numericInput("at_weibull", "a:",
                               value = 0.8, min = 0, step = 1
                  ),
                  numericInput("bt_weibull", "b: \\( (a \\leq b) \\)",
                               value = 1.2, min = 0, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas != 'Select distribution'&& input.tipoC == 'Probabilities'",
                  numericInput(inputId = "probC", label = "Probability of interest:",
                               value = 0.05, step = 0.001),
                  radioButtons(
                    inputId = "Continuasx",
                    label = "Type of desired outcome",
                    choices = c(
                      #"Exact value: \\(P(X = x)\\)" = "exact",
                      "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                      "Upper tail : \\(P(X \\geq x)\\)" = "upper.tail"
                    )
                  )
                ), br(),
                actionButton("refresh2" ,"Refresh")

                ),
                mainPanel(
                  tags$b("Distribution Details:"),
                  br(),
                  uiOutput("parameters_distribution"),
                  tags$b("Solution:"),
                  uiOutput("results_distribution"),
                  br(),

                  conditionalPanel(

                    condition = "input.continuas == 'Normal' && input.lower_tail_normal == 'lower.tail' && input.tipoC== 'Values'",
                    plotOutput("normalPlot_lower")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Normal' && input.lower_tail_normal == 'upper.tail' && input.tipoC== 'Values'",
                    plotOutput("normalPlot_upper")),
                  conditionalPanel(
                    condition = "input.continuas == 'Normal' && input.Continuasx  == 'lower.tail' && input.tipoC == 'Probabilities'",
                    plotOutput("normalPlot_lower_Probabilities")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Normal' && input.Continuasx == 'upper.tail' && input.tipoC == 'Probabilities'",
                    plotOutput("normalPlot_upper_Probabilities")),

                  conditionalPanel(
                    condition = "input.continuas == 'Normal' && input.lower_tail_normal == 'interval' && input.tipoC== 'Values'",
                    plotOutput("normalPlot_interval")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Normal' && input.lower_tail_normal == 'tails' && input.tipoC== 'Values'",
                    plotOutput("normalPlot_tails")
                  ),


                  conditionalPanel(
                    condition = "input.continuas == 't-Student' && input.lower_tail_student == 'lower.tail' && input.tipoC== 'Values'",
                    plotOutput("studentPlot_lower")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 't-Student' && input.lower_tail_student == 'upper.tail' && input.tipoC== 'Values'",
                    plotOutput("studentPlot_upper")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 't-Student' && input.Continuasx == 'lower.tail' && input.tipoC== 'Probabilities'",
                    plotOutput("studentPlot_lower_Probabilities")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 't-Student' && input.Continuasx == 'upper.tail' && input.tipoC== 'Probabilities'",
                    plotOutput("studentPlot_upper_Probabilities")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 't-Student' && input.lower_tail_student == 'interval' && input.tipoC== 'Values'",
                    plotOutput("studentPlot_interval")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 't-Student' && input.lower_tail_student == 'tails' && input.tipoC== 'Values'",
                    plotOutput("studentPlot_tails")
                  ),






                  conditionalPanel(
                    condition = "input.continuas == 'Beta' && input.lower_tail_beta == 'lower.tail' && input.tipoC== 'Values'",
                    plotOutput("betaPlot_lower")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Beta' && input.lower_tail_beta == 'upper.tail' && input.tipoC== 'Values'",
                    plotOutput("betaPlot_upper")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Beta' && input.Continuasx == 'lower.tail' && input.tipoC== 'Probabilities'",
                    plotOutput("betaPlot_lower_Probabilities")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Beta' && input.Continuasx == 'upper.tail' && input.tipoC== 'Probabilities'",
                    plotOutput("betaPlot_upper_Probabilities")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Beta' && input.lower_tail_beta == 'interval' && input.tipoC== 'Values'",
                    plotOutput("betaPlot_interval")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Beta' && input.lower_tail_beta == 'tails'&& input.tipoC== 'Values'",
                    plotOutput("betaPlot_tails")
                  ),



                  #### chi cuadrada continua

                  conditionalPanel(
                    condition = "input.continuas == 'Chi^2' && input.lower_tail_chisquare == 'lower.tail' && input.tipoC== 'Values'",
                    plotOutput("chisquarePlot_lower")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Chi^2' && input.lower_tail_chisquare == 'upper.tail' && input.tipoC== 'Values'",
                    plotOutput("chisquarePlot_upper")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Chi^2' && input.Continuasx == 'lower.tail' && input.tipoC== 'Probabilities'",
                    plotOutput("chisquarePlot_lower_Probabilities")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Chi^2' && input.Continuasx == 'upper.tail' && input.tipoC== 'Probabilities'",
                    plotOutput("chisquarePlot_upper_Probabilities")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Chi^2' && input.lower_tail_chisquare == 'interval' && input.tipoC== 'Values'",
                    plotOutput("chisquarePlot_interval")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Chi^2' && input.lower_tail_chisquare == 'tails' && input.tipoC== 'Values'",
                    plotOutput("chisquarePlot_tails")
                  ),



                  conditionalPanel(
                    condition = "input.continuas == 'Exponential' && input.lower_tail_exponential == 'lower.tail' && input.tipoC== 'Values'",
                    plotOutput("exponentialPlot_lower")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Exponential' && input.lower_tail_exponential == 'upper.tail' && input.tipoC== 'Values'",
                    plotOutput("exponentialPlot_upper")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Exponential' && input.Continuasx == 'lower.tail' && input.tipoC== 'Probabilities'",
                    plotOutput("exponentialPlot_lower_Probabilities")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Exponential' && input.Continuasx == 'upper.tail' && input.tipoC== 'Probabilities'",
                    plotOutput("exponentialPlot_upper_Probabilities")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Exponential' && input.lower_tail_exponential == 'interval' && input.tipoC== 'Values'",
                    plotOutput("exponentialPlot_interval")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Exponential' && input.lower_tail_exponential == 'tails' && input.tipoC== 'Values'",
                    plotOutput("exponentialPlot_tails")
                  ),





                  conditionalPanel(
                    condition = "input.continuas == 'F-Fisher' && input.lower_tail_fisher == 'lower.tail' && input.tipoC== 'Values'",
                    plotOutput("fisherPlot_lower")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'F-Fisher' && input.lower_tail_fisher == 'upper.tail' && input.tipoC== 'Values'",
                    plotOutput("fisherPlot_upper")
                  ),

                  conditionalPanel(
                    condition = "input.continuas == 'F-Fisher' && input.Continuasx == 'lower.tail' && input.tipoC== 'Probabilities'",
                    plotOutput("fisherPlot_lower_Probabilities")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'F-Fisher' && input.Continuasx == 'upper.tail' && input.tipoC== 'Probabilities'",
                    plotOutput("fisherPlot_upper_Probabilities")
                  ),


                  conditionalPanel(
                    condition = "input.continuas == 'F-Fisher' && input.lower_tail_fisher == 'interval' && input.tipoC== 'Values'",
                    plotOutput("fisherPlot_interval")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'F-Fisher' && input.lower_tail_fisher == 'tails' && input.tipoC== 'Values'",
                    plotOutput("fisherPlot_tails")
                  ),





                  conditionalPanel(
                    condition = "input.continuas == 'Gamma' && input.lower_tail_gamma == 'lower.tail' && input.tipoC== 'Values'",
                    plotOutput("gammaPlot_lower")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Gamma' && input.lower_tail_gamma == 'upper.tail' && input.tipoC== 'Values'",
                    plotOutput("gammaPlot_upper")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Gamma' && input.Continuasx == 'lower.tail' && input.tipoC== 'Probabilities'",
                    plotOutput("gammaPlot_lower_Probabilities")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Gamma' && input.Continuasx == 'upper.tail' && input.tipoC== 'Probabilities'",
                    plotOutput("gammaPlot_upper_Probabilities")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Gamma' && input.lower_tail_gamma == 'interval' && input.tipoC== 'Values'",
                    plotOutput("gammaPlot_interval")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Gamma' && input.lower_tail_gamma == 'tails' && input.tipoC== 'Values'",
                    plotOutput("gammaPlot_tails")
                  ),




                  conditionalPanel(
                    condition = "input.continuas == 'Logistics' && input.lower_tail_logistic == 'lower.tail' && input.tipoC== 'Values'",
                    plotOutput("logisticPlot_lower")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Logistics' && input.lower_tail_logistic == 'upper.tail' && input.tipoC== 'Values'",
                    plotOutput("logisticPlot_upper")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Logistics' && input.Continuasx == 'lower.tail' && input.tipoC== 'Probabilities'",
                    plotOutput("logisticPlot_lower_Probabilities")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Logistics' && input.Continuasx == 'upper.tail' && input.tipoC== 'Probabilities'",
                    plotOutput("logisticPlot_upper_Probabilities")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Logistics' && input.lower_tail_logistic == 'interval' && input.tipoC== 'Values'",
                    plotOutput("logisticPlot_interval")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Logistics' && input.lower_tail_logistic == 'tails' && input.tipoC== 'Values'",
                    plotOutput("logisticPlot_tails")
                  ),





                  conditionalPanel(
                    condition = "input.continuas == 'Log-Normal' && input.lower_tail_lognormal == 'lower.tail' && input.tipoC== 'Values'",
                    plotOutput("lognormalPlot_lower")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Log-Normal' && input.lower_tail_lognormal == 'upper.tail' && input.tipoC== 'Values'",
                    plotOutput("lognormalPlot_upper")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Log-Normal' && input.Continuasx == 'lower.tail' && input.tipoC== 'Probabilities'",
                    plotOutput("lognormalPlot_lower_Probabilities")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Log-Normal' && input.Continuasx == 'upper.tail' && input.tipoC== 'Probabilities'",
                    plotOutput("lognormalPlot_upper_Probabilities")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Log-Normal' && input.lower_tail_lognormal == 'interval' && input.tipoC== 'Values'",
                    plotOutput("lognormalPlot_interval")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Log-Normal' && input.lower_tail_lognormal == 'tails' && input.tipoC== 'Values'",
                    plotOutput("lognormalPlot_tails")
                  ),




                  conditionalPanel(
                    condition = "input.continuas == 'Weibull' && input.lower_tail_weibull == 'lower.tail' && input.tipoC== 'Values'",
                    plotOutput("weibullPlot_lower")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Weibull' && input.lower_tail_weibull == 'upper.tail' && input.tipoC== 'Values'",
                    plotOutput("weibullPlot_upper")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Weibull' && input.Continuasx == 'lower.tail' && input.tipoC== 'Probabilities'",
                    plotOutput("weibullPlot_lower_Probabilities")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Weibull' && input.Continuasx == 'upper.tail' && input.tipoC== 'Probabilities'",
                    plotOutput("weibullPlot_upper_Probabilities")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Weibull' && input.lower_tail_weibull == 'interval' && input.tipoC== 'Values'",
                    plotOutput("weibullPlot_interval")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Weibull' && input.lower_tail_weibull == 'tails' && input.tipoC== 'Values'",
                    plotOutput("weibullPlot_tails")
                  ),
                  br(),
                  shinyjs::useShinyjs(),
                  downloadButton('downloadPlot2', 'Download Plot'),
                  br()
                )# fin main panel
            )
    )

continuous_probability_distribution <- shinydashboard::tabItem(
     tabName = "Continuous",
     shinydashboard::box(width = "100%",
                height = "100%",
                title = "Continuous probability distributions",
                status = "primary",
                solidHeader = TRUE,
                collapsible = TRUE,
                sidebarPanel(helpText(h5("Continuous probability distributions")
                ),
                shinyWidgets::actionBttn("helpcontinuas",
                                         "",
                                         icon = icon("question-circle"),
                                         style = "stretch",
                                         block = FALSE,
                                         color = "primary"
                ),
                shinyBS::bsModal(id="dataset",
                                 title = "",
                                 trigger = "helpcontinuas",
                                 size="large",
                                 tags$iframe(
                                   src = "continuas.html",
                                   width = "100%",
                                  height = "100%",
                                   frameborder = 0,
                                   scrolling = "auto"
                                 ),

                                 # CSS para personalizar el tamaño del modal
                                 tags$style(HTML("
    #dataset .modal-dialog {
      width: 95%;  /* Adjusts the modal's width to 95% of the screen */
      height: 90%; /* Adjusts the modal's height to 90% of the screen */
      max-width: none; /* Removes the default max-width constraint */
    }
    #dataset .modal-content {
      height: 100%; /* Ensures that the content fills the modal */
      overflow: auto; /* Adds scrolling if the content exceeds the modal's height */
    }
    #dataset .modal-body {
      height: calc(100vh - 200px); /* Ensures the body takes full height with proper spacing */
      overflow-y: auto; /* Allows the body content to be scrollable */
    }
  "))
                ),
                shinyWidgets::pickerInput(
                  inputId = "continuas",
                  label = "Distribution",
                  choices = c("Select distribution",
                              "Normal",
                              "t-Student",
                              "Chi^2",
                              "F-Fisher",
                              "Exponential",
                              "Logistics",
                              "Log-Normal",
                              "Gamma",
                              "Weibull",
                              "Beta"),
                  options = list(
                    style = "btn-primary")
                ),
                conditionalPanel(
                  condition = "input.continuas != 'Select distribution'",
                  radioButtons(
                    inputId = "tipoC",
                    label = NULL,
                    inline = TRUE,
                    choices = c("Values", "Probabilities"))
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Normal'",
                  numericInput("mean_normal", "mean \\(\\mu\\):",
                               value = 0, step = 1
                  ),
                  radioButtons(
                    inputId = "variance_sd",
                    label = NULL,
                    choices = c(
                      "Variance \\(\\sigma^2\\)" = "variance_true",
                      "Standard deviation \\(\\sigma\\)" = "variance_false"
                    )
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Normal' && input.variance_sd == 'variance_true'",
                  numericInput("variance_normal", "Variance \\(\\sigma^2\\):",
                               value = 1, min = 0, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Normal' && input.variance_sd == 'variance_false'",
                  numericInput("sd_normal", "Standard deviation \\(\\sigma\\):",
                               value = 1, min = 0, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Normal'&& input.tipoC== 'Values'",
                  radioButtons(
                    inputId = "lower_tail_normal",
                    label = NULL,
                    choices = c(
                      "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                      "Upper tail : \\(P(X > x)\\)" = "upper.tail",
                      "Interval : \\(P(a \\leq X \\leq b)\\)" = "interval",
                      "Tails : \\(P(X \\leq a )+ P(X \\geq b)\\)" = "tails"
                    )
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Normal' && input.lower_tail_normal == 'lower.tail'&& input.tipoC == 'Values'",
                  numericInput("x1_normal", "x:",
                               value = 1, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Normal' && input.lower_tail_normal == 'upper.tail'&& input.tipoC == 'Values'",
                  numericInput("x2_normal", "x:",
                               value = 1, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Normal' && input.lower_tail_normal == 'interval'&& input.tipoC == 'Values'",
                  numericInput("a_normal", "a:",
                               value = -1, step = 1
                  ),
                  numericInput("b_normal", "b: \\( (a \\leq b) \\)",
                               value = 1, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Normal' && input.lower_tail_normal == 'tails'&& input.tipoC == 'Values'",
                  numericInput("at_normal", "a:",
                               value = -1, step = 1
                  ),
                  numericInput("bt_normal", "b:",
                               value = 1, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 't-Student'",
                  numericInput("df_student", "Degrees of freedom \\(gl\\):",
                               value = 10, min = 1, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 't-Student'&& input.tipoC== 'Values'",
                  radioButtons(
                    inputId = "lower_tail_student",
                    label = NULL,
                    choices = c(
                      "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                      "Upper tail : \\(P(X > x)\\)" = "upper.tail",
                      "Interval : \\(P(a \\leq X \\leq b)\\)" = "interval",
                      "Tails : \\(P(X \\leq a )+ P(X \\geq b)\\)" = "tails"
                    )
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Beta'",
                  numericInput("alpha_beta", "Shape \\(\\alpha\\):",
                               value = 1,
                               min = 0,
                               step = 1
                  ),
                  numericInput("beta_beta", "Shape \\(\\beta\\):",
                               value = 3,
                               min = 0,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Beta'&& input.tipoC== 'Values'",
                  radioButtons(
                    inputId = "lower_tail_beta",
                    label = NULL,
                    choices = c(
                      "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                      "Upper tail : \\(P(X > x)\\)" = "upper.tail",
                      "Interval : \\(P(a \\leq X \\leq b)\\)" = "interval",
                      "Tails : \\(P(X \\leq a )+ P(X \\geq b)\\)" = "tails"
                    )
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Chi^2'",
                  numericInput("df_chisquare", "Degrees of freedom \\(gl\\):",
                               value = 6,
                               min = 1,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Chi^2'&& input.tipoC== 'Values'",
                  radioButtons(
                    inputId = "lower_tail_chisquare",
                    label = NULL,
                    choices = c(
                      "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                      "Upper tail : \\(P(X > x)\\)" = "upper.tail",
                      "Interval : \\(P(a \\leq X \\leq b)\\)" = "interval",
                      "Tails : \\(P(X \\leq a )+ P(X \\geq b)\\)" = "tails"
                    )
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Exponential'",
                  numericInput("rate_exponential", "Rate \\(\\lambda\\):",
                               value = 1,
                               min = 0,
                               step = 0.5
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Exponential'&& input.tipoC== 'Values'",
                  radioButtons(
                    inputId = "lower_tail_exponential",
                    label = NULL,
                    choices = c(
                      "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                      "Upper tail : \\(P(X > x)\\)" = "upper.tail",
                      "Interval : \\(P(a \\leq X \\leq b)\\)" = "interval",
                      "Tails : \\(P(X \\leq a )+ P(X \\geq b)\\)" = "tails"
                    )
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'F-Fisher'",
                  numericInput("df1_fisher", "Degrees of freedom \\(gl_1\\):",
                               value = 10,
                               min = 1,
                               step = 1
                  ),
                  numericInput("df2_fisher", "Degrees of freedom \\(gl_2\\):",
                               value = 5,
                               min = 1,
                               step = 1
                  )
                ),

                conditionalPanel(
                  condition = "input.continuas == 'F-Fisher'&& input.tipoC== 'Values'",
                  radioButtons(
                    inputId = "lower_tail_fisher",
                    label = NULL,
                    choices = c(
                      "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                      "Upper tail : \\(P(X > x)\\)" = "upper.tail",
                      "Interval : \\(P(a \\leq X \\leq b)\\)" = "interval",
                      "Tails : \\(P(X \\leq a )+ P(X \\geq b)\\)" = "tails"
                    )
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Gamma'",
                  numericInput("alpha_gamma", "Shape \\(\\alpha\\):",
                               value = 3,
                               min = 0,
                               step = 1
                  ),
                  numericInput("beta_gamma", "Rate \\(\\beta\\):",
                               value = 2,
                               min = 0,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Gamma'&& input.tipoC== 'Values'",
                  radioButtons(
                    inputId = "lower_tail_gamma",
                    label = NULL,
                    choices = c(
                      "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                      "Upper tail : \\(P(X > x)\\)" = "upper.tail",
                      "Interval : \\(P(a \\leq X \\leq b)\\)" = "interval",
                      "Tails : \\(P(X \\leq a )+ P(X \\geq b)\\)" = "tails"
                    )
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Logistics'",
                  numericInput("location_logistic", "Location \\(\\mu\\):",
                               value = 0,
                               step = 1
                  ),
                  numericInput("scale_logistic", "Scale \\(s\\):",
                               value = 1,
                               min = 0,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Logistics'&& input.tipoC== 'Values'",
                  radioButtons(
                    inputId = "lower_tail_logistic",
                    label = NULL,
                    choices = c(
                      "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                      "Upper tail : \\(P(X > x)\\)" = "upper.tail",
                      "Interval : \\(P(a \\leq X \\leq b)\\)" = "interval",
                      "Tails : \\(P(X \\leq a )+ P(X \\geq b)\\)" = "tails"
                    )
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Log-Normal'",
                  numericInput("mean_lognormal",
                               "Mean \\(\\mu\\):",
                               value = 0,
                               step = 1
                  ),
                  radioButtons(
                    inputId = "variance_sd_lognormal",
                    label = NULL,
                    choices = c(
                      "Variance \\(\\sigma^2\\)" = "variance_true",
                      "Standard deviation \\(\\sigma\\)" = "variance_false"
                    )
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Log-Normal' && input.variance_sd_lognormal == 'variance_true'",
                  numericInput("variance_lognormal", "Variance \\(\\sigma^2\\):",
                               value = 1,
                               min = 0,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Log-Normal' && input.variance_sd_lognormal == 'variance_false'",
                  numericInput("sd_lognormal", "Standard deviation \\(\\sigma\\):",
                               value = 1,
                               min = 0,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Log-Normal'&& input.tipoC== 'Values'",
                  radioButtons(
                    inputId = "lower_tail_lognormal",
                    label = NULL,
                    choices = c(
                      "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                      "Upper tail : \\(P(X > x)\\)" = "upper.tail",
                      "Interval : \\(P(a \\leq X \\leq b)\\)" = "interval",
                      "Tails : \\(P(X \\leq a )+ P(X \\geq b)\\)" = "tails"
                    )
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Weibull'",
                  numericInput("alpha_weibull", "Shape \\(\\alpha\\):",
                               value = 5,
                               min = 0,
                               step = 1
                  ),
                  numericInput("beta_weibull", "Scale \\(\\beta\\):",
                               value = 1,
                               min = 0,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Weibull'&& input.tipoC== 'Values'",
                  radioButtons(
                    inputId = "lower_tail_weibull",
                    label = NULL,
                    choices = c(
                      "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                      "Upper tail : \\(P(X > x)\\)" = "upper.tail",
                      "Interval : \\(P(a \\leq X \\leq b)\\)" = "interval",
                      "Tails : \\(P(X \\leq a )+ P(X \\geq b)\\)" = "tails"
                    )
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 't-Student' && input.lower_tail_student == 'lower.tail'&& input.tipoC == 'Values'",
                  numericInput("x1_student", "x:",
                               value = 1,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 't-Student' && input.lower_tail_student == 'upper.tail'&& input.tipoC == 'Values'",
                  numericInput("x2_student", "x:",
                               value = 1,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 't-Student' && input.lower_tail_student == 'interval'&& input.tipoC == 'Values'",
                  numericInput("a_student", "a:",
                               value = -1,
                               step = 1
                  ),
                  numericInput("b_student", "b: \\( (a \\leq b) \\)",
                               value = 1,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 't-Student' && input.lower_tail_student == 'tails'&& input.tipoC == 'Values'",
                  numericInput("at_student", "a:",
                               value = -1,
                               step = 1
                  ),
                  numericInput("bt_student", "b: \\( (a \\leq b) \\)",
                               value = 1,
                               step = 1
                  )
                ),

                conditionalPanel(
                  condition = "input.continuas == 'Chi^2' && input.lower_tail_chisquare == 'lower.tail'&& input.tipoC == 'Values'",
                  numericInput("x1_chisquare", "x:",
                               value = 9.6,
                               min = 0, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Chi^2' && input.lower_tail_chisquare == 'upper.tail'&& input.tipoC == 'Values'",
                  numericInput("x2_chisquare", "x:",
                               value = 9.6,
                               min = 0,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Chi^2' && input.lower_tail_chisquare == 'interval'&& input.tipoC == 'Values'",
                  numericInput("a_chisquare", "a:",
                               value = 9.6,
                               min = 0,
                               step = 1
                  ),
                  numericInput("b_chisquare", "b: \\( (a \\leq b) \\)",
                               value = 14.4,
                               min = 0,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Chi^2' && input.lower_tail_chisquare == 'tails'&& input.tipoC == 'Values'",
                  numericInput("at_chisquare", "a:",
                               value = 9.6,
                               min = 0,
                               step = 1
                  ),
                  numericInput("bt_chisquare", "b: \\( (a \\leq b) \\)",
                               value = 14.4,
                               min = 0,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Beta' && input.lower_tail_beta == 'lower.tail'&& input.tipoC == 'Values'",
                  numericInput("x1_beta", "x:",
                               value = 0.45,
                               min = 0,
                               max = 1,
                               step = 0.01
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Beta' && input.lower_tail_beta == 'upper.tail'&& input.tipoC == 'Values'",
                  numericInput("x2_beta", "x:",
                               value = 0.45,
                               min = 0,
                               max = 1,
                               step = 0.01
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Beta' && input.lower_tail_beta == 'interval'&& input.tipoC == 'Values'",
                  numericInput("a_beta", "a:",
                               value = 0.25,
                               min = 0,
                               max = 1,
                               step = 0.01
                  ),
                  numericInput("b_beta", "b: \\( (a \\leq b) \\)",
                               value = 0.45,
                               min = 0,
                               max = 1,
                               step = 0.01
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Beta' && input.lower_tail_beta == 'tails'&& input.tipoC == 'Values'",
                  numericInput("at_beta", "a:",
                               value = 0.25,
                               min = 0,
                               max = 1,
                               step = 0.01
                  ),
                  numericInput("bt_beta", "b: \\( (a \\leq b) \\)",
                               value = 0.45,
                               min = 0,
                               max = 1,
                               step = 0.01
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Exponential' && input.lower_tail_exponential == 'lower.tail'&& input.tipoC == 'Values'",
                  numericInput("x1_exponential", "x:",
                               value = 2.24,
                               min = 0,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Exponential' && input.lower_tail_exponential == 'upper.tail'&& input.tipoC == 'Values'",
                  numericInput("x2_exponential", "x:",
                               value = 2.24,
                               min = 0,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Exponential' && input.lower_tail_exponential == 'interval'&& input.tipoC == 'Values'",
                  numericInput("a_exponential", "a:",
                               value = 2.24,
                               min = 0,
                               step = 1
                  ),
                  numericInput("b_exponential", "b: \\( (a \\leq b) \\)",
                               value = 3.36,
                               min = 0,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Exponential' && input.lower_tail_exponential == 'tails'&& input.tipoC == 'Values'",
                  numericInput("at_exponential", "a:",
                               value = 2.24,
                               min = 0,
                               step = 1
                  ),
                  numericInput("bt_exponential", "b: \\( (a \\leq b) \\)",
                               value = 3.36,
                               min = 0,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'F-Fisher' && input.lower_tail_fisher == 'lower.tail'&& input.tipoC == 'Values'",
                  numericInput("x1_fisher", "x:",
                               value = 4.14,
                               min = 0,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'F-Fisher' && input.lower_tail_fisher == 'upper.tail'&& input.tipoC == 'Values'",
                  numericInput("x2_fisher", "x:",
                               value = 4.14,
                               min = 0,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'F-Fisher' && input.lower_tail_fisher == 'interval'&& input.tipoC == 'Values'",
                  numericInput("a_fisher", "a:",
                               value = 2.76,
                               min = 0,
                               step = 1
                  ),
                  numericInput("b_fisher", "b: \\( (a \\leq b) \\)",
                               value = 4.14,
                               min = 0,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'F-Fisher' && input.lower_tail_fisher == 'tails'&& input.tipoC == 'Values'",
                  numericInput("at_fisher", "a:",
                               value = 2.76,
                               min = 0,
                               step = 1
                  ),
                  numericInput("bt_fisher", "b: \\( (a \\leq b) \\)",
                               value = 4.14,
                               min = 0,
                               step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Gamma' && input.lower_tail_gamma == 'lower.tail'&& input.tipoC == 'Values'",
                  numericInput("x1_gamma", "x:",
                               value = 2.4, min = 0, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Gamma' && input.lower_tail_gamma == 'upper.tail'&& input.tipoC == 'Values'",
                  numericInput("x2_gamma", "x:",
                               value = 2.4, min = 0, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Gamma' && input.lower_tail_gamma == 'interval'&& input.tipoC == 'Values'",
                  numericInput("a_gamma", "a:",
                               value = 0.8, min = 0, step = 1
                  ),
                  numericInput("b_gamma", "b: \\( (a \\leq b) \\)",
                               value = 2.4, min = 0, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Gamma' && input.lower_tail_gamma == 'tails'&& input.tipoC == 'Values'",
                  numericInput("at_gamma", "a:",
                               value = 0.8, min = 0, step = 1
                  ),
                  numericInput("bt_gamma", "b: \\( (a \\leq b) \\)",
                               value = 2.4, min = 0, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Logistics' && input.lower_tail_logistic == 'lower.tail'&& input.tipoC == 'Values'",
                  numericInput("x1_logistic", "x:",
                               value = 1.2, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Logistics' && input.lower_tail_logistic == 'upper.tail'&& input.tipoC == 'Values'",
                  numericInput("x2_logistic", "x:",
                               value = 1.2, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Logistics' && input.lower_tail_logistic == 'interval'&& input.tipoC == 'Values'",
                  numericInput("a_logistic", "a:",
                               value = -1.2, step = 1
                  ),
                  numericInput("b_logistic", "b: \\( (a \\leq b) \\)",
                               value = 1.2, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Logistics' && input.lower_tail_logistic == 'tails'&& input.tipoC == 'Values'",
                  numericInput("at_logistic", "a:",
                               value = -1.2, step = 1
                  ),
                  numericInput("bt_logistic", "b: \\( (a \\leq b) \\)",
                               value = 1.2, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Log-Normal' && input.lower_tail_lognormal == 'lower.tail'&& input.tipoC == 'Values'",
                  numericInput("x1_lognormal", "x:",
                               value = 1, min = 0, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Log-Normal' && input.lower_tail_lognormal == 'upper.tail'&& input.tipoC == 'Values'",
                  numericInput("x2_lognormal", "x:",
                               value = 1, min = 0, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Log-Normal' && input.lower_tail_lognormal == 'interval'&& input.tipoC == 'Values'",
                  numericInput("a_lognormal", "a:",
                               value = 1, min = 0, step = 1
                  ),
                  numericInput("b_lognormal", "b: \\( (a \\leq b) \\)",
                               value = 2, min = 0, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Log-Normal' && input.lower_tail_lognormal == 'tails'&& input.tipoC == 'Values'",
                  numericInput("at_lognormal", "a:",
                               value = 1, min = 0, step = 1
                  ),
                  numericInput("bt_lognormal", "b: \\( (a \\leq b) \\)",
                               value = 2, min = 0, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Weibull' && input.lower_tail_weibull == 'lower.tail'&& input.tipoC == 'Values'",
                  numericInput("x1_weibull", "x:",
                               value = 0.8, min = 0, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Weibull' && input.lower_tail_weibull == 'upper.tail'&& input.tipoC == 'Values'",
                  numericInput("x2_weibull", "x:",
                               value = 0.8, min = 0, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Weibull' && input.lower_tail_weibull == 'interval'&& input.tipoC == 'Values'",
                  numericInput("a_weibull", "a:",
                               value = 0.8, min = 0, step = 1
                  ),
                  numericInput("b_weibull", "b: \\( (a \\leq b) \\)",
                               value = 1.2, min = 0, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas == 'Weibull' && input.lower_tail_weibull == 'tails'&& input.tipoC == 'Values'",
                  numericInput("at_weibull", "a:",
                               value = 0.8, min = 0, step = 1
                  ),
                  numericInput("bt_weibull", "b: \\( (a \\leq b) \\)",
                               value = 1.2, min = 0, step = 1
                  )
                ),
                conditionalPanel(
                  condition = "input.continuas != 'Select distribution'&& input.tipoC == 'Probabilities'",
                  numericInput(inputId = "probC", label = "Probability of interest:",
                               value = 0.05, step = 0.001),
                  radioButtons(
                    inputId = "Continuasx",
                    label = "Type of desired outcome",
                    choices = c(
                      #"Exact value: \\(P(X = x)\\)" = "exact",
                      "Lower tail : \\(P(X \\leq x)\\)" = "lower.tail",
                      "Upper tail : \\(P(X \\geq x)\\)" = "upper.tail"
                    )
                  )
                ), br(),
                actionButton("refresh2" ,"Refresh")

                ),
                mainPanel(
                  tags$b("Distribution Details:"),
                  br(),
                  uiOutput("parameters_distribution"),
                  tags$b("Solution:"),
                  uiOutput("results_distribution"),
                  br(),

                  conditionalPanel(

                    condition = "input.continuas == 'Normal' && input.lower_tail_normal == 'lower.tail' && input.tipoC== 'Values'",
                    plotOutput("normalPlot_lower")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Normal' && input.lower_tail_normal == 'upper.tail' && input.tipoC== 'Values'",
                    plotOutput("normalPlot_upper")),
                  conditionalPanel(
                    condition = "input.continuas == 'Normal' && input.Continuasx  == 'lower.tail' && input.tipoC == 'Probabilities'",
                    plotOutput("normalPlot_lower_Probabilities")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Normal' && input.Continuasx == 'upper.tail' && input.tipoC == 'Probabilities'",
                    plotOutput("normalPlot_upper_Probabilities")),

                  conditionalPanel(
                    condition = "input.continuas == 'Normal' && input.lower_tail_normal == 'interval' && input.tipoC== 'Values'",
                    plotOutput("normalPlot_interval")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Normal' && input.lower_tail_normal == 'tails' && input.tipoC== 'Values'",
                    plotOutput("normalPlot_tails")
                  ),


                  conditionalPanel(
                    condition = "input.continuas == 't-Student' && input.lower_tail_student == 'lower.tail' && input.tipoC== 'Values'",
                    plotOutput("studentPlot_lower")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 't-Student' && input.lower_tail_student == 'upper.tail' && input.tipoC== 'Values'",
                    plotOutput("studentPlot_upper")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 't-Student' && input.Continuasx == 'lower.tail' && input.tipoC== 'Probabilities'",
                    plotOutput("studentPlot_lower_Probabilities")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 't-Student' && input.Continuasx == 'upper.tail' && input.tipoC== 'Probabilities'",
                    plotOutput("studentPlot_upper_Probabilities")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 't-Student' && input.lower_tail_student == 'interval' && input.tipoC== 'Values'",
                    plotOutput("studentPlot_interval")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 't-Student' && input.lower_tail_student == 'tails' && input.tipoC== 'Values'",
                    plotOutput("studentPlot_tails")
                  ),






                  conditionalPanel(
                    condition = "input.continuas == 'Beta' && input.lower_tail_beta == 'lower.tail' && input.tipoC== 'Values'",
                    plotOutput("betaPlot_lower")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Beta' && input.lower_tail_beta == 'upper.tail' && input.tipoC== 'Values'",
                    plotOutput("betaPlot_upper")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Beta' && input.Continuasx == 'lower.tail' && input.tipoC== 'Probabilities'",
                    plotOutput("betaPlot_lower_Probabilities")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Beta' && input.Continuasx == 'upper.tail' && input.tipoC== 'Probabilities'",
                    plotOutput("betaPlot_upper_Probabilities")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Beta' && input.lower_tail_beta == 'interval' && input.tipoC== 'Values'",
                    plotOutput("betaPlot_interval")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Beta' && input.lower_tail_beta == 'tails'&& input.tipoC== 'Values'",
                    plotOutput("betaPlot_tails")
                  ),



                  #### chi cuadrada continua

                  conditionalPanel(
                    condition = "input.continuas == 'Chi^2' && input.lower_tail_chisquare == 'lower.tail' && input.tipoC== 'Values'",
                    plotOutput("chisquarePlot_lower")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Chi^2' && input.lower_tail_chisquare == 'upper.tail' && input.tipoC== 'Values'",
                    plotOutput("chisquarePlot_upper")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Chi^2' && input.Continuasx == 'lower.tail' && input.tipoC== 'Probabilities'",
                    plotOutput("chisquarePlot_lower_Probabilities")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Chi^2' && input.Continuasx == 'upper.tail' && input.tipoC== 'Probabilities'",
                    plotOutput("chisquarePlot_upper_Probabilities")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Chi^2' && input.lower_tail_chisquare == 'interval' && input.tipoC== 'Values'",
                    plotOutput("chisquarePlot_interval")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Chi^2' && input.lower_tail_chisquare == 'tails' && input.tipoC== 'Values'",
                    plotOutput("chisquarePlot_tails")
                  ),



                  conditionalPanel(
                    condition = "input.continuas == 'Exponential' && input.lower_tail_exponential == 'lower.tail' && input.tipoC== 'Values'",
                    plotOutput("exponentialPlot_lower")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Exponential' && input.lower_tail_exponential == 'upper.tail' && input.tipoC== 'Values'",
                    plotOutput("exponentialPlot_upper")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Exponential' && input.Continuasx == 'lower.tail' && input.tipoC== 'Probabilities'",
                    plotOutput("exponentialPlot_lower_Probabilities")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Exponential' && input.Continuasx == 'upper.tail' && input.tipoC== 'Probabilities'",
                    plotOutput("exponentialPlot_upper_Probabilities")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Exponential' && input.lower_tail_exponential == 'interval' && input.tipoC== 'Values'",
                    plotOutput("exponentialPlot_interval")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Exponential' && input.lower_tail_exponential == 'tails' && input.tipoC== 'Values'",
                    plotOutput("exponentialPlot_tails")
                  ),





                  conditionalPanel(
                    condition = "input.continuas == 'F-Fisher' && input.lower_tail_fisher == 'lower.tail' && input.tipoC== 'Values'",
                    plotOutput("fisherPlot_lower")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'F-Fisher' && input.lower_tail_fisher == 'upper.tail' && input.tipoC== 'Values'",
                    plotOutput("fisherPlot_upper")
                  ),

                  conditionalPanel(
                    condition = "input.continuas == 'F-Fisher' && input.Continuasx == 'lower.tail' && input.tipoC== 'Probabilities'",
                    plotOutput("fisherPlot_lower_Probabilities")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'F-Fisher' && input.Continuasx == 'upper.tail' && input.tipoC== 'Probabilities'",
                    plotOutput("fisherPlot_upper_Probabilities")
                  ),


                  conditionalPanel(
                    condition = "input.continuas == 'F-Fisher' && input.lower_tail_fisher == 'interval' && input.tipoC== 'Values'",
                    plotOutput("fisherPlot_interval")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'F-Fisher' && input.lower_tail_fisher == 'tails' && input.tipoC== 'Values'",
                    plotOutput("fisherPlot_tails")
                  ),





                  conditionalPanel(
                    condition = "input.continuas == 'Gamma' && input.lower_tail_gamma == 'lower.tail' && input.tipoC== 'Values'",
                    plotOutput("gammaPlot_lower")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Gamma' && input.lower_tail_gamma == 'upper.tail' && input.tipoC== 'Values'",
                    plotOutput("gammaPlot_upper")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Gamma' && input.Continuasx == 'lower.tail' && input.tipoC== 'Probabilities'",
                    plotOutput("gammaPlot_lower_Probabilities")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Gamma' && input.Continuasx == 'upper.tail' && input.tipoC== 'Probabilities'",
                    plotOutput("gammaPlot_upper_Probabilities")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Gamma' && input.lower_tail_gamma == 'interval' && input.tipoC== 'Values'",
                    plotOutput("gammaPlot_interval")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Gamma' && input.lower_tail_gamma == 'tails' && input.tipoC== 'Values'",
                    plotOutput("gammaPlot_tails")
                  ),




                  conditionalPanel(
                    condition = "input.continuas == 'Logistics' && input.lower_tail_logistic == 'lower.tail' && input.tipoC== 'Values'",
                    plotOutput("logisticPlot_lower")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Logistics' && input.lower_tail_logistic == 'upper.tail' && input.tipoC== 'Values'",
                    plotOutput("logisticPlot_upper")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Logistics' && input.Continuasx == 'lower.tail' && input.tipoC== 'Probabilities'",
                    plotOutput("logisticPlot_lower_Probabilities")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Logistics' && input.Continuasx == 'upper.tail' && input.tipoC== 'Probabilities'",
                    plotOutput("logisticPlot_upper_Probabilities")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Logistics' && input.lower_tail_logistic == 'interval' && input.tipoC== 'Values'",
                    plotOutput("logisticPlot_interval")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Logistics' && input.lower_tail_logistic == 'tails' && input.tipoC== 'Values'",
                    plotOutput("logisticPlot_tails")
                  ),





                  conditionalPanel(
                    condition = "input.continuas == 'Log-Normal' && input.lower_tail_lognormal == 'lower.tail' && input.tipoC== 'Values'",
                    plotOutput("lognormalPlot_lower")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Log-Normal' && input.lower_tail_lognormal == 'upper.tail' && input.tipoC== 'Values'",
                    plotOutput("lognormalPlot_upper")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Log-Normal' && input.Continuasx == 'lower.tail' && input.tipoC== 'Probabilities'",
                    plotOutput("lognormalPlot_lower_Probabilities")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Log-Normal' && input.Continuasx == 'upper.tail' && input.tipoC== 'Probabilities'",
                    plotOutput("lognormalPlot_upper_Probabilities")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Log-Normal' && input.lower_tail_lognormal == 'interval' && input.tipoC== 'Values'",
                    plotOutput("lognormalPlot_interval")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Log-Normal' && input.lower_tail_lognormal == 'tails' && input.tipoC== 'Values'",
                    plotOutput("lognormalPlot_tails")
                  ),




                  conditionalPanel(
                    condition = "input.continuas == 'Weibull' && input.lower_tail_weibull == 'lower.tail' && input.tipoC== 'Values'",
                    plotOutput("weibullPlot_lower")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Weibull' && input.lower_tail_weibull == 'upper.tail' && input.tipoC== 'Values'",
                    plotOutput("weibullPlot_upper")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Weibull' && input.Continuasx == 'lower.tail' && input.tipoC== 'Probabilities'",
                    plotOutput("weibullPlot_lower_Probabilities")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Weibull' && input.Continuasx == 'upper.tail' && input.tipoC== 'Probabilities'",
                    plotOutput("weibullPlot_upper_Probabilities")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Weibull' && input.lower_tail_weibull == 'interval' && input.tipoC== 'Values'",
                    plotOutput("weibullPlot_interval")
                  ),
                  conditionalPanel(
                    condition = "input.continuas == 'Weibull' && input.lower_tail_weibull == 'tails' && input.tipoC== 'Values'",
                    plotOutput("weibullPlot_tails")
                  ),
                  br(),
                  shinyjs::useShinyjs(),
                  downloadButton('downloadPlot2', 'Download Plot'),
                  br()
                )# fin main panel
            )
    )

 Graphic_summary_ContinuousBivariate <- tabPanel(
          "Graphic summary",
          strong(h2("Scatterplot")),
          br(),
          conditionalPanel(
            condition = "input.Gruposcatter == 0",
            plotOutput("scat"),
            br(),
            downloadButton("ContinuousBivariateScatterDownloadNoGrupo", "Download Graph", class = "btn-primary"),
            br(), br(),
            shinyWidgets::dropdown(
              label = "Customize graph",
              tags$h3("Customize"),
              div(
        style = "display: inline-block;vertical-align:top; width: 100%; text-align: center; margin-bottom: 10px;",
        shinyWidgets::actionBttn(
          inputId = "resetScatterBivariate",
          label = "Reset to Initial State",
          style = "bordered",
          color = "warning",
          size = "sm",
          icon = icon("refresh")
        )
      ),
              div(
                style = "display: inline-block;vertical-align:top;
                               width: 150px;",
                selectInput("themescatter",
                  " Theme",
                  choices = names(themesb)
                )
              ),
              div(
                style = "display: inline-block;vertical-align:top; width: 150px;",
                selectInput("fontScatter",
                  " Font",
                  choices = fuentes
                )
              ),
              div(
                style = "display: inline-block;vertical-align:top;width: 150px;",
                textInput(
                  "ylabscatter",
                  label = "ylab",
                  value = "Write ylab..."
                )
              ),
              div(
                style = "display: inline-block;vertical-align:top;width: 150px;",
                textInput(
                  "xlabscatter",
                  label = "xlab",
                  value = "Write xlab..."
                )
              ),
              div(
                style = "display: inline-block;vertical-align:top;width: 150px;",
                colourInput(
                  "colorscatter",
                  label = "Color",
                  value = "blue"
                )
              ),
              div(
                style = "display: inline-block;vertical-align:top; width: 150px;",
                sliderInput(
                  inputId = "fontSizeScatter",
                  label = "Size font",
                  min = 1,
                  max = 50,
                  value = 12
                )
              ),
              div(
                style = "display: inline-block;vertical-align:top; width: 150px;",
                sliderInput(
                  inputId = "sizescatter",
                  label = "Size",
                  min = 1,
                  max = 50,
                  value = 3
                )
              ),
              div(
                style = "display: inline-block;vertical-align:top; width: 150px;",
                sliderInput(
                  inputId = "shapescatter",
                  label = "Shape",
                  min = 1,
                  max = 25,
                  value = 16
                )
              ),
              div(
                style = "display: inline-block;vertical-align:top; width: 150px;",
                sliderInput(
                  inputId = "alphascatter",
                  label = "alpha",
                  min = 0.001,
                  max = 1,
                  value = 0.5
                )
              ),
              style = "unite",
              icon = icon("fish"),
              status = "primary",
              width = "500px",
              animate = shinyWidgets::animateOptions(
                enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
                exit = shinyWidgets::animations$fading_exits$fadeOutRightBig
              )
            )
          ),
          conditionalPanel(
            condition = "input.Gruposcatter == 1",
            plotOutput("scat2"),
            br(),
            downloadButton("ContinuousBivariateScatterDownloadGrupo", "Download Graph", class = "btn-primary"),
            br(), br(),
            shinyWidgets::dropdown(
              label = "Customize graph",
              tags$h3("Customize"),
               div(
        style = "display: inline-block;vertical-align:top; width: 100%; text-align: center; margin-bottom: 10px;",
        shinyWidgets::actionBttn(
          inputId = "resetScatterBivariate2",
          label = "Reset to Initial State",
          style = "bordered",
          color = "warning",
          size = "sm",
          icon = icon("refresh")
        )
      ),
              div(
                style = "display: inline-block;vertical-align:top;
                               width: 150px;",
                selectInput("themescatter2",
                  " Theme",
                  choices = names(themesb)
                )
              ),
              div(
                style = "display: inline-block;vertical-align:top; width: 150px;",
                selectInput("fontScatter2",
                  " Font",
                  choices = fuentes
                )
              ),
              div(
                style = "display: inline-block;vertical-align:top;width: 150px;",
                textInput(
                  "ylabscatter2",
                  label = "ylab",
                  value = "Write ylab..."
                )
              ),
              div(
                style = "display: inline-block;vertical-align:top;width: 150px;",
                textInput(
                  "xlabscatter2",
                  label = "xlab",
                  value = "Write xlab..."
                )
              ),
              div(
                style = "display: inline-block;vertical-align:top; width: 150px;",
                selectInput("paletascatter",
                  "Palletes",
                  choices = paletas
                )
              ),
              div(
                style = "display: inline-block;vertical-align:top; width: 150px;",
                sliderInput(
                  inputId = "fontSizeScatter2",
                  label = "Size font",
                  min = 1,
                  max = 50,
                  value = 12
                )
              ),
              div(
                style = "display: inline-block;vertical-align:top; width: 150px;",
                sliderInput(
                  inputId = "sizescatter2",
                  label = "Size",
                  min = 1,
                  max = 50,
                  value = 3
                )
              ),
              div(
                style = "display: inline-block;vertical-align:top; width: 150px;",
                sliderInput(
                  inputId = "shapescatter2",
                  label = "Shape",
                  min = 1,
                  max = 25,
                  value = 16
                )
              ),
              div(
                style = "display: inline-block;vertical-align:top; width: 150px;",
                sliderInput(
                  inputId = "alphascatter2",
                  label = "alpha",
                  min = 0.001,
                  max = 1,
                  value = 0.5
                )
              ),
              style = "unite",
              icon = icon("fish"),
              status = "primary",
              width = "500px",
              animate = shinyWidgets::animateOptions(
                enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
                exit = shinyWidgets::animations$fading_exits$fadeOutRightBig
              )
            )
          )
        )

 Graphic_summary_ContinuousBivariate <- tabPanel(
          "Graphic summary",
          strong(h2("Scatterplot")),
          br(),
          conditionalPanel(
            condition = "input.Gruposcatter == 0",
            plotOutput("scat"),
            br(),
            downloadButton("ContinuousBivariateScatterDownloadNoGrupo", "Download Graph", class = "btn-primary"),
            br(), br(),
            shinyWidgets::dropdown(
              label = "Customize graph",
              tags$h3("Customize"),
              div(
        style = "display: inline-block;vertical-align:top; width: 100%; text-align: center; margin-bottom: 10px;",
        shinyWidgets::actionBttn(
          inputId = "resetScatterBivariate",
          label = "Reset to Initial State",
          style = "bordered",
          color = "warning",
          size = "sm",
          icon = icon("refresh")
        )
      ),
              div(
                style = "display: inline-block;vertical-align:top;
                               width: 150px;",
                selectInput("themescatter",
                  " Theme",
                  choices = names(themesb)
                )
              ),
              div(
                style = "display: inline-block;vertical-align:top; width: 150px;",
                selectInput("fontScatter",
                  " Font",
                  choices = fuentes
                )
              ),
              div(
                style = "display: inline-block;vertical-align:top;width: 150px;",
                textInput(
                  "ylabscatter",
                  label = "ylab",
                  value = "Write ylab..."
                )
              ),
              div(
                style = "display: inline-block;vertical-align:top;width: 150px;",
                textInput(
                  "xlabscatter",
                  label = "xlab",
                  value = "Write xlab..."
                )
              ),
              div(
                style = "display: inline-block;vertical-align:top;width: 150px;",
                colourInput(
                  "colorscatter",
                  label = "Color",
                  value = "blue"
                )
              ),
              div(
                style = "display: inline-block;vertical-align:top; width: 150px;",
                sliderInput(
                  inputId = "fontSizeScatter",
                  label = "Size font",
                  min = 1,
                  max = 50,
                  value = 12
                )
              ),
              div(
                style = "display: inline-block;vertical-align:top; width: 150px;",
                sliderInput(
                  inputId = "sizescatter",
                  label = "Size",
                  min = 1,
                  max = 50,
                  value = 3
                )
              ),
              div(
                style = "display: inline-block;vertical-align:top; width: 150px;",
                sliderInput(
                  inputId = "shapescatter",
                  label = "Shape",
                  min = 1,
                  max = 25,
                  value = 16
                )
              ),
              div(
                style = "display: inline-block;vertical-align:top; width: 150px;",
                sliderInput(
                  inputId = "alphascatter",
                  label = "alpha",
                  min = 0.001,
                  max = 1,
                  value = 0.5
                )
              ),
              style = "unite",
              icon = icon("fish"),
              status = "primary",
              width = "500px",
              animate = shinyWidgets::animateOptions(
                enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
                exit = shinyWidgets::animations$fading_exits$fadeOutRightBig
              )
            )
          ),
          conditionalPanel(
            condition = "input.Gruposcatter == 1",
            plotOutput("scat2"),
            br(),
            downloadButton("ContinuousBivariateScatterDownloadGrupo", "Download Graph", class = "btn-primary"),
            br(), br(),
            shinyWidgets::dropdown(
              label = "Customize graph",
              tags$h3("Customize"),
               div(
        style = "display: inline-block;vertical-align:top; width: 100%; text-align: center; margin-bottom: 10px;",
        shinyWidgets::actionBttn(
          inputId = "resetScatterBivariate2",
          label = "Reset to Initial State",
          style = "bordered",
          color = "warning",
          size = "sm",
          icon = icon("refresh")
        )
      ),
              div(
                style = "display: inline-block;vertical-align:top;
                               width: 150px;",
                selectInput("themescatter2",
                  " Theme",
                  choices = names(themesb)
                )
              ),
              div(
                style = "display: inline-block;vertical-align:top; width: 150px;",
                selectInput("fontScatter2",
                  " Font",
                  choices = fuentes
                )
              ),
              div(
                style = "display: inline-block;vertical-align:top;width: 150px;",
                textInput(
                  "ylabscatter2",
                  label = "ylab",
                  value = "Write ylab..."
                )
              ),
              div(
                style = "display: inline-block;vertical-align:top;width: 150px;",
                textInput(
                  "xlabscatter2",
                  label = "xlab",
                  value = "Write xlab..."
                )
              ),
              div(
                style = "display: inline-block;vertical-align:top; width: 150px;",
                selectInput("paletascatter",
                  "Palletes",
                  choices = paletas
                )
              ),
              div(
                style = "display: inline-block;vertical-align:top; width: 150px;",
                sliderInput(
                  inputId = "fontSizeScatter2",
                  label = "Size font",
                  min = 1,
                  max = 50,
                  value = 12
                )
              ),
              div(
                style = "display: inline-block;vertical-align:top; width: 150px;",
                sliderInput(
                  inputId = "sizescatter2",
                  label = "Size",
                  min = 1,
                  max = 50,
                  value = 3
                )
              ),
              div(
                style = "display: inline-block;vertical-align:top; width: 150px;",
                sliderInput(
                  inputId = "shapescatter2",
                  label = "Shape",
                  min = 1,
                  max = 25,
                  value = 16
                )
              ),
              div(
                style = "display: inline-block;vertical-align:top; width: 150px;",
                sliderInput(
                  inputId = "alphascatter2",
                  label = "alpha",
                  min = 0.001,
                  max = 1,
                  value = 0.5
                )
              ),
              style = "unite",
              icon = icon("fish"),
              status = "primary",
              width = "500px",
              animate = shinyWidgets::animateOptions(
                enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
                exit = shinyWidgets::animations$fading_exits$fadeOutRightBig
              )
            )
          )
        )

source("pages/bivariate_graphic_summary.R")
source("pages/dep_correlation_study.R")
continuous_variables_bivariate <- shinydashboard::tabItem(
  tabName = "Continuous_variables_bivariate",
  shinydashboard::box(
    height = "100%", width = 12, title = "Continuos variables",
    status = "primary",
    solidHeader = TRUE,
    collapsible = TRUE,
    sidebarPanel(
      shinyWidgets::actionBttn(
        "helpbivariate",
        "Help",
        icon = icon("question-circle"),
        style = "stretch",
        block = FALSE,
        color = "primary"
      ),
      shinyBS::bsModal(
        id = "modalHelpBivariate",
        title = "Help: Continuous variables (bivariate)",
        trigger = "helpbivariate",
        size = "large",
        tags$iframe(src = "continuous_variables_bivariate.html", width = "100%", height = "600px", frameborder = 0)
      ),
      selectizeInput("selvar1",
        "Variable 1 (x)",
        choices = NULL,
        multiple = FALSE
      ),
      selectizeInput("selvar2",
        "Variable 2 (y)",
        choices = NULL,
        multiple = FALSE
      ),
    conditionalPanel(
  condition = "input.bivariateTabs != 'Dependency_and_Correlation_Study'",
  shinyWidgets::prettyCheckbox(
    inputId = "Gruposcatter",
    label = "Statistics by group?",
    value = FALSE,
    status = "success"
  )
),
      conditionalPanel(
        condition = "input.Gruposcatter == 1",
        selectizeInput("selgruposcatter",
          "group by",
          choices = NULL,
          multiple = FALSE
        )
      )
    ),
    mainPanel(
      tabsetPanel(id = "bivariateTabs",
        Dependency_and_Correlation_Study,
        Graphic_summary_ContinuousBivariate
      )
    )
  )
)

#' Shiny GUI for StatisticTeach1 package
#'@import shiny
#'@import shinydashboard
#'@importFrom shinyBS bsModal
#'@importFrom shinyjs useShinyjs
#'@importFrom shinyjs disable
#'@importFrom shinyjs enable
#'@importFrom shinyWidgets pickerInput
#'@importFrom shinyWidgets actionBttn
#'@importFrom shinyWidgets prettyCheckbox
#'@importFrom shinyWidgets dropdown
#'@importFrom shinyWidgets switchInput
#'@importFrom shinyWidgets animateOptions
#'@importFrom readxl excel_sheets
#'@importFrom readxl read_excel
#'@import dplyr
#'@import RColorBrewer
#'@importFrom rlang syms
#'@importFrom rlang sym
#'@import ggplot2
#'@import mixdist
#'@import descriptr
#'@import DescTools
#'@import tibble
#'@import tidyr
#'@importFrom colourpicker colourInput updateColourInput
#'@importFrom magrittr %<>%
#'@description runStatisticTeach1() loads interactive user interface built using R 'shiny'.
#'@details The interactive user interface to provide an easy way for to perform descriptive statistical analysis
#' @param launch.browser If true,
#' the system's default web browser will be launched automatically
#' after the app is started. Defaults to true in interactive sessions
#' only. This value of this parameter can also be a function to call with
#' the application's URL.
#' @param port is the TCP port that the application should listen on.
#' If the port is not specified,
#' and the shiny.port option is set (with options(shiny.port = XX)),
#' then that port will be used.
#' Otherwise, use a random port.
#' @param host The IPv4 address that the application should listen on.
#' Defaults to the shiny.host option, if set, or "127.0.0.1" if not.
#' @return No return value
#' @examples
#' if(interactive()){
#' runStatisticTeach1()
#' }
#' @export


runStatisticTeach1 <- function(host = "127.0.0.1",
                                port = NULL,launch.browser = TRUE) {
  appDir <- system.file("StatisticTeach1App", package = "StatisticTeach1")
  if (appDir == "") {
    stop("Could not find StatisticTeach1.
         Try re-installing `StatisticTeach1`.", call. = FALSE)
  }

  shiny::runApp(appDir,
                display.mode = "normal",
                launch.browser = launch.browser,
                port = port,
                host = getOption("shiny.host", host)
  )
}

load_dataPage <- shinydashboard::tabItem( tabName = "Load_data",
      tags$head(
        tags$style(HTML("
          /* Global styles to ensure all text is black */
          .tab-pane label, .tab-pane .control-label { color: #000000 !important; }
          .tab-pane .form-control { color: #000000 !important; }
          .tab-pane strong { color: #000000 !important; }
          .tab-pane .checkbox label { color: #000000 !important; }
          .tab-pane .shiny-input-container label { color: #000000 !important; }
          .tab-pane .form-group label { color: #000000 !important; }
          .tab-pane .file-input-container label { color: #000000 !important; }
          .tab-pane .selectize-input { color: #000000 !important; }
          .tab-pane .selectize-dropdown { color: #000000 !important; }
          .tab-pane .btn-file { color: #000000 !important; }
          .tab-pane .input-group-addon { color: #000000 !important; }
          .tab-pane .help-block { color: #000000 !important; }
          .tab-pane .text-muted { color: #000000 !important; }
          .tab-pane .text-info { color: #000000 !important; }
          .tab-pane .text-success { color: #000000 !important; }
          .tab-pane .text-warning { color: #000000 !important; }
          .tab-pane .text-danger { color: #000000 !important; }
          .tab-pane .pretty { color: #000000 !important; }
          .tab-pane .pretty .state label { color: #000000 !important; }
          .tab-pane .pretty .state label:before { color: #000000 !important; }
          .tab-pane .pretty .state label:after { color: #000000 !important; }
          
          /* Improved styling for column type selector */
          .column-type-row { 
            background: #f8f9fa; 
            border: 1px solid #e9ecef; 
            border-radius: 6px; 
            padding: 12px; 
            margin-bottom: 8px; 
            transition: all 0.3s ease;
          }
          .column-type-row:hover { 
            background: #e9ecef; 
            border-color: #007bff; 
            box-shadow: 0 2px 4px rgba(0,0,0,0.1);
          }
          .column-type-row label { 
            font-weight: bold; 
            color: #495057 !important; 
            margin-bottom: 8px; 
          }
          .column-type-row .form-control { 
            border-radius: 4px; 
            border: 1px solid #ced4da; 
          }
          .column-type-row .form-control:focus { 
            border-color: #007bff; 
            box-shadow: 0 0 0 0.2rem rgba(0,123,255,0.25); 
          }
          .decimal-separator-section, .date-format-section { 
            background: #e7f3ff; 
            border: 1px solid #b3d9ff; 
            border-radius: 4px; 
            padding: 8px; 
            margin-top: 5px; 
          }
          .decimal-separator-section label, .date-format-section label { 
            font-size: 12px; 
            color: #0056b3 !important; 
            font-weight: normal; 
          }
          
          /* Improved table styling */
          .shiny-table-output table {
            width: 100% !important;
            border-collapse: collapse !important;
            margin: 0 !important;
            font-size: 13px !important;
            font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif !important;
          }
          .shiny-table-output th {
            background: linear-gradient(135deg, #e9ecef, #f8f9fa) !important;
            color: #000000 !important;
            font-weight: 600 !important;
            padding: 12px 8px !important;
            text-align: center !important;
            border: 1px solid #dee2e6 !important;
            font-size: 14px !important;
            text-transform: uppercase !important;
            letter-spacing: 0.5px !important;
          }
          .shiny-table-output td {
            padding: 10px 8px !important;
            border: 1px solid #e9ecef !important;
            text-align: center !important;
            vertical-align: middle !important;
            color: #000000 !important;
            font-weight: 500 !important;
          }
          .shiny-table-output tr:nth-child(even) {
            background-color: #f8f9fa !important;
          }
          .shiny-table-output tr:nth-child(odd) {
            background-color: white !important;
          }
          .shiny-table-output tr:hover {
            background-color: #e3f2fd !important;
            transform: scale(1.01) !important;
            transition: all 0.2s ease !important;
            box-shadow: 0 2px 8px rgba(0,0,0,0.1) !important;
          }
          .shiny-table-output .table {
            box-shadow: 0 4px 12px rgba(0,0,0,0.15) !important;
            border-radius: 8px !important;
            overflow: hidden !important;
            border: none !important;
          }
          .shiny-table-output .table-striped > tbody > tr:nth-of-type(odd) {
            background-color: white !important;
          }
          .shiny-table-output .table-striped > tbody > tr:nth-of-type(even) {
            background-color: #f8f9fa !important;
          }
          .shiny-table-output .table-hover > tbody > tr:hover {
            background-color: #e3f2fd !important;
          }
          .shiny-table-output .table-bordered {
            border: 1px solid #dee2e6 !important;
          }
          .shiny-table-output .table-bordered > thead > tr > th,
          .shiny-table-output .table-bordered > tbody > tr > td {
            border: 1px solid #dee2e6 !important;
          }
          
          /* Force all table text to be black with maximum specificity */
          .shiny-table-output,
          .shiny-table-output *,
          .shiny-table-output table,
          .shiny-table-output table *,
          .shiny-table-output thead,
          .shiny-table-output thead *,
          .shiny-table-output tbody,
          .shiny-table-output tbody *,
          .shiny-table-output tr,
          .shiny-table-output tr *,
          .shiny-table-output th,
          .shiny-table-output th *,
          .shiny-table-output td,
          .shiny-table-output td *,
          .shiny-table-output .table,
          .shiny-table-output .table *,
          .shiny-table-output .table-striped,
          .shiny-table-output .table-striped *,
          .shiny-table-output .table-hover,
          .shiny-table-output .table-hover *,
          .shiny-table-output .table-bordered,
          .shiny-table-output .table-bordered * {
            color: #000000 !important;
          }
          
          /* Override any Bootstrap or other framework styles */
          .shiny-table-output .text-white,
          .shiny-table-output .text-light,
          .shiny-table-output .text-muted {
            color: #000000 !important;
          }
        "))
      ),
      fluidRow(
        column(
          width = 12,
          shinydashboard::box(
            width = 12,
            title = tags$h3(icon("database"), " Load Data", style = "margin: 0; color: #000000;"),
            status = "primary",
            solidHeader = TRUE,
            collapsible = TRUE,
            background = "light-blue",
            fluidRow(
              column(
                width = 4,
                div(class = "well-panel",
                  style = "background: linear-gradient(135deg, #f8f9fa 0%, #e9ecef 100%); border: 1px solid #dee2e6; border-radius: 8px; box-shadow: 0 2px 4px rgba(0,0,0,0.1);",
                  tags$style(HTML("
                    .well-panel label, .well-panel .control-label { color: #000000 !important; }
                    .well-panel .form-control { color: #000000 !important; }
                    .well-panel strong { color: #000000 !important; }
                    .well-panel .checkbox label { color: #000000 !important; }
                    .well-panel .pretty-checkbox label { color: #000000 !important; }
                    .well-panel .shiny-input-container label { color: #000000 !important; }
                    .well-panel .form-group label { color: #000000 !important; }
                    .well-panel .file-input-container label { color: #000000 !important; }
                    .well-panel .selectize-input { color: #000000 !important; }
                    .well-panel .selectize-dropdown { color: #000000 !important; }
                    .well-panel .btn-file { color: #000000 !important; }
                    .well-panel .input-group-addon { color: #000000 !important; }
                    .well-panel .help-block { color: #000000 !important; }
                    .well-panel .text-muted { color: #000000 !important; }
                    .well-panel .text-info { color: #000000 !important; }
                    .well-panel .text-success { color: #000000 !important; }
                    .well-panel .text-warning { color: #000000 !important; }
                    .well-panel .text-danger { color: #000000 !important; }
                    .well-panel .pretty { color: #000000 !important; }
                    .well-panel .pretty .state label { color: #000000 !important; }
                    .well-panel .pretty .state label:before { color: #000000 !important; }
                    .well-panel .pretty .state label:after { color: #000000 !important; }
                    
                    /* Column type selector improvements */
                    .well-panel .column-type-row { 
                      background: #f8f9fa; 
                      border: 1px solid #e9ecef; 
                      border-radius: 6px; 
                      padding: 12px; 
                      margin-bottom: 8px; 
                      transition: all 0.3s ease;
                    }
                    .well-panel .column-type-row:hover { 
                      background: #e9ecef; 
                      border-color: #007bff; 
                      box-shadow: 0 2px 4px rgba(0,0,0,0.1);
                    }
                    .well-panel .column-type-row label { 
                      font-weight: bold; 
                      color: #495057 !important; 
                      margin-bottom: 8px; 
                    }
                    .well-panel .decimal-separator-section, .well-panel .date-format-section { 
                      background: #e7f3ff; 
                      border: 1px solid #b3d9ff; 
                      border-radius: 4px; 
                      padding: 8px; 
                      margin-top: 5px; 
                    }
                    .well-panel .decimal-separator-section label, .well-panel .date-format-section label { 
                      font-size: 12px; 
                      color: #0056b3 !important; 
                      font-weight: normal; 
                    }
                    
                    /* Table styling for the panel */
                    .well-panel .shiny-table-output table {
                      width: 100% !important;
                      border-collapse: collapse !important;
                      margin: 0 !important;
                      font-size: 13px !important;
                      font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif !important;
                      color: #000000 !important;
                    }
                    .well-panel .shiny-table-output th {
                      background: linear-gradient(135deg, #e9ecef, #f8f9fa) !important;
                      color: #000000 !important;
                      font-weight: 600 !important;
                      padding: 12px 8px !important;
                      text-align: center !important;
                      border: 1px solid #dee2e6 !important;
                      font-size: 14px !important;
                      text-transform: uppercase !important;
                      letter-spacing: 0.5px !important;
                    }
                    .well-panel .shiny-table-output td {
                      padding: 10px 8px !important;
                      border: 1px solid #e9ecef !important;
                      text-align: center !important;
                      vertical-align: middle !important;
                      color: #495057 !important;
                      font-weight: 500 !important;
                    }
                    .well-panel .shiny-table-output tr:nth-child(even) {
                      background-color: #f8f9fa !important;
                    }
                    .well-panel .shiny-table-output tr:nth-child(odd) {
                      background-color: white !important;
                    }
                    .well-panel .shiny-table-output tr:hover {
                      background-color: #e3f2fd !important;
                      transform: scale(1.01) !important;
                      transition: all 0.2s ease !important;
                      box-shadow: 0 2px 8px rgba(0,0,0,0.1) !important;
                    }
                    
                    /* Force all table text to be black in panel with maximum specificity */
                    .well-panel .shiny-table-output,
                    .well-panel .shiny-table-output *,
                    .well-panel .shiny-table-output table,
                    .well-panel .shiny-table-output table *,
                    .well-panel .shiny-table-output thead,
                    .well-panel .shiny-table-output thead *,
                    .well-panel .shiny-table-output tbody,
                    .well-panel .shiny-table-output tbody *,
                    .well-panel .shiny-table-output tr,
                    .well-panel .shiny-table-output tr *,
                    .well-panel .shiny-table-output th,
                    .well-panel .shiny-table-output th *,
                    .well-panel .shiny-table-output td,
                    .well-panel .shiny-table-output td *,
                    .well-panel .shiny-table-output .table,
                    .well-panel .shiny-table-output .table *,
                    .well-panel .shiny-table-output .table-striped,
                    .well-panel .shiny-table-output .table-striped *,
                    .well-panel .shiny-table-output .table-hover,
                    .well-panel .shiny-table-output .table-hover *,
                    .well-panel .shiny-table-output .table-bordered,
                    .well-panel .shiny-table-output .table-bordered * {
                      color: #000000 !important;
                    }
                    
                    /* Override any Bootstrap or other framework styles in panel */
                    .well-panel .shiny-table-output .text-white,
                    .well-panel .shiny-table-output .text-light,
                    .well-panel .shiny-table-output .text-muted {
                      color: #000000 !important;
                    }
                  ")),
                  tags$h4(icon("cog"), " Data Source Configuration", style = "color: #000000; margin-bottom: 20px; border-bottom: 2px solid #007bff; padding-bottom: 10px;"),
                  
                  # Help Button with improved styling
                  div(
                    style = "margin-bottom: 20px;",
                    shinyWidgets::actionBttn(
                      "helpload",
                      "Help Guide",
                      icon = icon("question-circle"),
                      style = "gradient",
                      block = TRUE,
                      color = "primary",
                      size = "sm"
                    )
                  ),
                  
                  # Help Modal
                  shinyBS::bsModal(
                    id="helploaddata",
                    title = tags$h3(icon("info-circle"), " Data Loading Guide"),
                    trigger = "helpload",
                    size="large",
                    tags$iframe(
                      src = "load_data.html",
                      width = "100%",
                      height = "1000px",
                      frameborder = 0,
                      scrolling = "auto"
                    )
                  ),
                  
                  # Example Data Section
                  div(
                    style = "background: #f8f9fa; padding: 15px; border-radius: 6px; margin-bottom: 20px; border-left: 4px solid #28a745;",
                    tags$h5(icon("flask"), " Example Data", style = "color: #000000; margin-bottom: 15px;"),
                    shinyWidgets::prettyCheckbox(
                      inputId = "example",
                      label = "Use example data set?",
                      value = FALSE,
                      status = "success",
                      shape = "round",
                      outline = TRUE
                    ),
                    conditionalPanel(
                      condition = "input.example == 1",
                      div(
                        style = "margin-top: 10px;",
                        selectInput('selexample',
                                   'Select Example Dataset:',
                                   choices = c("iris","fishes"),
                                   multiple = FALSE,
                                   selectize = TRUE)
                      )
                    )
                  ),
                  
                  # File Upload Section
                  div(
                    style = "background: #f8f9fa; padding: 15px; border-radius: 6px; margin-bottom: 20px; border-left: 4px solid #007bff;",
                    tags$h5(icon("upload"), " File Upload", style = "color: #000000; margin-bottom: 15px;"),
                    fileInput(
                      "file1",
                      "Choose File:",
                      accept = c(".csv", ".xlsx", ".xls"),
                      multiple = FALSE,
                      buttonLabel = "Browse...",
                      placeholder = "No file selected"
                    ),
                    selectInput(
                      inputId = "worksheet",
                      label = "Worksheet Name:",
                      choices = NULL,
                      selectize = TRUE
                    ),
                    div(
                      style = "margin-top: 15px; color: #000000;",
                      actionButton(
                        inputId = "getData",
                        label = "Load Data",
                        icon = icon("download"),
                        class = "btn-primary btn-block ",
                        style = "background: linear-gradient(45deg, #007bff, #0056b3); border: none; border-radius: 6px; padding: 10px;"
                      )
                    )
                  ),
                  
                  # Column Types Section
                  div(
                    style = "background: #f8f9fa; padding: 15px; border-radius: 6px; border-left: 4px solid #ffc107;",
                    tags$h5(icon("columns"), " Column Types Configuration", style = "color: #000000; margin-bottom: 15px; border-bottom: 2px solid #ffc107; padding-bottom: 8px;"),
                    
                    # Info panel
                    div(
                      style = "background: #fff3cd; border: 1px solid #ffeaa7; border-radius: 6px; padding: 10px; margin-bottom: 15px;",
                      tags$p(
                        icon("info-circle"), 
                        " Configure the data types for each column. This helps ensure proper data analysis.",
                        style = "margin: 0; color: #856404; font-size: 12px;"
                      )
                    ),
                    
                    # Column types selector with improved styling
                    div(
                      style = "max-height: 300px; overflow-y: auto; border: 1px solid #dee2e6; border-radius: 6px; padding: 10px; background: white; margin-bottom: 15px;",
                      uiOutput("type_selector")
                    ),
                    
                    # Apply button with improved styling
                    div(
                      style = "text-align: center;",
                      shinyWidgets::actionBttn(
                        "apply_types",
                        "Apply Column Types",
                        icon = icon("check-circle"),
                        style = "gradient",
                        block = TRUE,
                        color = "success",
                        size = "md"
                      )
                    ),
                    
                    # Status indicator
                    div(
                      id = "type_status",
                      style = "margin-top: 10px; text-align: center; display: none;",
                      tags$span(
                        icon("check-circle"),
                        " Column types applied successfully!",
                        style = "color: #28a745; font-weight: bold;"
                      )
                    )
                  )
                )
              ),
              
              # Main Panel with improved styling
              column(
                width = 8,
                div(
                  style = "background: white; border-radius: 8px; padding: 20px; box-shadow: 0 2px 4px rgba(0,0,0,0.1); min-height: 400px;",
                  tags$h4(icon("table"), " Data Preview", style = "color: #000000; margin-bottom: 20px; border-bottom: 2px solid #dee2e6; padding-bottom: 10px;"),
                  div(
                    style = "background: #f8f9fa; border-radius: 6px; padding: 15px; border-left: 4px solid #007bff;",
                    tags$style(HTML("
                      #table1, #table1 * { color: #000000 !important; }
                      #table1 table, #table1 table * { color: #000000 !important; }
                      #table1 th, #table1 th * { color: #000000 !important; }
                      #table1 td, #table1 td * { color: #000000 !important; }
                    ")),
                    tableOutput("table1")
                  )
                )
              )
            )
          )
        )
      )
    )

source(file.path(appDir, "pages/descriptive_statistics/cont_biv/graphic_summary.r"))
source(file.path(appDir, "pages/descriptive_statistics/cont_biv/dep_corr_study.r"))
continuous_variables_bivariate <- shinydashboard::tabItem(
  tabName = "Continuous_variables_bivariate",
  shinydashboard::box(
    height = "100%", width = 12, title = "Continuos variables",
    status = "primary",
    solidHeader = TRUE,
    collapsible = TRUE,
    sidebarPanel(
      shinyWidgets::actionBttn(
        "helpbivariate",
        "Help",
        icon = icon("question-circle"),
        style = "stretch",
        block = FALSE,
        color = "primary"
      ),
      shinyBS::bsModal(
        id = "modalHelpBivariate",
        title = "Help: Continuous variables (bivariate)",
        trigger = "helpbivariate",
        size = "large",
        tags$iframe(src = "continuous_variables_bivariate.html", width = "100%", height = "600px", frameborder = 0)
      ),
      selectizeInput("selvar1",
        "Variable 1 (x)",
        choices = NULL,
        multiple = FALSE
      ),
      selectizeInput("selvar2",
        "Variable 2 (y)",
        choices = NULL,
        multiple = FALSE
      ),
    conditionalPanel(
  condition = "input.bivariateTabs != 'Dependency_and_Correlation_Study'",
  shinyWidgets::prettyCheckbox(
    inputId = "Gruposcatter",
    label = "Statistics by group?",
    value = FALSE,
    status = "success"
  )
),
      conditionalPanel(
        condition = "input.Gruposcatter == 1",
        selectizeInput("selgruposcatter",
          "group by",
          choices = NULL,
          multiple = FALSE
        )
      )
    ),
    mainPanel(
      tabsetPanel(id = "bivariateTabs",
        Dependency_and_Correlation_Study,
        Graphic_summary_ContinuousBivariate
      )
    )
  )
)

graphical_summary <- tabPanel(
  "Graphic summary",
  div(style = "display: inline-block;vertical-align:top;
                        width: 150px;", shinyWidgets::pickerInput(
    inputId = "SelecTipografico",
    label = "Select :",
    choices = c(
      "",
      "Histogram",
      "Density",
      "Boxplot",
      "Violin",
      "Polygon",
      "Ogive"
    ),
    options = list(
      style = "btn-primary"
    )
  )), div(style = "display: inline-block; vertical-align:top; margin-left: 10px; padding-top: 25px;",
      prettySwitch(
        inputId = "horizontal_plot",
        label = "Horizontal", 
        status = "primary",
        slim = TRUE
      )
  ),
  conditionalPanel(
    condition = "input.SelecTipografico == 'Histogram'& input.Grupo == 0",
    plotOutput("plotdescript"),
    br(),
    downloadButton("ContinuousUnivariateHistogramDownloadGrupo", "Download Graph", class = "btn-primary"),
    br(), br(),
    shinyWidgets::dropdown(
      label = "Customize graph",
      tags$h3("Customize"),
      div(
        style = "display: inline-block;vertical-align:top; width: 100%; text-align: center; margin-bottom: 10px;",
        shinyWidgets::actionBttn(
          inputId = "resetHistogram",
          label = "Reset to Initial State",
          style = "bordered",
          color = "warning",
          size = "sm",
          icon = icon("refresh")
        )
      ),
      sliderInput("binsHist",
        "Bins",
        min = 4,
        max = 500,
        value = 10,
        step = 1
      ),
      div(
        style = "display: inline-block;vertical-align:top;
                               width: 150px;",
        selectInput("themeHist",
          " Theme",
          choices = names(themesb)
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        selectInput("fontH",
          " Font",
          choices = fuentes
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        textInput(
          "ylabHist",
          label = "ylab",
          value = "Write ylab..."
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        textInput(
          "xlabHist",
          label = "xlab",
          value = "Write xlab..."
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        colourInput(
          label = "Line_color",
          "linecolorHist", "red", palette = "square",
          showColour = "background"
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;", colourInput(
          label = "Fill_color",
          "fillHist", "blue", palette = "square",
          showColour = "background"
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        sliderInput(
          inputId = "lwdHist",
          label = "Line width",
          min = 0.1,
          max = 10,
          value = 1.5
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "fontHist",
          label = "Size font",
          min = 1,
          max = 50,
          value = 12
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "alphaHist",
          label = "alpha",
          min = 0.001,
          max = 1,
          value = 0.3
        )
      ),
      style = "unite",
      icon = icon("fish"),
      status = "primary",
      width = "500px",
      animate = shinyWidgets::animateOptions(
        enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
        exit = shinyWidgets::animations$fading_exits$fadeOutRightBig
      )
    )
  ),
  conditionalPanel(
    condition = "input.SelecTipografico == 'Histogram'& input.Grupo == 1",
    plotOutput("plotdescript2"),
    br(),
    downloadButton("ContinuousUnivariateHistogramDownloadNoGrupo", "Download Graph", class = "btn-primary"),
    br(), br(),
    shinyWidgets::dropdown(
      label = "Customize graph",
      tags$h3("Customize"),
      div(
        style = "display: inline-block;vertical-align:top; width: 100%; text-align: center; margin-bottom: 10px;",
        shinyWidgets::actionBttn(
          inputId = "resetHistogram2",
          label = "Reset to Initial State",
          style = "bordered",
          color = "warning",
          size = "sm",
          icon = icon("refresh")
        )
      ),
      sliderInput("binsHist2",
        "Bins",
        min = 4,
        max = 500,
        value = 10,
        step = 1
      ),
      div(
        style = "display: inline-block;vertical-align:top;
                               width: 150px;",
        selectInput("themeHist2",
          " Theme",
          choices = names(themesb)
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        selectInput("fontH2",
          " Font",
          choices = fuentes
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        selectInput("paletas",
          "Palletes",
          choices = paletas
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        textInput(
          "linecolorHist2",
          label = "Line color",
          value = "black"
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        textInput(
          "ylabHist2",
          label = "ylab",
          value = "Write ylab..."
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        textInput(
          "xlabHist2",
          label = "xlab",
          value = "Write xlab..."
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        sliderInput(
          inputId = "lwdHist2",
          label = "Line width",
          min = 0.1,
          max = 10,
          value = 2
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "fontHist2",
          label = "Size font",
          min = 1,
          max = 50,
          value = 12
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "alphaHist2",
          label = "alpha",
          min = 0.001,
          max = 1,
          value = 0.5
        )
      ),
      style = "unite",
      icon = icon("fish"),
      status = "primary",
      width = "500px",
      animate = shinyWidgets::animateOptions(
        enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
        exit = shinyWidgets::animations$fading_exits$fadeOutRightBig
      )
    )
  ),
  conditionalPanel(
    condition = "input.SelecTipografico == 'Density'& input.Grupo == 0",
    plotOutput("plotdescript3"),
    br(),
    downloadButton("ContinuousUnivariateDensityDownloadGrupo", "Download Graph", class = "btn-primary"),
    br(), br(),
    shinyWidgets::dropdown(
      label = "Customize graph",
      tags$h3("Customize"),
      div(
        style = "display: inline-block;vertical-align:top; width: 100%; text-align: center; margin-bottom: 10px;",
        shinyWidgets::actionBttn(
          inputId = "resetDensity",
          label = "Reset to Initial State",
          style = "bordered",
          color = "warning",
          size = "sm",
          icon = icon("refresh")
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;
                               width: 150px;",
        selectInput("themeDensy",
          " Theme",
          choices = names(themesb)
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        selectInput("fontdensy",
          " Font",
          choices = fuentes
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        colourInput(
          label = "Line_color",
          "linecolorDensy", "blue", palette = "square",
          showColour = "background"
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        colourInput(
          label = "Fill_color",
          "fillDensy", "blue", palette = "square",
          showColour = "background"
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        textInput(
          "ylabDensy",
          label = "ylab",
          value = "Write ylab..."
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        textInput(
          "xlabDensy",
          label = "xlab",
          value = "Write xlab..."
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        sliderInput(
          inputId = "lwdDensy",
          label = "Line width",
          min = 0.1,
          max = 10,
          value = 2
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "fontDensy",
          label = "Size font",
          min = 1,
          max = 50,
          value = 12
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "alphaDensy",
          label = "alpha",
          min = 0.001,
          max = 1,
          value = 0.5
        )
      ),
      style = "unite",
      icon = icon("fish"),
      status = "primary",
      width = "500px",
      animate = shinyWidgets::animateOptions(
        enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
        exit = shinyWidgets::animations$fading_exits$fadeOutRightBig
      )
    )
  ),
  conditionalPanel(
    condition = "input.SelecTipografico == 'Density'& input.Grupo == 1",
    plotOutput("plotdescript4"),
    br(),
    downloadButton("ContinuousUnivariateDensityDownloadNoGrupo", "Download Graph", class = "btn-primary"),
    br(), br(),
    shinyWidgets::dropdown(
      label = "Customize graph",
      tags$h3("Customize"),
      div(
        style = "display: inline-block;vertical-align:top; width: 100%; text-align: center; margin-bottom: 10px;",
        shinyWidgets::actionBttn(
          inputId = "resetDensity2",
          label = "Reset to Initial State",
          style = "bordered",
          color = "warning",
          size = "sm",
          icon = icon("refresh")
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;
                               width: 150px;",
        selectInput("themeDensy2",
          " Theme",
          choices = names(themesb)
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        selectInput("paletasDensy2",
          "Palletes",
          choices = paletas
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        selectInput("fontdensy2",
          " Font",
          choices = fuentes
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        selectInput("paletas",
          "Palletes",
          choices = paletas
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        textInput(
          "linecolorDensy2",
          label = "Line color",
          value = "black"
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        textInput(
          "ylabDensy2",
          label = "ylab",
          value = "Write ylab..."
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        textInput(
          "xlabDensy2",
          label = "xlab",
          value = "Write xlab..."
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        sliderInput(
          inputId = "lwdDensy2",
          label = "Line width",
          min = 0.1,
          max = 10,
          value = 2
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "fontDensy2",
          label = "Size font",
          min = 1,
          max = 50,
          value = 12
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "alphaDensy2",
          label = "alpha",
          min = 0.001,
          max = 1,
          value = 0.5
        )
      ),
      style = "unite",
      icon = icon("fish"),
      status = "primary",
      width = "500px",
      animate = shinyWidgets::animateOptions(
        enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
        exit = shinyWidgets::animations$fading_exits$fadeOutRightBig
      )
    )
  ),
  conditionalPanel(
    condition = "input.SelecTipografico == 'Boxplot'& input.Grupo == 0",
    plotOutput("plotdescript5"),
    br(),
    downloadButton("ContinuousUnivariateBoxplotDownloadGrupo", "Download Graph", class = "btn-primary"),
    br(), br(),
    shinyWidgets::dropdown(
      label = "Customize graph", tags$h3("Customize"),
      div(
        style = "display: inline-block;vertical-align:top; width: 100%; text-align: center; margin-bottom: 10px;",
        shinyWidgets::actionBttn(
          inputId = "resetBoxplot",
          label = "Reset to Initial State",
          style = "bordered",
          color = "warning",
          size = "sm",
          icon = icon("refresh")
        )
      ),
      div(style = "display: inline-block;vertical-align:top;
        width: 150px;", selectInput("themeboxplot", " Theme",
        choices = names(themesb)
      )),
      div(style = "display: inline-block;vertical-align:top;
        width: 150px;", selectInput("fontbox", " Font", choices = fuentes)),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        textInput("ylabboxplot",
          label = "ylab",
          value = "Write ylab..."
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        textInput("xlabboxplot",
          label = "xlab",
          value = "Write xlab..."
        )
      ),
      div(
        style = "display: inline-block;
        vertical-align:top; width: 150px;",
        colourInput(
          label = "Line_color",
          "linecolorboxplot", "black",
          palette = "square",
          showColour = "background"
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        colourInput(
          label = "Fill_color",
          "fillboxplot", "blue",
          palette = "square",
          showColour = "background"
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        colourInput(
          label = "Outlier_color",
          "coloroutlier", "red",
          palette = "square",
          showColour = "background"
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "lwdboxplot",
          label = "Line width",
          min = 0.1,
          max = 10,
          value = 1.5
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        sliderInput(
          inputId = "fontboxplot",
          label = "Size font",
          min = 1,
          max = 50,
          value = 12
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "pointboxplot",
          label = "Size point",
          min = 1,
          max = 10,
          value = 2
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "alphaboxplot",
          label = "alpha",
          min = 0.001,
          max = 1,
          value = 0.5
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "pchboxplot",
          label = " Point shape",
          min = 0,
          max = 25,
          value = 16
        )
      ),
      shinyWidgets::switchInput(
        inputId = "nocht",
        label = "Nocht",
        onLabel = "TRUE",
        offLabel = "FALSE",
        size = "mini"
      ),
      style = "unite",
      icon = icon("fish"),
      status = "primary",
      width = "500px",
      animate = shinyWidgets::animateOptions(
        enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
        exit = shinyWidgets::animations$fading_exits$fadeOutRightBig
      )
    ),
    h2("Outlier - No Group"),
    DT::DTOutput("outlierNoGroup")
  ),
  conditionalPanel(
    condition = "input.SelecTipografico == 'Boxplot'& input.Grupo == 1",
    plotOutput(outputId = "graph", brush = "plot_brush"),
    br(),
    downloadButton("ContinuousUnivariateBoxplotDownloadNoGrupo", "Download Graph", class = "btn-primary"),
    br(), br(),
    shinyWidgets::dropdown(
      label = "Customize graph", tags$h3("Customize"),
      div(style = "display: inline-block;vertical-align:top;
        width: 150px;", shinyWidgets::actionBttn(
        inputId = "resetBoxplot2",
        label = "Reset to Initial State",
        style = "bordered",
        color = "warning",
        size = "sm",
        icon = icon("refresh")
      )),
      div(style = "display: inline-block;vertical-align:top;
        width: 150px;", selectInput("themeboxplot2", " Theme",
        choices = names(themesb)
      )),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        selectInput("paletasboxplot2",
          "Palletes",
          choices = paletas
        )
      ),
      div(style = "display: inline-block;vertical-align:top;
        width: 150px;", selectInput("fontbox2", " Font", choices = fuentes)),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        textInput("ylabboxplot2",
          label = "ylab",
          value = "Write ylab..."
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        textInput("xlabboxplot2",
          label = "xlab",
          value = "Write xlab..."
        )
      ),
      div(
        style = "display: inline-block;
        vertical-align:top; width: 150px;",
        textInput("linecolorboxplot2",
          label = "Color box",
          value = "black"
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        colourInput("coloroutlier2", "red",
          label = "Color outlier"
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "lwdboxplot2",
          label = "Line width",
          min = 0.1,
          max = 10,
          value = 1.5
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        sliderInput(
          inputId = "fontboxplot2",
          label = "Size font",
          min = 1,
          max = 50,
          value = 12
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "pointboxplot2",
          label = "Size point",
          min = 1,
          max = 10,
          value = 2
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "alphaboxplot2",
          label = "alpha",
          min = 0.001,
          max = 1,
          value = 0.5
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "pchboxplot2",
          label = " Point shape",
          min = 0,
          max = 25,
          value = 16
        )
      ),
      shinyWidgets::switchInput(
        inputId = "nocht2",
        label = "Nocht",
        onLabel = "TRUE",
        offLabel = "FALSE",
        size = "mini"
      ),
      style = "unite",
      icon = icon("fish"),
      status = "primary",
      width = "500px",
      animate = shinyWidgets::animateOptions(
        enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
        exit = shinyWidgets::animations$fading_exits$fadeOutRightBig
      )
    ),
    h2("Outlier - Group"),
    DT::DTOutput("outlier")
  ),
  conditionalPanel(
    condition = "input.SelecTipografico == 'Violin'& input.Grupo == 0",
    plotOutput("plotdescript6"),
    br(),
    downloadButton("ContinuousUnivariateViolinDownloadGrupo", "Download Graph", class = "btn-primary"),
    br(), br(),
    shinyWidgets::dropdown(
      label = "Customize graph", tags$h3("Customize"),
      div(style = "display: inline-block;vertical-align:top;
        width: 150px;", shinyWidgets::actionBttn(
        inputId = "resetViolin",
        label = "Reset to Initial State",
        style = "bordered",
        color = "warning",
        size = "sm",
        icon = icon("refresh")
      )),
      div(style = "display: inline-block;vertical-align:top;
        width: 150px;", selectInput("themeviolin", " Theme",
        choices = names(themesb)
      )),
      div(style = "display: inline-block;vertical-align:top;
        width: 150px;", selectInput("fontviolin", " Font", choices = fuentes)),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        textInput("ylabviolin",
          label = "ylab",
          value = "Write ylab..."
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        textInput("xlabviolin",
          label = "xlab",
          value = "Write xlab..."
        )
      ),
      div(
        style = "display: inline-block;
        vertical-align:top; width: 150px;",
        textInput("linecolorviolin",
          label = "Color line",
          value = "red"
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        textInput("fillviolin",
          label = "Color fill",
          value = "#0095ff"
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "lwdviolin",
          label = "Line width",
          min = 0.1,
          max = 10,
          value = 1.5
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        sliderInput(
          inputId = "fontSviolin",
          label = "Size font",
          min = 1,
          max = 50,
          value = 12
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "alphaviolin",
          label = "alpha",
          min = 0.001,
          max = 1,
          value = 0.5
        )
      ),
      shinyWidgets::switchInput(
        inputId = "trim",
        label = "Trim",
        onLabel = "TRUE",
        offLabel = "FALSE",
        size = "mini"
      ),
      style = "unite",
      icon = icon("fish"),
      status = "primary",
      width = "500px",
      animate = shinyWidgets::animateOptions(
        enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
        exit = shinyWidgets::animations$fading_exits$fadeOutRightBig
      )
    )
  ),
  conditionalPanel(
    condition = "input.SelecTipografico == 'Violin'& input.Grupo == 1",
    plotOutput("plotdescript7"),
    br(),
    downloadButton("ContinuousUnivariateViolinDownloadNoGrupo", "Download Graph", class = "btn-primary"),
    br(), br(),
    shinyWidgets::dropdown(
      label = "Customize graph", tags$h3("Customize"),
      div(style = "display: inline-block;vertical-align:top;
        width: 150px;", shinyWidgets::actionBttn(
        inputId = "resetViolin2",
        label = "Reset to Initial State",
        style = "bordered",
        color = "warning",
        size = "sm",
        icon = icon("refresh")
      )),
      div(style = "display: inline-block;vertical-align:top;
        width: 150px;", selectInput("themeviolin2", " Theme",
        choices = names(themesb)
      )),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        selectInput("paletasviolin",
          "Palletes",
          choices = paletas
        )
      ),
      div(style = "display: inline-block;vertical-align:top;
        width: 150px;", selectInput("fontviolin2", " Font", choices = fuentes)),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        textInput("ylabviolin2",
          label = "ylab",
          value = "Write ylab..."
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        textInput("xlabviolin2",
          label = "xlab",
          value = "Write xlab..."
        )
      ),
      div(
        style = "display: inline-block;
        vertical-align:top; width: 150px;",
        textInput("linecolorviolin2",
          label = "Color line",
          value = "red"
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "lwdviolin2",
          label = "Line width",
          min = 0.1,
          max = 10,
          value = 1.5
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        sliderInput(
          inputId = "fontSviolin2",
          label = "Size font",
          min = 1,
          max = 50,
          value = 12
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "alphaviolin2",
          label = "alpha",
          min = 0.001,
          max = 1,
          value = 0.5
        )
      ),
      shinyWidgets::switchInput(
        inputId = "trim2",
        label = "Trim",
        onLabel = "TRUE",
        offLabel = "FALSE",
        size = "mini"
      ),
      style = "unite",
      icon = icon("fish"),
      status = "primary",
      width = "500px",
      animate = shinyWidgets::animateOptions(
        enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
        exit = shinyWidgets::animations$fading_exits$fadeOutRightBig
      )
    )
  ),

  # =====================================================================
  # POLYGON PLOTS
  # =====================================================================

  # Polygon without groups
  conditionalPanel(
    condition = "input.SelecTipografico == 'Polygon'& input.Grupo == 0",
    plotOutput("plotdescript8"),
    br(),
    downloadButton("ContinuousUnivariatePolygonDownloadGrupo", "Download Graph", class = "btn-primary"),
    br(), br(),
    shinyWidgets::dropdown(
      label = "Customize graph",
      tags$h3("Customize"),
      div(
        style = "display: inline-block; vertical-align: top; width: 100%; text-align: center; margin-bottom: 10px;",
        shinyWidgets::actionBttn(
          inputId = "resetPolygon",
          label = "Reset to Initial State",
          style = "bordered",
          color = "warning",
          size = "sm",
          icon = icon("refresh")
        )
      ),
      sliderInput("binsPolygon", "Bins", min = 4, max = 500, value = 10, step = 1),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        selectInput("themePolygon", " Theme", choices = names(themesb))
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        selectInput("fontPolygon", "Font", choices = fuentes)
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        textInput("ylabPolygon", label = "ylab", value = "Frequency")
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        textInput("xlabPolygon", label = "xlab", value = "Values")
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        colourInput(
          label = "Line_color",
          "linecolorPolygon", "blue", palette = "square",
          showColour = "background"
        )
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        colourInput(
          label = "Point_color",
          "pointcolorPolygon", "red", palette = "square",
          showColour = "background"
        )
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        sliderInput(
          inputId = "lwdPolygon",
          label = "Line width",
          min = 0.1, max = 10, value = 2
        )
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        sliderInput(
          inputId = "fontSizePolygon",
          label = "Size font",
          min = 1, max = 50, value = 12
        )
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        sliderInput(
          inputId = "pointsizePolygon",
          label = "Point size",
          min = 1, max = 10, value = 3
        )
      ),
      style = "unite",
      icon = icon("fish"),
      status = "primary",
      width = "500px",
      animate = shinyWidgets::animateOptions(
        enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
        exit = shinyWidgets::animations$fading_exits$fadeOutRightBig
      )
    )
  ),

  # Polygon with groups
  conditionalPanel(
    condition = "input.SelecTipografico == 'Polygon'& input.Grupo == 1",
    plotOutput("plotdescript9"),
    br(),
    downloadButton("ContinuousUnivariatePolygonDownloadNoGrupo", "Download Graph", class = "btn-primary"),
    br(), br(),
    shinyWidgets::dropdown(
      label = "Customize graph",
      tags$h3("Customize"),
      div(
        style = "display: inline-block; vertical-align: top; width: 100%; text-align: center; margin-bottom: 10px;",
        shinyWidgets::actionBttn(
          inputId = "resetPolygon2",
          label = "Reset to Initial State",
          style = "bordered",
          color = "warning",
          size = "sm",
          icon = icon("refresh")
        )
      ),
      sliderInput("binsPolygon2", "Bins", min = 4, max = 500, value = 10, step = 1),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        selectInput("themePolygon2", " Theme", choices = names(themesb))
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        selectInput("paletasPolygon", "Palletes", choices = paletas)
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        selectInput("fontPolygon2", " Font", choices = fuentes)
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        textInput("ylabPolygon2", label = "ylab", value = "Frequency")
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        textInput("xlabPolygon2", label = "xlab", value = "Values")
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        sliderInput(
          inputId = "lwdPolygon2",
          label = "Line width",
          min = 0.1, max = 10, value = 2
        )
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        sliderInput(
          inputId = "fontSizePolygon2",
          label = "Size font",
          min = 1, max = 50, value = 12
        )
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        sliderInput(
          inputId = "pointsizePolygon2",
          label = "Point size",
          min = 1, max = 10, value = 3
        )
      ),
      style = "unite",
      icon = icon("fish"),
      status = "primary",
      width = "500px",
      animate = shinyWidgets::animateOptions(
        enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
        exit = shinyWidgets::animations$fading_exits$fadeOutRightBig
      )
    )
  ),

  # =====================================================================
  # OGIVE PLOTS
  # =====================================================================

  # Ogive without groups
  conditionalPanel(
    condition = "input.SelecTipografico == 'Ogive'& input.Grupo == 0",
    plotOutput("plotdescript10"),
    br(),
    downloadButton("ContinuousUnivariateOgiveDownloadGrupo", "Download Graph", class = "btn-primary"),
    br(), br(),
    shinyWidgets::dropdown(
      label = "Customize graph",
      tags$h3("Customize"),
      div(
        style = "display: inline-block; vertical-align: top; width: 100%; text-align: center; margin-bottom: 10px;",
        shinyWidgets::actionBttn(
          inputId = "resetOgive",
          label = "Reset to Initial State",
          style = "bordered",
          color = "warning",
          size = "sm",
          icon = icon("refresh")
        )
      ),
      sliderInput("binsOgive", "Bins", min = 4, max = 500, value = 10, step = 1),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        selectInput("themeOgive", " Theme", choices = names(themesb))
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        selectInput(
          "fontOgive", " Font",
          choices = fuentes
        )
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        textInput("ylabOgive", label = "ylab", value = "Cumulative Frequency")
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        textInput("xlabOgive", label = "xlab", value = "Values")
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        colourInput(
          label = "Line_color",
          "linecolorOgive", "darkgreen", palette = "square",
          showColour = "background"
        )
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        colourInput(
          label = "Point_color",
          "pointcolorOgive", "orange", palette = "square",
          showColour = "background"
        )
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        sliderInput(
          inputId = "lwdOgive",
          label = "Line width",
          min = 0.1, max = 10, value = 2
        )
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        sliderInput(
          inputId = "fontSizeOgive",
          label = "Size font",
          min = 1, max = 50, value = 12
        )
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        sliderInput(
          inputId = "pointsizeOgive",
          label = "Point size",
          min = 1, max = 10, value = 3
        )
      ),
      style = "unite",
      icon = icon("fish"),
      status = "primary",
      width = "500px",
      animate = shinyWidgets::animateOptions(
        enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
        exit = shinyWidgets::animations$fading_exits$fadeOutRightBig
      )
    )
  ),

  # Ogive with groups
  conditionalPanel(
    condition = "input.SelecTipografico == 'Ogive'& input.Grupo == 1",
    plotOutput("plotdescript11"),
    br(),
    downloadButton("ContinuousUnivariateOgiveDownloadNoGrupo", "Download Graph", class = "btn-primary"),
    br(), br(),
    shinyWidgets::dropdown(
      label = "Customize graph",
      tags$h3("Customize"),
      div(
        style = "display: inline-block; vertical-align: top; width: 100%; text-align: center; margin-bottom: 10px;",
        shinyWidgets::actionBttn(
          inputId = "resetOgive2",
          label = "Reset to Initial State",
          style = "bordered",
          color = "warning",
          size = "sm",
          icon = icon("refresh")
        )
      ),
      sliderInput("binsOgive2", "Bins", min = 4, max = 500, value = 10, step = 1),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        selectInput("themeOgive2", " Theme", choices = names(themesb))
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        selectInput("paletasOgive", "Palletes", choices = paletas)
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        selectInput("fontOgive2", " Font", choices = fuentes)
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        textInput("ylabOgive2", label = "ylab", value = "Cumulative Frequency")
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        textInput("xlabOgive2", label = "xlab", value = "Values")
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        sliderInput(
          inputId = "lwdOgive2",
          label = "Line width",
          min = 0.1, max = 10, value = 2
        )
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        sliderInput(
          inputId = "fontSizeOgive2",
          label = "Size font",
          min = 1, max = 50, value = 12
        )
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        sliderInput(
          inputId = "pointsizeOgive2",
          label = "Point size",
          min = 1, max = 10, value = 3
        )
      ),
      style = "unite",
      icon = icon("fish"),
      status = "primary",
      width = "500px",
      animate = shinyWidgets::animateOptions(
        enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
        exit = shinyWidgets::animations$fading_exits$fadeOutRightBig
      )
    )
  )
)

source(file.path(appDir, "pages/descriptive_statistics/qual_vars/tabular_summary.r"), local = TRUE)
source(file.path(appDir, "pages/descriptive_statistics/qual_vars/graphic_summaries.r"), local = TRUE)
qualitative_variables <- shinydashboard::tabItem( tabName = "Qualitative_variables",
     shinydashboard::box(   height =  "100%",   width = 12,  title = "Qualitative variables",
       status = "primary",
       solidHeader = TRUE,
       collapsible = TRUE,
       sidebarPanel(
         shinyWidgets::actionBttn(
           "helpquali",
           "Help",
           icon = icon("question-circle"),
           style = "stretch",
           block = FALSE,
           color = "primary"
         ),
         shinyBS::bsModal(
           id = "modalHelpQuali",
           title = "Help: Qualitative Variables",
           trigger = "helpquali",
           size = "large",
           tags$iframe(src = "qualitative_variables.html", width = "100%", height = "600px", frameborder = 0)
         ),
         selectizeInput('selvarcuali',
                        'Qualitative variable',
                        choices = NULL,
                        multiple = FALSE),
         shinyWidgets::prettyCheckbox(
           inputId = "GrupoQuali",
           label = "Statistics by group?",
           value = FALSE,
           status = "success"
         ),
         conditionalPanel(
           condition = "input.GrupoQuali == 1",
           selectizeInput('selgrupoQuali',
                          'Group by',
                          choices = NULL,
                          multiple = TRUE,
                      
                          )
           )
       ),
       mainPanel(
         tabsetPanel(
           tabular_summary,
           graphic_summaries))
       )
     )

multivariate <- shinydashboard::tabItem( tabName = "Multivariate",
     shinydashboard::box( height =  "100%", width = 12,title = "Multivariate",
       status = "primary",
       solidHeader = TRUE,
       collapsible = TRUE,
       sidebarPanel(
          shinyWidgets::actionBttn(
            "helpmulti",
            "Help",
            icon = icon("question-circle"),
            style = "stretch",
            block = FALSE,
            color = "primary"
          ),
          shinyBS::bsModal(
            id = "modalHelpMulti",
            title = "Help: Multivariate",
            trigger = "helpmulti",
            size = "large",
            tags$iframe(src = "multivariate.html", width = "100%", height = "600px", frameborder = 0)
          ),
         selectizeInput('selmulti',
                        'Variables',
                        choices = NULL,
                        multiple = TRUE),
         shinyWidgets::prettyCheckbox(
           inputId = "Grupomulti",
           label = "Statistics by group?",
           value = FALSE,
           status = "success"
         )

         ),
       mainPanel(
         tabsetPanel(
           tabPanel("Summaries",
                    br(), strong(h2("Correlation matrix")),
                    DT::DTOutput("cormat"),
                    br(), strong(h2("Variances and covariances matrix")),
                    DT::DTOutput("covmat"),br()
                     ),
       
                    
         )
       )
     )
   )

################################# Header #######################################
source("header.R")
#####################################Header Fin ################################
#######################################Sidebar #################################
source("sidebar.R")
source("pages/tab0_about.R", local = TRUE)
source("pages/discrete_prob_distributions.R", local = TRUE)
source("pages/continuous_prob_distributions.R", local = TRUE)
source("pages/load_data.R", local=TRUE)
source("pages/univariate_main.R",local=TRUE)
source("pages/qualitative_main.R", local = TRUE)
source("pages/bivariate_main.R", local = TRUE)
source("pages/multivariate.R", local = TRUE)
##############<#######################Sidebar Fin ###############################
####################################Body #######################################
body <- shinydashboard::dashboardBody(
  height = "auto",
  width = "100p%",
 tags$head(
  tags$style(HTML(
  '/* logo when hovered */
  .skin-blue .main-header .logo:hover {
  background-color: #3991e3;}
  /* navbar (rest of the header) */
  .skin-blue .main-header .navbar {
  background-color: #3991e3;}
  /* main sidebar */
  .skin-blue .main-sidebar {
  background-color: #3991e3;}
  /* active selected tab in the sidebarmenu */
  .skin-blue .main-sidebar .sidebar .sidebar-menu .active a{
  background-color: #0091ff;}
  /* other links in the sidebarmenu */
  .skin-blue .main-sidebar .sidebar .sidebar-menu a{
  background-color: #ccdceb;
  color: #000000;}
  /* other links in the sidebarmenu when hovered */
  .skin-blue .main-sidebar .sidebar .sidebar-menu a:hover{
  background-color: #69c3ff;}
  /* toggle button when hovered  */
  .skin-blue .main-header .navbar .sidebar-toggle:hover{
  background-color: #9bc2e8;}
  /* body */
  .content-wrapper, .right-side {
  background-color: #7da2d1;}')
  )
  ),
 shinydashboard::tabItems(
  tab0_about,
  discrete_probability_distributions,
  continuous_probability_distribution,
   load_dataPage,
  continuous_variables_univariate,
  qualitative_variables,
  continuous_variables_bivariate,
  multivariate
  )#fintabItems
)
####################################Body Fin #################################
shinydashboard::dashboardPage(header, sidebar, body)

Dependency_and_Correlation_Study <- tabPanel(
  "Dependency and Correlation Study", value = "Dependency_and_Correlation_Study",
  div(
    style = "display: inline-block;vertical-align:top;width: 220px;",
    shinyWidgets::pickerInput(
      inputId = "correlation",
      label = "Correlation method:",
      choices = c("All", "Pearson", "Spearman", "Kendall"),
      selected = "All",
      options = list(style = "btn-primary")
    )
  ),
  br(),
  DT::DTOutput("bivar_metrics")
)

# =============================================================================
# Continuous Variables Univariate Analysis - Main Module
# =============================================================================
# This file serves as the main entry point for the continuous variables 
# univariate analysis module. It sources the individual tab components
# and assembles them into the complete UI.
# =============================================================================

# =============================================================================
# SOURCE INDIVIDUAL TAB COMPONENTS
# =============================================================================

# Load numerical summary tab component
source(file.path(appDir, "pages/descriptive_statistics/cont_univ/numerical_summary.r"), local = TRUE)

# Load tabular summary tab component  
source(file.path(appDir, "pages/descriptive_statistics/cont_univ/tabular_summary.r"), local = TRUE)

# Load graphical summary tab component
source(file.path(appDir, "pages/descriptive_statistics/cont_univ/graphical_summary.r"), local = TRUE)

# =============================================================================
# MAIN UI COMPONENT
# =============================================================================

continuous_variables_univariate <- shinydashboard::tabItem(
  tabName = "Continuous_variables_univariate",
  
  # Main container box
  shinydashboard::box(
    height = "100%",
    width = 12,
    title = "Descriptive Statistics for Continuous Variables",
    status = "primary",
    solidHeader = TRUE,
    collapsible = TRUE,
    
    # =====================================================================
    # SIDEBAR PANEL - Controls and Options
    # =====================================================================
    sidebarPanel(
      
      # Help button and modal
      shinyWidgets::actionBttn(
        "helpuni",
        "Help",
        icon = icon("question-circle"),
        style = "stretch",
        block = FALSE,
        color = "primary"
      ),
      
      # Help modal with documentation
      shinyBS::bsModal(
        id = "modalHelpUni",
        title = "Help: Continuous Variables (Univariate)",
        trigger = "helpuni",
        size = "large",
        tags$iframe(
          src = "continuous_variables_univariate.html", 
          width = "100%", 
          height = "600px", 
          frameborder = 0
        )
      ),
      
      # Variable selection
      selectizeInput(
        'selvarcuanti',
        'Select Quantitative Variable',
        choices = NULL,
        multiple = FALSE
      ),
      
      # Group analysis option
      shinyWidgets::prettyCheckbox(
        inputId = "Grupo",
        label = "Statistics by group?",
        value = FALSE,
        status = "success"
      ),
      
      # Group variable selection (conditional)
      conditionalPanel(
        condition = "input.Grupo == 1",
        selectizeInput(
          'selgrupo',
          'Group by (max 2 variables)',
          choices = NULL,
          multiple = TRUE,
          options = list(maxItems = 2)
        )
      )
    ),
    
    # =====================================================================
    # MAIN PANEL - Content Tabs
    # =====================================================================
    mainPanel(
      
      # Tab navigation
      tabsetPanel(
        type = "tabs",
        
        # Numerical summary tab
        numerical_summary,
        
        # Tabular summary tab
        tabular_summary,
        
        # Graphical summary tab
        graphical_summary
      )
    )
  )
)

# header.R
library(shinydashboard)

header <- dashboardHeader(
  title = "StatisticTeach1",
  titleWidth = 280,
  tags$li(
    class = "dropdown",
    actionLink(
      "stop_radiant",
      "Stop",
      icon = icon("power-off"),
      onclick = "setTimeout(function(){window.close();}, 100);")
  )
)

# global.R — loaded once when the Shiny app starts
# Packages are loaded here so all app files (ui.R, server.R, pages/) share them.
# library() calls in inst/ Shiny apps are accepted by CRAN policy.

library(shiny)
library(shinydashboard)
library(shinyBS)
library(shinyjs)
library(shinyWidgets)
library(dplyr)
library(ggplot2)
library(rlang)
library(magrittr)
library(descriptr)
library(DescTools)
library(RColorBrewer)
library(readxl)
library(mixdist)
library(tibble)
library(tidyr)
library(colourpicker)
library(DT)

# ── Helper functions ──────────────────────────────────────────────────────────

kurtosis <- function(x) {
  m4 <- mean((x - mean(x))^4)
  m4 / (sd(x)^4) - 3
}

kurtosis_standardized <- function(x) {
  n  <- length(x)
  m4 <- mean((x - mean(x))^4)
  (m4 / (sd(x)^4)) - 3 * ((n - 1) / ((n - 2) * (n - 3)))
}

skewness <- function(x) {
  m3 <- mean((x - mean(x))^3)
  m3 / (sd(x)^3)
}

skewness_standardized <- function(x) {
  n   <- length(x)
  m3  <- mean((x - mean(x))^3)
  s3  <- sd(x)^3
  (m3 / s3) * sqrt(n * (n - 1)) / (n - 2)
}

geometric.mean <- function(x, na.rm = TRUE) {
  if (is.null(nrow(x))) {
    exp(mean(log(x), na.rm = na.rm))
  } else {
    exp(apply(log(x), 2, mean, na.rm = na.rm))
  }
}

bsModalNoClose <- function(...) {
  b <- shinyBS::bsModal(...)
  b[[2]]$`data-backdrop` <- "static"
  b[[2]]$`data-keyboard` <- "false"
  b
}

# ── ggplot themes and aesthetic options ───────────────────────────────────────

themesb <- list(
  "grey"     = ggplot2::theme_grey(),
  "minimal"  = ggplot2::theme_minimal(),
  "bw"       = ggplot2::theme_bw(),
  "classic"  = ggplot2::theme_classic(),
  "linedraw" = ggplot2::theme_linedraw(),
  "light"    = ggplot2::theme_light(),
  "dark"     = ggplot2::theme_dark(),
  "test"     = ggplot2::theme_test(),
  "void"     = ggplot2::theme_void()
)

fuentes <- list(
  "mono"      = "mono",
  "sans"      = "sans",
  "serif"     = "serif",
  "Courier"   = "Courier",
  "Helvetica" = "Helvetica",
  "Times"     = "Times",
  "Palatino"  = "Palatino"
)

paletas <- c(
  "Accent", "Dark2", "Paired", "Pastel1", "Pastel2", "Set1", "Set2",
  "Blues", "BuGn", "BuPu", "GnBu", "Greens", "Greys",
  "Oranges", "OrRd", "PuBu", "PuBuGn", "PuRd", "Purples",
  "RdPu", "Reds", "YlGn", "YlGnBu", "YlOrBr", "YlOrRd",
  "BrBG", "PiYG", "PRGn", "PuOr", "RdBu", "RdGy", "RdYlBu",
  "RdYlGn", "Spectral", "Set3"
)

# ── Multivariate global measures ─────────────────────────────────────────────

Multiva <- function(datos) {
  n <- nrow(datos)
  p <- ncol(datos)
  vector.uno    <- matrix(rep(1, n), ncol = 1)
  vector.media  <- (t(datos) %*% vector.uno) / n
  S             <- cov(datos) * (n - 1) / n
  DN            <- diag(1 / sqrt(diag(S)))
  VT <- sum(diag(S))
  VM <- VT / p
  VG <- det(S)
  VE <- VG^(1 / p)
  cat("----------------------------------------------------------------\n")
  cat("-Global measures of variability\n",
      "1.- Total variance =", VT, "\n",
      "2.- Mean variance =", VM, "\n",
      "3.- Generalized Variance =", VG, "\n",
      "4.- Effective Variance =", VE, "\n")
  cat("----------------------------------------------------------------\n")
}

# ── Quantile helper for probability distributions ────────────────────────────

valor_x_lower <- function(distr, prob, df = NULL, param1 = NULL, param2 = NULL) {
  switch(distr,
    "Normal"      = qnorm(prob),
    "t-Student"   = qt(prob, df = df, lower.tail = TRUE),
    "Chi^2"       = qchisq(prob, df = df, lower.tail = TRUE),
    "F-Fisher"    = qf(prob, df1 = param1, df2 = param2, lower.tail = TRUE),
    "Exponential" = qexp(prob, rate = param1, lower.tail = TRUE),
    "Logistics"   = qlogis(prob, location = param1, scale = param2, lower.tail = TRUE),
    "Log-Normal"  = qlnorm(prob, meanlog = param1, sdlog = param2, lower.tail = TRUE),
    "Gamma"       = qgamma(prob, shape = param1, rate = param2, lower.tail = TRUE),
    "Weibull"     = qweibull(prob, shape = param1, scale = param2, lower.tail = TRUE),
    "Beta"        = qbeta(prob, shape1 = param1, shape2 = param2, lower.tail = TRUE),
    stop("Distribution not supported.", call. = FALSE)
  )
}

# sidebar.R
library(shinydashboard)

sidebar <- dashboardSidebar(
  width = 280, 
  sidebarMenu(
    menuItem("About StatisticTeach1", tabName = "tab0"),
    menuItem("Descriptive statistics", tabName = "tab3", icon = icon("chart-bar"),
             menuItem("Load data", tabName = "Load_data", icon = icon("file-import")),
             menuSubItem("Continuous variables (univariate)", tabName = "Continuous_variables_univariate"),
             menuSubItem("Continuous variables (bivariate)", tabName = "Continuous_variables_bivariate"),
             menuSubItem("Qualitative variables", tabName = "Qualitative_variables"),
             menuSubItem("Multivariate", tabName = "Multivariate")
    ),
    menuItem("Probability distributions", tabName = "tab1", icon = icon("dice"),
             menuSubItem("Discrete", tabName = "Discrete", icon = icon("chart-bar")),
             menuSubItem("Continuous", tabName = "Continuous", icon = tags$img(src = "normal1.png", width = "35px"))
    )
  )
)

tabular_summary <- tabPanel("Tabular summary",
                     div(style="display: inline-block;vertical-align:top;
                        width: 150px;",shinyWidgets::pickerInput(
                          inputId = "Selectrule",
                          label = "Select rule :",
                          choices = c("",
                                      "Sturges",
                                      "Sqrt",
                                      "Scott",
                                      "Freedman–Diaconis",
                                      "Number of bin"),
                          options = list(
                            style = "btn-primary")),

                     ),
                     conditionalPanel(
                       condition = "input.Selectrule == 'Number of bin'",
                       sliderInput("intervalnum",
                                   "",
                                   min = 4,
                                   max = 50,
                                   value = 5,
                                   step = 1)
                     ),
                     br(),
                     actionButton(
                       inputId = "getTable",
                       label="Get table"), br(),br(),

                     DT::DTOutput("tablefreq")
                     )

numerical_summary <- tabPanel("Numerical summary",
              div(style="display: inline-block;vertical-align:top;
                        width: 180px;",
                  shinyWidgets::pickerInput(
                    inputId = "NumSu",
                    label = "Select measures of:",
                    choices = c("",
                                "Central tendency",
                                "Dispersion or variability",
                                "Relative position",
                                "Shape"),
                    options = list(
                      style = "btn-primary"))),
              conditionalPanel(
                condition = "input.NumSu == 'Central tendency'",
                DT::DTOutput("central"),
              ),
              conditionalPanel(
                condition = "input.NumSu == 'Dispersion or variability'",
                DT::DTOutput("variability"),
              ),
              conditionalPanel(
                condition = "input.NumSu == 'Relative position'",
                div(style="display: inline-block;vertical-align:top;
                        width: 180px;",
                    shinyWidgets::pickerInput(
                      inputId = "relpos",
                      label = "Select measures of:",
                      choices = c("Quartiles","Percentiles"),
                      options = list(
                        style = "btn-default")))
              ),
              conditionalPanel( condition = "input.relpos == 'Quartiles' && input.NumSu == 'Relative position'",
                div(style="display: inline-block;vertical-align:top;
                        width: 180px;",
                    numericInput(inputId= "nquartiles", "Number of quartiles to calculate:",
                                 value = 3, min = 2, max = 10, step = 1, width = "90%")),
                DT::DTOutput("quart")
              ),
              conditionalPanel(
                condition = "input.relpos == 'Percentiles'",
                div(style="display: inline-block;vertical-align:top;
                        width: 180px;",
                numericInput(inputId= "npercent", "Enter the desired percentile (between 1 and 99):",
                             value = 90, min = 1, max = 99, step = 1, width = "90%")),
                   verbatimTextOutput("perc"),
                DT::DTOutput("perct")
              ),
              conditionalPanel( condition = "input.NumSu == 'Shape'",
                DT::DTOutput("shape")
              )
              )

library(shinyWidgets)
graphical_summary <- tabPanel(
  "Graphic summary",
  div(style = "display: inline-block;vertical-align:top;
                        width: 150px;", shinyWidgets::pickerInput(
    inputId = "SelecTipografico",
    label = "Select :",
    choices = c(
      "",
      "Histogram",
      "Density",
      "Boxplot",
      "Violin",
      "Polygon",
      "Ogive"
    ),
    options = list(
      style = "btn-primary"
    )
  )), div(style = "display: inline-block; vertical-align:top; margin-left: 10px; padding-top: 25px;",
      prettySwitch(
        inputId = "horizontal_plot",
        label = "Horizontal", 
        status = "primary",
        slim = TRUE
      )
  ),
  conditionalPanel(
    condition = "input.SelecTipografico == 'Histogram'& input.Grupo == 0",
    plotOutput("plotdescript"),
    br(),
    downloadButton("ContinuousUnivariateHistogramDownloadGrupo", "Download Graph", class = "btn-primary"),
    br(), br(),
    shinyWidgets::dropdown(
      label = "Customize graph",
      tags$h3("Customize"),
      div(
        style = "display: inline-block;vertical-align:top; width: 100%; text-align: center; margin-bottom: 10px;",
        shinyWidgets::actionBttn(
          inputId = "resetHistogram",
          label = "Reset to Initial State",
          style = "bordered",
          color = "warning",
          size = "sm",
          icon = icon("refresh")
        )
      ),
      sliderInput("binsHist",
        "Bins",
        min = 4,
        max = 500,
        value = 10,
        step = 1
      ),
      div(
        style = "display: inline-block;vertical-align:top;
                               width: 150px;",
        selectInput("themeHist",
          " Theme",
          choices = names(themesb)
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        selectInput("fontH",
          " Font",
          choices = fuentes
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        textInput(
          "ylabHist",
          label = "ylab",
          value = "Write ylab..."
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        textInput(
          "xlabHist",
          label = "xlab",
          value = "Write xlab..."
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        colourInput(
          label = "Line_color",
          "linecolorHist", "red", palette = "square",
          showColour = "background"
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;", colourInput(
          label = "Fill_color",
          "fillHist", "blue", palette = "square",
          showColour = "background"
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        sliderInput(
          inputId = "lwdHist",
          label = "Line width",
          min = 0.1,
          max = 10,
          value = 1.5
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "fontHist",
          label = "Size font",
          min = 1,
          max = 50,
          value = 12
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "alphaHist",
          label = "alpha",
          min = 0.001,
          max = 1,
          value = 0.3
        )
      ),
      style = "unite",
      icon = icon("fish"),
      status = "primary",
      width = "500px",
      animate = shinyWidgets::animateOptions(
        enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
        exit = shinyWidgets::animations$fading_exits$fadeOutRightBig
      )
    )
  ),
  conditionalPanel(
    condition = "input.SelecTipografico == 'Histogram'& input.Grupo == 1",
    plotOutput("plotdescript2"),
    br(),
    downloadButton("ContinuousUnivariateHistogramDownloadNoGrupo", "Download Graph", class = "btn-primary"),
    br(), br(),
    shinyWidgets::dropdown(
      label = "Customize graph",
      tags$h3("Customize"),
      div(
        style = "display: inline-block;vertical-align:top; width: 100%; text-align: center; margin-bottom: 10px;",
        shinyWidgets::actionBttn(
          inputId = "resetHistogram2",
          label = "Reset to Initial State",
          style = "bordered",
          color = "warning",
          size = "sm",
          icon = icon("refresh")
        )
      ),
      sliderInput("binsHist2",
        "Bins",
        min = 4,
        max = 500,
        value = 10,
        step = 1
      ),
      div(
        style = "display: inline-block;vertical-align:top;
                               width: 150px;",
        selectInput("themeHist2",
          " Theme",
          choices = names(themesb)
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        selectInput("fontH2",
          " Font",
          choices = fuentes
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        selectInput("paletas",
          "Palletes",
          choices = paletas
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        textInput(
          "linecolorHist2",
          label = "Line color",
          value = "black"
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        textInput(
          "ylabHist2",
          label = "ylab",
          value = "Write ylab..."
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        textInput(
          "xlabHist2",
          label = "xlab",
          value = "Write xlab..."
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        sliderInput(
          inputId = "lwdHist2",
          label = "Line width",
          min = 0.1,
          max = 10,
          value = 2
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "fontHist2",
          label = "Size font",
          min = 1,
          max = 50,
          value = 12
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "alphaHist2",
          label = "alpha",
          min = 0.001,
          max = 1,
          value = 0.5
        )
      ),
      style = "unite",
      icon = icon("fish"),
      status = "primary",
      width = "500px",
      animate = shinyWidgets::animateOptions(
        enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
        exit = shinyWidgets::animations$fading_exits$fadeOutRightBig
      )
    )
  ),
  conditionalPanel(
    condition = "input.SelecTipografico == 'Density'& input.Grupo == 0",
    plotOutput("plotdescript3"),
    br(),
    downloadButton("ContinuousUnivariateDensityDownloadGrupo", "Download Graph", class = "btn-primary"),
    br(), br(),
    shinyWidgets::dropdown(
      label = "Customize graph",
      tags$h3("Customize"),
      div(
        style = "display: inline-block;vertical-align:top; width: 100%; text-align: center; margin-bottom: 10px;",
        shinyWidgets::actionBttn(
          inputId = "resetDensity",
          label = "Reset to Initial State",
          style = "bordered",
          color = "warning",
          size = "sm",
          icon = icon("refresh")
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;
                               width: 150px;",
        selectInput("themeDensy",
          " Theme",
          choices = names(themesb)
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        selectInput("fontdensy",
          " Font",
          choices = fuentes
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        colourInput(
          label = "Line_color",
          "linecolorDensy", "blue", palette = "square",
          showColour = "background"
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        colourInput(
          label = "Fill_color",
          "fillDensy", "blue", palette = "square",
          showColour = "background"
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        textInput(
          "ylabDensy",
          label = "ylab",
          value = "Write ylab..."
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        textInput(
          "xlabDensy",
          label = "xlab",
          value = "Write xlab..."
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        sliderInput(
          inputId = "lwdDensy",
          label = "Line width",
          min = 0.1,
          max = 10,
          value = 2
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "fontDensy",
          label = "Size font",
          min = 1,
          max = 50,
          value = 12
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "alphaDensy",
          label = "alpha",
          min = 0.001,
          max = 1,
          value = 0.5
        )
      ),
      style = "unite",
      icon = icon("fish"),
      status = "primary",
      width = "500px",
      animate = shinyWidgets::animateOptions(
        enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
        exit = shinyWidgets::animations$fading_exits$fadeOutRightBig
      )
    )
  ),
  conditionalPanel(
    condition = "input.SelecTipografico == 'Density'& input.Grupo == 1",
    plotOutput("plotdescript4"),
    br(),
    downloadButton("ContinuousUnivariateDensityDownloadNoGrupo", "Download Graph", class = "btn-primary"),
    br(), br(),
    shinyWidgets::dropdown(
      label = "Customize graph",
      tags$h3("Customize"),
      div(
        style = "display: inline-block;vertical-align:top; width: 100%; text-align: center; margin-bottom: 10px;",
        shinyWidgets::actionBttn(
          inputId = "resetDensity2",
          label = "Reset to Initial State",
          style = "bordered",
          color = "warning",
          size = "sm",
          icon = icon("refresh")
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;
                               width: 150px;",
        selectInput("themeDensy2",
          " Theme",
          choices = names(themesb)
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        selectInput("paletasDensy2",
          "Palletes",
          choices = paletas
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        selectInput("fontdensy2",
          " Font",
          choices = fuentes
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        selectInput("paletas",
          "Palletes",
          choices = paletas
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        textInput(
          "linecolorDensy2",
          label = "Line color",
          value = "black"
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        textInput(
          "ylabDensy2",
          label = "ylab",
          value = "Write ylab..."
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        textInput(
          "xlabDensy2",
          label = "xlab",
          value = "Write xlab..."
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        sliderInput(
          inputId = "lwdDensy2",
          label = "Line width",
          min = 0.1,
          max = 10,
          value = 2
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "fontDensy2",
          label = "Size font",
          min = 1,
          max = 50,
          value = 12
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "alphaDensy2",
          label = "alpha",
          min = 0.001,
          max = 1,
          value = 0.5
        )
      ),
      style = "unite",
      icon = icon("fish"),
      status = "primary",
      width = "500px",
      animate = shinyWidgets::animateOptions(
        enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
        exit = shinyWidgets::animations$fading_exits$fadeOutRightBig
      )
    )
  ),
  conditionalPanel(
    condition = "input.SelecTipografico == 'Boxplot'& input.Grupo == 0",
    plotOutput("plotdescript5"),
    br(),
    downloadButton("ContinuousUnivariateBoxplotDownloadGrupo", "Download Graph", class = "btn-primary"),
    br(), br(),
    shinyWidgets::dropdown(
      label = "Customize graph", tags$h3("Customize"),
      div(
        style = "display: inline-block;vertical-align:top; width: 100%; text-align: center; margin-bottom: 10px;",
        shinyWidgets::actionBttn(
          inputId = "resetBoxplot",
          label = "Reset to Initial State",
          style = "bordered",
          color = "warning",
          size = "sm",
          icon = icon("refresh")
        )
      ),
      div(style = "display: inline-block;vertical-align:top;
        width: 150px;", selectInput("themeboxplot", " Theme",
        choices = names(themesb)
      )),
      div(style = "display: inline-block;vertical-align:top;
        width: 150px;", selectInput("fontbox", " Font", choices = fuentes)),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        textInput("ylabboxplot",
          label = "ylab",
          value = "Write ylab..."
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        textInput("xlabboxplot",
          label = "xlab",
          value = "Write xlab..."
        )
      ),
      div(
        style = "display: inline-block;
        vertical-align:top; width: 150px;",
        colourInput(
          label = "Line_color",
          "linecolorboxplot", "black",
          palette = "square",
          showColour = "background"
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        colourInput(
          label = "Fill_color",
          "fillboxplot", "blue",
          palette = "square",
          showColour = "background"
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        colourInput(
          label = "Outlier_color",
          "coloroutlier", "red",
          palette = "square",
          showColour = "background"
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "lwdboxplot",
          label = "Line width",
          min = 0.1,
          max = 10,
          value = 1.5
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        sliderInput(
          inputId = "fontboxplot",
          label = "Size font",
          min = 1,
          max = 50,
          value = 12
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "pointboxplot",
          label = "Size point",
          min = 1,
          max = 10,
          value = 2
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "alphaboxplot",
          label = "alpha",
          min = 0.001,
          max = 1,
          value = 0.5
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "pchboxplot",
          label = " Point shape",
          min = 0,
          max = 25,
          value = 16
        )
      ),
      shinyWidgets::switchInput(
        inputId = "nocht",
        label = "Nocht",
        onLabel = "TRUE",
        offLabel = "FALSE",
        size = "mini"
      ),
      style = "unite",
      icon = icon("fish"),
      status = "primary",
      width = "500px",
      animate = shinyWidgets::animateOptions(
        enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
        exit = shinyWidgets::animations$fading_exits$fadeOutRightBig
      )
    ),
    h2("Outlier - No Group"),
    DT::DTOutput("outlierNoGroup")
  ),
  conditionalPanel(
    condition = "input.SelecTipografico == 'Boxplot'& input.Grupo == 1",
    plotOutput(outputId = "graph", brush = "plot_brush"),
    br(),
    downloadButton("ContinuousUnivariateBoxplotDownloadNoGrupo", "Download Graph", class = "btn-primary"),
    br(), br(),
    shinyWidgets::dropdown(
      label = "Customize graph", tags$h3("Customize"),
      div(style = "display: inline-block;vertical-align:top;
        width: 150px;", shinyWidgets::actionBttn(
        inputId = "resetBoxplot2",
        label = "Reset to Initial State",
        style = "bordered",
        color = "warning",
        size = "sm",
        icon = icon("refresh")
      )),
      div(style = "display: inline-block;vertical-align:top;
        width: 150px;", selectInput("themeboxplot2", " Theme",
        choices = names(themesb)
      )),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        selectInput("paletasboxplot2",
          "Palletes",
          choices = paletas
        )
      ),
      div(style = "display: inline-block;vertical-align:top;
        width: 150px;", selectInput("fontbox2", " Font", choices = fuentes)),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        textInput("ylabboxplot2",
          label = "ylab",
          value = "Write ylab..."
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        textInput("xlabboxplot2",
          label = "xlab",
          value = "Write xlab..."
        )
      ),
      div(
        style = "display: inline-block;
        vertical-align:top; width: 150px;",
        textInput("linecolorboxplot2",
          label = "Color box",
          value = "black"
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        colourInput("coloroutlier2", "red",
          label = "Color outlier"
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "lwdboxplot2",
          label = "Line width",
          min = 0.1,
          max = 10,
          value = 1.5
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        sliderInput(
          inputId = "fontboxplot2",
          label = "Size font",
          min = 1,
          max = 50,
          value = 12
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "pointboxplot2",
          label = "Size point",
          min = 1,
          max = 10,
          value = 2
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "alphaboxplot2",
          label = "alpha",
          min = 0.001,
          max = 1,
          value = 0.5
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "pchboxplot2",
          label = " Point shape",
          min = 0,
          max = 25,
          value = 16
        )
      ),
      shinyWidgets::switchInput(
        inputId = "nocht2",
        label = "Nocht",
        onLabel = "TRUE",
        offLabel = "FALSE",
        size = "mini"
      ),
      style = "unite",
      icon = icon("fish"),
      status = "primary",
      width = "500px",
      animate = shinyWidgets::animateOptions(
        enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
        exit = shinyWidgets::animations$fading_exits$fadeOutRightBig
      )
    ),
    h2("Outlier - Group"),
    DT::DTOutput("outlier")
  ),
  conditionalPanel(
    condition = "input.SelecTipografico == 'Violin'& input.Grupo == 0",
    plotOutput("plotdescript6"),
    br(),
    downloadButton("ContinuousUnivariateViolinDownloadGrupo", "Download Graph", class = "btn-primary"),
    br(), br(),
    shinyWidgets::dropdown(
      label = "Customize graph", tags$h3("Customize"),
      div(style = "display: inline-block;vertical-align:top;
        width: 150px;", shinyWidgets::actionBttn(
        inputId = "resetViolin",
        label = "Reset to Initial State",
        style = "bordered",
        color = "warning",
        size = "sm",
        icon = icon("refresh")
      )),
      div(style = "display: inline-block;vertical-align:top;
        width: 150px;", selectInput("themeviolin", " Theme",
        choices = names(themesb)
      )),
      div(style = "display: inline-block;vertical-align:top;
        width: 150px;", selectInput("fontviolin", " Font", choices = fuentes)),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        textInput("ylabviolin",
          label = "ylab",
          value = "Write ylab..."
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        textInput("xlabviolin",
          label = "xlab",
          value = "Write xlab..."
        )
      ),
      div(
        style = "display: inline-block;
        vertical-align:top; width: 150px;",
        textInput("linecolorviolin",
          label = "Color line",
          value = "red"
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        textInput("fillviolin",
          label = "Color fill",
          value = "#0095ff"
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "lwdviolin",
          label = "Line width",
          min = 0.1,
          max = 10,
          value = 1.5
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        sliderInput(
          inputId = "fontSviolin",
          label = "Size font",
          min = 1,
          max = 50,
          value = 12
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "alphaviolin",
          label = "alpha",
          min = 0.001,
          max = 1,
          value = 0.5
        )
      ),
      shinyWidgets::switchInput(
        inputId = "trim",
        label = "Trim",
        onLabel = "TRUE",
        offLabel = "FALSE",
        size = "mini"
      ),
      style = "unite",
      icon = icon("fish"),
      status = "primary",
      width = "500px",
      animate = shinyWidgets::animateOptions(
        enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
        exit = shinyWidgets::animations$fading_exits$fadeOutRightBig
      )
    )
  ),
  conditionalPanel(
    condition = "input.SelecTipografico == 'Violin'& input.Grupo == 1",
    plotOutput("plotdescript7"),
    br(),
    downloadButton("ContinuousUnivariateViolinDownloadNoGrupo", "Download Graph", class = "btn-primary"),
    br(), br(),
    shinyWidgets::dropdown(
      label = "Customize graph", tags$h3("Customize"),
      div(style = "display: inline-block;vertical-align:top;
        width: 150px;", shinyWidgets::actionBttn(
        inputId = "resetViolin2",
        label = "Reset to Initial State",
        style = "bordered",
        color = "warning",
        size = "sm",
        icon = icon("refresh")
      )),
      div(style = "display: inline-block;vertical-align:top;
        width: 150px;", selectInput("themeviolin2", " Theme",
        choices = names(themesb)
      )),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        selectInput("paletasviolin",
          "Palletes",
          choices = paletas
        )
      ),
      div(style = "display: inline-block;vertical-align:top;
        width: 150px;", selectInput("fontviolin2", " Font", choices = fuentes)),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        textInput("ylabviolin2",
          label = "ylab",
          value = "Write ylab..."
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        textInput("xlabviolin2",
          label = "xlab",
          value = "Write xlab..."
        )
      ),
      div(
        style = "display: inline-block;
        vertical-align:top; width: 150px;",
        textInput("linecolorviolin2",
          label = "Color line",
          value = "red"
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "lwdviolin2",
          label = "Line width",
          min = 0.1,
          max = 10,
          value = 1.5
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top;width: 150px;",
        sliderInput(
          inputId = "fontSviolin2",
          label = "Size font",
          min = 1,
          max = 50,
          value = 12
        )
      ),
      div(
        style = "display: inline-block;vertical-align:top; width: 150px;",
        sliderInput(
          inputId = "alphaviolin2",
          label = "alpha",
          min = 0.001,
          max = 1,
          value = 0.5
        )
      ),
      shinyWidgets::switchInput(
        inputId = "trim2",
        label = "Trim",
        onLabel = "TRUE",
        offLabel = "FALSE",
        size = "mini"
      ),
      style = "unite",
      icon = icon("fish"),
      status = "primary",
      width = "500px",
      animate = shinyWidgets::animateOptions(
        enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
        exit = shinyWidgets::animations$fading_exits$fadeOutRightBig
      )
    )
  ),

  # =====================================================================
  # POLYGON PLOTS
  # =====================================================================

  # Polygon without groups
  conditionalPanel(
    condition = "input.SelecTipografico == 'Polygon'& input.Grupo == 0",
    plotOutput("plotdescript8"),
    br(),
    downloadButton("ContinuousUnivariatePolygonDownloadGrupo", "Download Graph", class = "btn-primary"),
    br(), br(),
    shinyWidgets::dropdown(
      label = "Customize graph",
      tags$h3("Customize"),
      div(
        style = "display: inline-block; vertical-align: top; width: 100%; text-align: center; margin-bottom: 10px;",
        shinyWidgets::actionBttn(
          inputId = "resetPolygon",
          label = "Reset to Initial State",
          style = "bordered",
          color = "warning",
          size = "sm",
          icon = icon("refresh")
        )
      ),
      sliderInput("binsPolygon", "Bins", min = 4, max = 500, value = 10, step = 1),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        selectInput("themePolygon", " Theme", choices = names(themesb))
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        selectInput("fontPolygon", "Font", choices = fuentes)
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        textInput("ylabPolygon", label = "ylab", value = "Frequency")
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        textInput("xlabPolygon", label = "xlab", value = "Values")
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        colourInput(
          label = "Line_color",
          "linecolorPolygon", "blue", palette = "square",
          showColour = "background"
        )
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        colourInput(
          label = "Point_color",
          "pointcolorPolygon", "red", palette = "square",
          showColour = "background"
        )
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        sliderInput(
          inputId = "lwdPolygon",
          label = "Line width",
          min = 0.1, max = 10, value = 2
        )
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        sliderInput(
          inputId = "fontSizePolygon",
          label = "Size font",
          min = 1, max = 50, value = 12
        )
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        sliderInput(
          inputId = "pointsizePolygon",
          label = "Point size",
          min = 1, max = 10, value = 3
        )
      ),
      style = "unite",
      icon = icon("fish"),
      status = "primary",
      width = "500px",
      animate = shinyWidgets::animateOptions(
        enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
        exit = shinyWidgets::animations$fading_exits$fadeOutRightBig
      )
    )
  ),

  # Polygon with groups
  conditionalPanel(
    condition = "input.SelecTipografico == 'Polygon'& input.Grupo == 1",
    plotOutput("plotdescript9"),
    br(),
    downloadButton("ContinuousUnivariatePolygonDownloadNoGrupo", "Download Graph", class = "btn-primary"),
    br(), br(),
    shinyWidgets::dropdown(
      label = "Customize graph",
      tags$h3("Customize"),
      div(
        style = "display: inline-block; vertical-align: top; width: 100%; text-align: center; margin-bottom: 10px;",
        shinyWidgets::actionBttn(
          inputId = "resetPolygon2",
          label = "Reset to Initial State",
          style = "bordered",
          color = "warning",
          size = "sm",
          icon = icon("refresh")
        )
      ),
      sliderInput("binsPolygon2", "Bins", min = 4, max = 500, value = 10, step = 1),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        selectInput("themePolygon2", " Theme", choices = names(themesb))
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        selectInput("paletasPolygon", "Palletes", choices = paletas)
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        selectInput("fontPolygon2", " Font", choices = fuentes)
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        textInput("ylabPolygon2", label = "ylab", value = "Frequency")
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        textInput("xlabPolygon2", label = "xlab", value = "Values")
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        sliderInput(
          inputId = "lwdPolygon2",
          label = "Line width",
          min = 0.1, max = 10, value = 2
        )
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        sliderInput(
          inputId = "fontSizePolygon2",
          label = "Size font",
          min = 1, max = 50, value = 12
        )
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        sliderInput(
          inputId = "pointsizePolygon2",
          label = "Point size",
          min = 1, max = 10, value = 3
        )
      ),
      style = "unite",
      icon = icon("fish"),
      status = "primary",
      width = "500px",
      animate = shinyWidgets::animateOptions(
        enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
        exit = shinyWidgets::animations$fading_exits$fadeOutRightBig
      )
    )
  ),

  # =====================================================================
  # OGIVE PLOTS
  # =====================================================================

  # Ogive without groups
  conditionalPanel(
    condition = "input.SelecTipografico == 'Ogive'& input.Grupo == 0",
    plotOutput("plotdescript10"),
    br(),
    downloadButton("ContinuousUnivariateOgiveDownloadGrupo", "Download Graph", class = "btn-primary"),
    br(), br(),
    shinyWidgets::dropdown(
      label = "Customize graph",
      tags$h3("Customize"),
      div(
        style = "display: inline-block; vertical-align: top; width: 100%; text-align: center; margin-bottom: 10px;",
        shinyWidgets::actionBttn(
          inputId = "resetOgive",
          label = "Reset to Initial State",
          style = "bordered",
          color = "warning",
          size = "sm",
          icon = icon("refresh")
        )
      ),
      sliderInput("binsOgive", "Bins", min = 4, max = 500, value = 10, step = 1),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        selectInput("themeOgive", " Theme", choices = names(themesb))
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        selectInput(
          "fontOgive", " Font",
          choices = fuentes
        )
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        textInput("ylabOgive", label = "ylab", value = "Cumulative Frequency")
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        textInput("xlabOgive", label = "xlab", value = "Values")
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        colourInput(
          label = "Line_color",
          "linecolorOgive", "darkgreen", palette = "square",
          showColour = "background"
        )
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        colourInput(
          label = "Point_color",
          "pointcolorOgive", "orange", palette = "square",
          showColour = "background"
        )
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        sliderInput(
          inputId = "lwdOgive",
          label = "Line width",
          min = 0.1, max = 10, value = 2
        )
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        sliderInput(
          inputId = "fontSizeOgive",
          label = "Size font",
          min = 1, max = 50, value = 12
        )
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        sliderInput(
          inputId = "pointsizeOgive",
          label = "Point size",
          min = 1, max = 10, value = 3
        )
      ),
      style = "unite",
      icon = icon("fish"),
      status = "primary",
      width = "500px",
      animate = shinyWidgets::animateOptions(
        enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
        exit = shinyWidgets::animations$fading_exits$fadeOutRightBig
      )
    )
  ),

  # Ogive with groups
  conditionalPanel(
    condition = "input.SelecTipografico == 'Ogive'& input.Grupo == 1",
    plotOutput("plotdescript11"),
    br(),
    downloadButton("ContinuousUnivariateOgiveDownloadNoGrupo", "Download Graph", class = "btn-primary"),
    br(), br(),
    shinyWidgets::dropdown(
      label = "Customize graph",
      tags$h3("Customize"),
      div(
        style = "display: inline-block; vertical-align: top; width: 100%; text-align: center; margin-bottom: 10px;",
        shinyWidgets::actionBttn(
          inputId = "resetOgive2",
          label = "Reset to Initial State",
          style = "bordered",
          color = "warning",
          size = "sm",
          icon = icon("refresh")
        )
      ),
      sliderInput("binsOgive2", "Bins", min = 4, max = 500, value = 10, step = 1),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        selectInput("themeOgive2", " Theme", choices = names(themesb))
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        selectInput("paletasOgive", "Palletes", choices = paletas)
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        selectInput("fontOgive2", " Font", choices = fuentes)
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        textInput("ylabOgive2", label = "ylab", value = "Cumulative Frequency")
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        textInput("xlabOgive2", label = "xlab", value = "Values")
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        sliderInput(
          inputId = "lwdOgive2",
          label = "Line width",
          min = 0.1, max = 10, value = 2
        )
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        sliderInput(
          inputId = "fontSizeOgive2",
          label = "Size font",
          min = 1, max = 50, value = 12
        )
      ),
      div(
        style = "display: inline-block; vertical-align: top; width: 150px;",
        sliderInput(
          inputId = "pointsizeOgive2",
          label = "Point size",
          min = 1, max = 10, value = 3
        )
      ),
      style = "unite",
      icon = icon("fish"),
      status = "primary",
      width = "500px",
      animate = shinyWidgets::animateOptions(
        enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
        exit = shinyWidgets::animations$fading_exits$fadeOutRightBig
      )
    )
  )
)

#' Frequency table for continuous data
#' Frequency table for continuous data.
#' @param data A \code{data.frame} or a \code{tibble}.
#' @param variable Column in \code{data}.
#' @param bins Number of intervals into which the data must be split.
#' @return A \code{data.frame} with frequency, cumulative frequency, frequency percent and cumulative frequency
#' percent.
#' @examples
#' ST_freq_numeric(mtcars, mpg,bins = 5)
#' @export


ST_freq_numeric <- function(data, variable, bins = 5) {

  var_name <- deparse(substitute(variable))
  varyable <- rlang::enquo(variable)

  fdata <-
    data %>%
    dplyr::pull(!! varyable) %>%
    stats::na.omit()
  if (!is.numeric(bins)) {
    stop("bins must be integer value")
  }
  if (is.numeric(bins)) {
    bins <- as.integer(bins)
  }
  var_name <-
    data %>%
    dplyr::select(!! varyable) %>%
    names()

  bin_size <- function(data, bins) {
    return((max(data, na.rm = TRUE) - min(data, na.rm = TRUE)) / bins)
  }

  intervals <- function(data, bins, na.rm = TRUE) {
    binsize <- bin_size(data, bins)
    bin <- bins - 1
    interval <- min(data)
    for (i in seq_len(bin)) {
      out <- interval[i] + binsize
      interval <- c(interval, out)
    }
    interval <- c(interval, max(data))
    return(interval)
  }
  freq <- function(data, bins, inta) {
    result <- numeric(bins)
    for (i in seq_len(bins)) {
      k <- i + 1
      if (i < bins) {
        f <- data >= inta[i] & data < inta[k]
      } else {
        f <- data >= inta[i] & data <= inta[k]
      }
      result[i] <- sum(f)
    }
    return(result)
  }
  percent <- function(x, y) {
    out <- round((x / y) * 100, 2)
    return(out)}

  n_bins   <- bins
  inta     <- intervals(fdata, bins)
  result   <- freq(fdata, bins, inta)
  data_len <- length(fdata)
  cum      <- cumsum(result)
  per      <- percent(result, data_len)
  cum_per  <- percent(cum, data_len)

  na_count <-
    data %>%
    dplyr::pull(!! varyable) %>%
    is.na() %>%
    sum()

  if (na_count > 0) {
    na_freq <- na_count
  } else {
    na_freq <- 0
  }

  n_obs <-
    data %>%
    dplyr::pull(!! varyable) %>%
    length()

  lower_n <- n_bins + 1
  lower <- inta[-lower_n]
  upper <- inta[-1]

  freq_data <-
    data.frame(lower  = lower,
                   upper  = upper,
                   midpoint     = (lower+upper)/2,
                   frequency    = result,
                   cumulative   = cum,
                   freq_percent = per,
                   cum_percent  = cum_per)

  return(freq_data)
}

load_dataPage <- shinydashboard::tabItem( tabName = "Load_data",
      tags$head(
        tags$style(HTML("
          /* Global styles to ensure all text is black */
          .tab-pane label, .tab-pane .control-label { color: #000000 !important; }
          .tab-pane .form-control { color: #000000 !important; }
          .tab-pane strong { color: #000000 !important; }
          .tab-pane .checkbox label { color: #000000 !important; }
          .tab-pane .shiny-input-container label { color: #000000 !important; }
          .tab-pane .form-group label { color: #000000 !important; }
          .tab-pane .file-input-container label { color: #000000 !important; }
          .tab-pane .selectize-input { color: #000000 !important; }
          .tab-pane .selectize-dropdown { color: #000000 !important; }
          .tab-pane .btn-file { color: #000000 !important; }
          .tab-pane .input-group-addon { color: #000000 !important; }
          .tab-pane .help-block { color: #000000 !important; }
          .tab-pane .text-muted { color: #000000 !important; }
          .tab-pane .text-info { color: #000000 !important; }
          .tab-pane .text-success { color: #000000 !important; }
          .tab-pane .text-warning { color: #000000 !important; }
          .tab-pane .text-danger { color: #000000 !important; }
          .tab-pane .pretty { color: #000000 !important; }
          .tab-pane .pretty .state label { color: #000000 !important; }
          .tab-pane .pretty .state label:before { color: #000000 !important; }
          .tab-pane .pretty .state label:after { color: #000000 !important; }
          
          /* Improved styling for column type selector */
          .column-type-row { 
            background: #f8f9fa; 
            border: 1px solid #e9ecef; 
            border-radius: 6px; 
            padding: 12px; 
            margin-bottom: 8px; 
            transition: all 0.3s ease;
          }
          .column-type-row:hover { 
            background: #e9ecef; 
            border-color: #007bff; 
            box-shadow: 0 2px 4px rgba(0,0,0,0.1);
          }
          .column-type-row label { 
            font-weight: bold; 
            color: #495057 !important; 
            margin-bottom: 8px; 
          }
          .column-type-row .form-control { 
            border-radius: 4px; 
            border: 1px solid #ced4da; 
          }
          .column-type-row .form-control:focus { 
            border-color: #007bff; 
            box-shadow: 0 0 0 0.2rem rgba(0,123,255,0.25); 
          }
          .decimal-separator-section, .date-format-section { 
            background: #e7f3ff; 
            border: 1px solid #b3d9ff; 
            border-radius: 4px; 
            padding: 8px; 
            margin-top: 5px; 
          }
          .decimal-separator-section label, .date-format-section label { 
            font-size: 12px; 
            color: #0056b3 !important; 
            font-weight: normal; 
          }
          
          /* Improved table styling */
          .shiny-table-output table {
            width: 100% !important;
            border-collapse: collapse !important;
            margin: 0 !important;
            font-size: 13px !important;
            font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif !important;
          }
          .shiny-table-output th {
            background: linear-gradient(135deg, #e9ecef, #f8f9fa) !important;
            color: #000000 !important;
            font-weight: 600 !important;
            padding: 12px 8px !important;
            text-align: center !important;
            border: 1px solid #dee2e6 !important;
            font-size: 14px !important;
            text-transform: uppercase !important;
            letter-spacing: 0.5px !important;
          }
          .shiny-table-output td {
            padding: 10px 8px !important;
            border: 1px solid #e9ecef !important;
            text-align: center !important;
            vertical-align: middle !important;
            color: #000000 !important;
            font-weight: 500 !important;
          }
          .shiny-table-output tr:nth-child(even) {
            background-color: #f8f9fa !important;
          }
          .shiny-table-output tr:nth-child(odd) {
            background-color: white !important;
          }
          .shiny-table-output tr:hover {
            background-color: #e3f2fd !important;
            transform: scale(1.01) !important;
            transition: all 0.2s ease !important;
            box-shadow: 0 2px 8px rgba(0,0,0,0.1) !important;
          }
          .shiny-table-output .table {
            box-shadow: 0 4px 12px rgba(0,0,0,0.15) !important;
            border-radius: 8px !important;
            overflow: hidden !important;
            border: none !important;
          }
          .shiny-table-output .table-striped > tbody > tr:nth-of-type(odd) {
            background-color: white !important;
          }
          .shiny-table-output .table-striped > tbody > tr:nth-of-type(even) {
            background-color: #f8f9fa !important;
          }
          .shiny-table-output .table-hover > tbody > tr:hover {
            background-color: #e3f2fd !important;
          }
          .shiny-table-output .table-bordered {
            border: 1px solid #dee2e6 !important;
          }
          .shiny-table-output .table-bordered > thead > tr > th,
          .shiny-table-output .table-bordered > tbody > tr > td {
            border: 1px solid #dee2e6 !important;
          }
          
          /* Force all table text to be black with maximum specificity */
          .shiny-table-output,
          .shiny-table-output *,
          .shiny-table-output table,
          .shiny-table-output table *,
          .shiny-table-output thead,
          .shiny-table-output thead *,
          .shiny-table-output tbody,
          .shiny-table-output tbody *,
          .shiny-table-output tr,
          .shiny-table-output tr *,
          .shiny-table-output th,
          .shiny-table-output th *,
          .shiny-table-output td,
          .shiny-table-output td *,
          .shiny-table-output .table,
          .shiny-table-output .table *,
          .shiny-table-output .table-striped,
          .shiny-table-output .table-striped *,
          .shiny-table-output .table-hover,
          .shiny-table-output .table-hover *,
          .shiny-table-output .table-bordered,
          .shiny-table-output .table-bordered * {
            color: #000000 !important;
          }
          
          /* Override any Bootstrap or other framework styles */
          .shiny-table-output .text-white,
          .shiny-table-output .text-light,
          .shiny-table-output .text-muted {
            color: #000000 !important;
          }
        "))
      ),
      fluidRow(
        column(
          width = 12,
          shinydashboard::box(
            width = 12,
            title = tags$h3(icon("database"), " Load Data", style = "margin: 0; color: #000000;"),
            status = "primary",
            solidHeader = TRUE,
            collapsible = TRUE,
            background = "light-blue",
            fluidRow(
              column(
                width = 4,
                div(class = "well-panel",
                  style = "background: linear-gradient(135deg, #f8f9fa 0%, #e9ecef 100%); border: 1px solid #dee2e6; border-radius: 8px; box-shadow: 0 2px 4px rgba(0,0,0,0.1);",
                  tags$style(HTML("
                    .well-panel label, .well-panel .control-label { color: #000000 !important; }
                    .well-panel .form-control { color: #000000 !important; }
                    .well-panel strong { color: #000000 !important; }
                    .well-panel .checkbox label { color: #000000 !important; }
                    .well-panel .pretty-checkbox label { color: #000000 !important; }
                    .well-panel .shiny-input-container label { color: #000000 !important; }
                    .well-panel .form-group label { color: #000000 !important; }
                    .well-panel .file-input-container label { color: #000000 !important; }
                    .well-panel .selectize-input { color: #000000 !important; }
                    .well-panel .selectize-dropdown { color: #000000 !important; }
                    .well-panel .btn-file { color: #000000 !important; }
                    .well-panel .input-group-addon { color: #000000 !important; }
                    .well-panel .help-block { color: #000000 !important; }
                    .well-panel .text-muted { color: #000000 !important; }
                    .well-panel .text-info { color: #000000 !important; }
                    .well-panel .text-success { color: #000000 !important; }
                    .well-panel .text-warning { color: #000000 !important; }
                    .well-panel .text-danger { color: #000000 !important; }
                    .well-panel .pretty { color: #000000 !important; }
                    .well-panel .pretty .state label { color: #000000 !important; }
                    .well-panel .pretty .state label:before { color: #000000 !important; }
                    .well-panel .pretty .state label:after { color: #000000 !important; }
                    
                    /* Column type selector improvements */
                    .well-panel .column-type-row { 
                      background: #f8f9fa; 
                      border: 1px solid #e9ecef; 
                      border-radius: 6px; 
                      padding: 12px; 
                      margin-bottom: 8px; 
                      transition: all 0.3s ease;
                    }
                    .well-panel .column-type-row:hover { 
                      background: #e9ecef; 
                      border-color: #007bff; 
                      box-shadow: 0 2px 4px rgba(0,0,0,0.1);
                    }
                    .well-panel .column-type-row label { 
                      font-weight: bold; 
                      color: #495057 !important; 
                      margin-bottom: 8px; 
                    }
                    .well-panel .decimal-separator-section, .well-panel .date-format-section { 
                      background: #e7f3ff; 
                      border: 1px solid #b3d9ff; 
                      border-radius: 4px; 
                      padding: 8px; 
                      margin-top: 5px; 
                    }
                    .well-panel .decimal-separator-section label, .well-panel .date-format-section label { 
                      font-size: 12px; 
                      color: #0056b3 !important; 
                      font-weight: normal; 
                    }
                    
                    /* Table styling for the panel */
                    .well-panel .shiny-table-output table {
                      width: 100% !important;
                      border-collapse: collapse !important;
                      margin: 0 !important;
                      font-size: 13px !important;
                      font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif !important;
                      color: #000000 !important;
                    }
                    .well-panel .shiny-table-output th {
                      background: linear-gradient(135deg, #e9ecef, #f8f9fa) !important;
                      color: #000000 !important;
                      font-weight: 600 !important;
                      padding: 12px 8px !important;
                      text-align: center !important;
                      border: 1px solid #dee2e6 !important;
                      font-size: 14px !important;
                      text-transform: uppercase !important;
                      letter-spacing: 0.5px !important;
                    }
                    .well-panel .shiny-table-output td {
                      padding: 10px 8px !important;
                      border: 1px solid #e9ecef !important;
                      text-align: center !important;
                      vertical-align: middle !important;
                      color: #495057 !important;
                      font-weight: 500 !important;
                    }
                    .well-panel .shiny-table-output tr:nth-child(even) {
                      background-color: #f8f9fa !important;
                    }
                    .well-panel .shiny-table-output tr:nth-child(odd) {
                      background-color: white !important;
                    }
                    .well-panel .shiny-table-output tr:hover {
                      background-color: #e3f2fd !important;
                      transform: scale(1.01) !important;
                      transition: all 0.2s ease !important;
                      box-shadow: 0 2px 8px rgba(0,0,0,0.1) !important;
                    }
                    
                    /* Force all table text to be black in panel with maximum specificity */
                    .well-panel .shiny-table-output,
                    .well-panel .shiny-table-output *,
                    .well-panel .shiny-table-output table,
                    .well-panel .shiny-table-output table *,
                    .well-panel .shiny-table-output thead,
                    .well-panel .shiny-table-output thead *,
                    .well-panel .shiny-table-output tbody,
                    .well-panel .shiny-table-output tbody *,
                    .well-panel .shiny-table-output tr,
                    .well-panel .shiny-table-output tr *,
                    .well-panel .shiny-table-output th,
                    .well-panel .shiny-table-output th *,
                    .well-panel .shiny-table-output td,
                    .well-panel .shiny-table-output td *,
                    .well-panel .shiny-table-output .table,
                    .well-panel .shiny-table-output .table *,
                    .well-panel .shiny-table-output .table-striped,
                    .well-panel .shiny-table-output .table-striped *,
                    .well-panel .shiny-table-output .table-hover,
                    .well-panel .shiny-table-output .table-hover *,
                    .well-panel .shiny-table-output .table-bordered,
                    .well-panel .shiny-table-output .table-bordered * {
                      color: #000000 !important;
                    }
                    
                    /* Override any Bootstrap or other framework styles in panel */
                    .well-panel .shiny-table-output .text-white,
                    .well-panel .shiny-table-output .text-light,
                    .well-panel .shiny-table-output .text-muted {
                      color: #000000 !important;
                    }
                  ")),
                  tags$h4(icon("cog"), " Data Source Configuration", style = "color: #000000; margin-bottom: 20px; border-bottom: 2px solid #007bff; padding-bottom: 10px;"),
                  
                  # Help Button with improved styling
                  div(
                    style = "margin-bottom: 20px;",
                    shinyWidgets::actionBttn(
                      "helpload",
                      "Help Guide",
                      icon = icon("question-circle"),
                      style = "gradient",
                      block = TRUE,
                      color = "primary",
                      size = "sm"
                    )
                  ),
                  
                  # Help Modal
                  shinyBS::bsModal(
                    id="helploaddata",
                    title = tags$h3(icon("info-circle"), " Data Loading Guide"),
                    trigger = "helpload",
                    size="large",
                    tags$iframe(
                      src = "load_data.html",
                      width = "100%",
                      height = "1000px",
                      frameborder = 0,
                      scrolling = "auto"
                    )
                  ),
                  
                  # Example Data Section
                  div(
                    style = "background: #f8f9fa; padding: 15px; border-radius: 6px; margin-bottom: 20px; border-left: 4px solid #28a745;",
                    tags$h5(icon("flask"), " Example Data", style = "color: #000000; margin-bottom: 15px;"),
                    shinyWidgets::prettyCheckbox(
                      inputId = "example",
                      label = "Use example data set?",
                      value = FALSE,
                      status = "success",
                      shape = "round",
                      outline = TRUE
                    ),
                    conditionalPanel(
                      condition = "input.example == 1",
                      div(
                        style = "margin-top: 10px;",
                        selectInput('selexample',
                                   'Select Example Dataset:',
                                   choices = c("iris","fishes"),
                                   multiple = FALSE,
                                   selectize = TRUE)
                      )
                    )
                  ),
                  
                  # File Upload Section
                  div(
                    style = "background: #f8f9fa; padding: 15px; border-radius: 6px; margin-bottom: 20px; border-left: 4px solid #007bff;",
                    tags$h5(icon("upload"), " File Upload", style = "color: #000000; margin-bottom: 15px;"),
                    fileInput(
                      "file1",
                      "Choose File:",
                      accept = c(".csv", ".xlsx", ".xls"),
                      multiple = FALSE,
                      buttonLabel = "Browse...",
                      placeholder = "No file selected"
                    ),
                    selectInput(
                      inputId = "worksheet",
                      label = "Worksheet Name:",
                      choices = NULL,
                      selectize = TRUE
                    ),
                    div(
                      style = "margin-top: 15px; color: #000000;",
                      actionButton(
                        inputId = "getData",
                        label = "Load Data",
                        icon = icon("download"),
                        class = "btn-primary btn-block ",
                        style = "background: linear-gradient(45deg, #007bff, #0056b3); border: none; border-radius: 6px; padding: 10px;"
                      )
                    )
                  ),
                  
                  # Column Types Section
                  div(
                    style = "background: #f8f9fa; padding: 15px; border-radius: 6px; border-left: 4px solid #ffc107;",
                    tags$h5(icon("columns"), " Column Types Configuration", style = "color: #000000; margin-bottom: 15px; border-bottom: 2px solid #ffc107; padding-bottom: 8px;"),
                    
                    # Info panel
                    div(
                      style = "background: #fff3cd; border: 1px solid #ffeaa7; border-radius: 6px; padding: 10px; margin-bottom: 15px;",
                      tags$p(
                        icon("info-circle"), 
                        " Configure the data types for each column. This helps ensure proper data analysis.",
                        style = "margin: 0; color: #856404; font-size: 12px;"
                      )
                    ),
                    
                    # Column types selector with improved styling
                    div(
                      style = "max-height: 300px; overflow-y: auto; border: 1px solid #dee2e6; border-radius: 6px; padding: 10px; background: white; margin-bottom: 15px;",
                      uiOutput("type_selector")
                    ),
                    
                    # Apply button with improved styling
                    div(
                      style = "text-align: center;",
                      shinyWidgets::actionBttn(
                        "apply_types",
                        "Apply Column Types",
                        icon = icon("check-circle"),
                        style = "gradient",
                        block = TRUE,
                        color = "success",
                        size = "md"
                      )
                    ),
                    
                    # Status indicator
                    div(
                      id = "type_status",
                      style = "margin-top: 10px; text-align: center; display: none;",
                      tags$span(
                        icon("check-circle"),
                        " Column types applied successfully!",
                        style = "color: #28a745; font-weight: bold;"
                      )
                    )
                  )
                )
              ),
              
              # Main Panel with improved styling
              column(
                width = 8,
                div(
                  style = "background: white; border-radius: 8px; padding: 20px; box-shadow: 0 2px 4px rgba(0,0,0,0.1); min-height: 400px;",
                  tags$h4(icon("table"), " Data Preview", style = "color: #000000; margin-bottom: 20px; border-bottom: 2px solid #dee2e6; padding-bottom: 10px;"),
                  div(
                    style = "background: #f8f9fa; border-radius: 6px; padding: 15px; border-left: 4px solid #007bff;",
                    tags$style(HTML("
                      #table1, #table1 * { color: #000000 !important; }
                      #table1 table, #table1 table * { color: #000000 !important; }
                      #table1 th, #table1 th * { color: #000000 !important; }
                      #table1 td, #table1 td * { color: #000000 !important; }
                    ")),
                    tableOutput("table1")
                  )
                )
              )
            )
          )
        )
      )
    )

#' Frequency table for categorical data
#' Frequency table for categorical data.
#' @param data A \code{data.frame} or a \code{tibble}.
#' @param variable Column (factor) in \code{data}.
#' @return A \code{data.frame} with frequency, cumulative frequency, frequency percent and cumulative frequency
#' percent.
#' @examples
#' ST_freq_factor(iris,Species)
#' @export

ST_freq_factor <- function(data, variable) {

  var_name <- deparse(substitute(variable))
  varyable <- rlang::enquo(variable)
  fdata <-
    data %>%
    dplyr::pull(!! varyable) %>%
    stats::na.omit()

  var_name <-
    data %>%
    dplyr::select(!! varyable) %>%
    names()

  cq <-
    fdata %>%
    sort() %>%
    unique()

  result <-
    fdata %>%
    table() %>%
    as.vector()

  percent <- function(x, y) {
    out <- round((x / y) * 100, 2)
    return(out)}

  level_names <- levels(fdata)
  data_len    <- length(fdata)
  len         <- length(result)
  cum         <- cumsum(result)
  per         <- percent(result, data_len)
  cum_per     <- percent(cum, data_len)

  ftable <- data.frame(
    Levels          = level_names,
    Frequency       = result,
    `Cum Frequency` = cum,
    Percent         = per,
    `Cum Percent`   = cum_per
  )

  na_count <-
    data %>%
    dplyr::pull(!! varyable) %>%
    is.na() %>%
    sum()

  n_obs <-
    data %>%
    dplyr::pull(!! varyable) %>%
    length()

  if (na_count > 0) {
    na_data <- dplyr::pull(data, !! varyable)

    var_count <-
      na_data %>%
      table() %>%
      as.vector() %>%
      sum()

    na_freq <- n_obs - var_count
  } else {
    na_freq <- 0
  }
  return(ftable )
}

---
title: "DISTRIBUCIONES CONINUAS"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{my-vignette}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)
```

```{r setup}
library(StatisticTeach1)
```

# Distribución normal

**1. Densidad**

La función de densidad de la distribución $t$ de Student con parámetros $\mu$ y $\sigma^2$ está dada por:

$$f(x)\;= \; \frac{1}{\sqrt{2 \pi \sigma^2}} \, e^{-\frac{(x-\mu)^2} {2 \sigma^2}}, \qquad \text{para todo $x$ real}$$

**2. Función de distribución acumulada**

Se simboliza por $F$ y se define como:

$$F(t) \; = \;  P(X \leq t) = \int\limits_{-\infty}^t f(x) dx, \qquad \text{para todo $t$ real}$$


**3. Esperanza y varianza**

Si $X$ es normal con parámetros $\mu$ y $\sigma^2$, entonces, 
$$E(X)=\mu, \qquad  V(X)=\sigma^2$$


**4. Distribución normal estándar**

Aquella distribución normal con esperanza 0 y varianza 1 se llama *normal estándar*. La variable aleatoria asociada se simbolizará con $Z$.


**5. Fórmula $Z$**

Sea $X$  una variable aleatoria que tiene distribución normal con parámetros $\mu$ y $\sigma^2$. Entonces, la siguiente variable tiene distribución normal estándar: 

$$Z=\frac{X-\mu}{\sigma}$$



**6. Estandarización a $Z$**

Sea $X$  una variable aleatoria que tiene distribución normal con parámetros $\mu$ y $\sigma^2$. Entonces, para todo número real $t$, se cumple que:


$$P(X \leq t)  \;=\;  P\Big(Z \leq \frac{t-\mu}{\sigma}\Big)$$



**7. Cuantil**

Supongamos que $X$ tiene distribución normal con media $\mu$ y desviación estándar $\sigma$. Para $0 < \alpha < 1$, el símbolo  $x_\alpha$ es un *valor cuantil* de la distribución normal si cumple con la condición:
$$P(X \geq x_\alpha) \;= \; \alpha$$

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


# Distribución $t$ de Student

**1. Densidad**

Sea $n$ un número natural. Una variable aleatoria $X$ tiene
 distribución
$t$ con $n$ grados de libertad  cuando tiene densidad de
probabilidad
$$f(x)= \mbox{$\frac{\Gamma \big(\frac{n+ 1}{2}\big)}{\sqrt{\pi n}\; \Gamma
\big({\frac{n}{2}\big)\, \big(1 + \frac{x^2}{n}\big)^{\frac{n
+1}{2}}}}$}, \quad x\in R$$


La densidad de la distribución $t$ con
$n$ grados de libertad es una función par, cuya representación
gráfica no se diferencia mucho de la densidad normal para $n$
grande. Para $n=1$ se obtiene como caso especial la densidad de
Cauchy.

**2. Función de distribución acumulada**

Se simboliza por $F$ y se define como:

$$F(t) \; = \;  P(X \leq t) = \int\limits_{-\infty}^t f(x) dx, \qquad \text{para todo $t$ real}$$


**3. Esperanza y varianza**

Si $X$ es normal con parámetros $\mu$ y $\sigma^2$, entonces, 
$$E(X)=0, \qquad  V(X)=\frac{n}{n-2}, \quad n\geq 3$$


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


# Distribución chi-cuadrada

**1. Densidad**

Sea $n$ un número natural. Una variable aleatoria $X$ tiene
 distribución
$\chi^2$ (chi-cuadrada) con $n$ grados de libertad cuando tiene
densidad de probabilidad
$$f(x)=\begin{cases}
    0 & \text{para $x\leq 0$} \\
    \mbox{$\frac{1}{2^{n/2}\Gamma\big(\frac{n}{2}\big)}$} x^{\frac{n}{2}-1}
    e^{-\frac{x}{2}}& \text{para $x>0$}
  \end{cases}$$

\noindent Para el caso $n=2$ se obtiene el caso especial que la
distribución $\chi^2$ es la distribución exponencial con
parámetro $\beta=\frac{1}{2}$. Inclusive, comparando, obtenemos
que
\begin{equation} \label{ec-Bassler-10.22c}
 \chi^2(n) = \gamma\big(\mbox{$\frac{n}{2}, \frac{1}{2}$}\big), \quad
 \forall 
\end{equation}


**2. Función de distribución acumulada**

Se simboliza por $F$ y se define como:

$$F(t) \; = \;  P(X \leq t) = \int\limits_{-\infty}^t f(x) dx, \qquad \text{para todo $t$ real}$$


**3. Esperanza y varianza**

Si $X$ es normal con parámetros $\mu$ y $\sigma^2$, entonces, 
$$E(X)=n, \qquad  V(X)=2n$$


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


# Distribución $F$ de Fisher

**1. Densidad**

Sean $n$ y $m$ números naturales. Una variable aleatoria $X$
 distribución $F$ de Fisher
con $n$ $m$ grados de libertad}  cuando tiene densidad de
probabilidad
$$f(x)= \begin{cases}
    0 & \text{para $x\leq 0$} \\
    \mbox{$\frac{\Gamma \big(\frac{n+ m}{2}\big)\,n^{n/2}\,
    m^{m/2}}{\Gamma\big(\frac{n}{2}\big)\,
    \Gamma\big(\frac{m}{2}\big)}\, \frac{x^{\frac{m}{2}-1}}{(n+mx)^{(n+m)/2}}$}
    & \text{para $x>0$}
  \end{cases}$$
  
  
La distribución $F$ de Fisher, al igual que la
chi-cuadrada, tiene una función de densidad asimétrica,
definida solo para valores no negativos.

**2. Función de distribución acumulada**

Se simboliza por $F$ y se define como:

$$F(t) \; = \;  P(X \leq t) = \int\limits_{-\infty}^t f(x) dx, \qquad \text{para todo $t$ real}$$


**3. Esperanza y varianza**

Si $X$ es normal con parámetros $\mu$ y $\sigma^2$, entonces, 
$$E(X)=\frac{n}{n-2}, \quad n\geq 3$$
$$V(X)=\frac{2n^2(m+n-2)}{m(n-2)^2(n-4)}, \quad n\geq 5$$



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


# Distribución exponencial


**1. Densidad**

Una variable aleatoria $X$ tiene
distribución
exponencial si para todo $\beta>0$ su densidad es
$$ f(x):=f(x; \beta)=  \begin{cases}
    0 & \text{para $x\leq 0$} \\
    \beta e^{-\beta x} & \text{para $x>0$}
  \end{cases}$$

**2. Función de distribución acumulada**

Se simboliza por $F$ y se define como:

$$F(t) \; = \;  P(X \leq t) = \int\limits_{-\infty}^t f(x) dx, \qquad \text{para todo $t$ real}$$

En este caso, tiene la forma: 
$$ F(t):=\begin{cases}
    0 & \text{para $t\leq 0$} \\
    1- e^{-\beta t} & \text{para $t>0$}
  \end{cases}$$

**3. Esperanza y varianza**

$$E(X)=\frac{1}{\beta}, \qquad  V(X)=\frac{1}{\beta^2}$$



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


# Distribución logística

**1. Densidad**

La función de densidad de la distribución logística con parámetros $\mu$ y $\sigma^2$ está dada por:

 

$$f(x)\;= \; \frac{e^{-(x-\mu)^2/\sigma^2}}{\sigma^2 (1 + e^{-(x-\mu)^2/\sigma^2})^2}$$

**2. Función de distribución acumulada**

Se simboliza por $F$ y se define como:

$$F(t) \; = \;  P(X \leq t) = \int\limits_{-\infty}^t f(x) dx, \qquad \text{para todo $t$ real}$$

En este caso, tiene la forma
$$F(t) \; = \; \frac{1}{1 + e^{-(x-\mu)^2/\sigma^2}}$$


**3. Esperanza y varianza**

Si $X$ es normal con parámetros $\mu$ y $\sigma^2$, entonces, 
$$E(X)=\mu, \qquad  V(X)=\frac{\pi^2\,\sigma^2}{3}$$


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


# Distribución log-normal

La distribución log-normal en su forma más simple puede
ser definida como la distribución  de una variable aleatoria
cuyo logaritmo obedece a  la densidad de probabilidad normal. Sea
$Y$ una variable aleatoria que está normalmente distribuida con
parámetros $\mu$ y $\sigma^2$. Si $Y=\ln X$ o $X=e^Y$, entonces
se dice que $X$  tiene distribución log-normal.


**1. Densidad**

Una variable aleatoria $X$ tiene
 distribución
log-normal con parámetros $\mu$ y $\sigma^2>0$  si su
densidad de probabilidad está dada por
$$f(x)= \begin{cases}
    \frac{1}{x\sqrt{\sigma^2\,\pi}}\exp\big\{-\frac{1}{2\sigma^2}(\ln x - \mu)^2
    \big\} & \text{si $x>0$} \\
    0 & \text{de otro modo}
  \end{cases}$$

**2. Función de distribución acumulada**

Se simboliza por $F$ y se define como:

$$F(t) \; = \;  P(X \leq t) = \int\limits_{-\infty}^t f(x) dx, \qquad \text{para todo $t$ real}$$


**3. Esperanza y varianza**

Si $X$ es normal con parámetros $\mu$ y $\sigma^2$, entonces, 
$$E(X)=\exp\left\{\mu + \frac{\sigma^2}{2}\right\}, \qquad  V(X)=[\exp\left\{\sigma^2\right\}-1]\; \exp\left\{2\mu +\sigma^2\right\}$$


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


# Distribución gamma


**1. Densidad**

Una variable aleatoria $X$ tiene 
distribución gamma con parámetros $\alpha, \beta$ si su densidad es

$$f(x):=f(x;\alpha,\beta) = \begin{cases}
    0 & \text{para $x\leq 0$}, \\
    \frac{\beta^\alpha}{\Gamma(\alpha)}\, x^{\alpha-1}\, e^{-\beta x}& \text{para $x>0$},
  \end{cases}$$

**2. Función de distribución acumulada**

Se simboliza por $F$ y se define como:

$$F(t) \; = \;  P(X \leq t) = \int\limits_{-\infty}^t f(x) dx, \qquad \text{para todo $t$ real}$$


**3. Esperanza y varianza**

 
$$E(X)=\frac{\alpha}{\beta}, \qquad  V(X)=\frac{\alpha}{\beta^2}$$


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


# Distribución weibull

**1. Densidad**

Una variable aleatoria $X$ tiene  con parámetros
$\alpha, \beta>0$  si su densidad de probabilidad está
dada por
$$f(x)= \begin{cases}
    \beta\alpha \left(x \beta\right)^{\alpha-1} \exp\big\{-
    [x\beta]^{\alpha}\big\} & \text{si $x>0$} \\
    0 & \text{de otro modo}
  \end{cases}$$
  
  Los tres parámetros, $\alpha$ y $\beta$, que
describen completamente a la densidad de Weibull son de mucha
importancia. Aquí $\alpha$ es un parámetro de forma y
$\beta$ es un parámetro de escala. 

**2. Función de distribución acumulada**

Se simboliza por $F$ y se define como:

$$F(t) \; = \;  P(X \leq t) = \int\limits_{-\infty}^t f(x) dx, \qquad \text{para todo $t$ real}$$

La función de distribución correspondiente está dada por
$$F(t)=\begin{cases}
    0  & \text{si $t\leq 0$} \\
    1- \exp\big\{- (\beta t)^{\alpha}\big\} & \text{si $t>0$}
  \end{cases}$$


**3. Esperanza y varianza**

$$E(X)=\frac{1}{\beta}\, \Gamma\left(1+\frac{1}{\alpha}\right)$$
$$  V(X)=\frac{1}{\beta^2}\, \left[\Gamma\left(1+\frac{2}{\alpha}\right) - \Gamma^2\left(1+\frac{1}{\alpha}\right)\right]$$


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


# Distribución beta

Para $x, y >0$, la integral
\begin{equation} 
B(x,y):=\int_0^1 t^{x-1} (1-t)^{y-1} dt
\end{equation}

\noindent existe como integral de Riemann indeterminada
absolutamente convergente, por tanto, también como integral de
Lebesgue. La función $B: (0,\infty)^2\to R$ se llama
función beta de Euler.


**1. Densidad**

Una variable aleatoria $X$ tiene  distribución beta  si
$$f(x)=\begin{cases}
    \frac{1}{B(\alpha, \beta)}\, x^{\alpha-1}\,(1-x)^{\beta-1} &
    \text{para $0<x<1$ y $\alpha,\beta>0$} \\
    0 & \text{para $x\leq 0$ y $x\geq 1$}
  \end{cases}$$

**2. Función de distribución acumulada**

Se simboliza por $F$ y se define como:

$$F(t) \; = \;  P(X \leq t) = \int\limits_{-\infty}^t f(x) dx, \qquad \text{para todo $t$ real}$$


**3. Esperanza y varianza**

Si $X$ es normal con parámetros $\mu$ y $\sigma^2$, entonces, 
$$E(X)=\frac{\alpha}{\alpha + \beta}$$
$$  V(X)=\frac{\alpha \beta}{(\alpha +\beta)^2 \,(\alpha +\beta +1)}$$


**4. Propiedades**

Algunos
caso especiales de la distribución beta  son:

*Propiedad 1. *

Cuando
$\alpha=\beta=1$ tenemos la distribución rectangular $f(x)=1$ si
$x\in[0,1]$ y $f(x)=0$ de otro modo.

*Propiedad 2. *

Cuando $\alpha=1$,
$\beta=2$ y $\alpha=2$, $\beta=1$ tenemos las distribuciones
rectangulares
$$f(x)=\begin{cases}
    2(1-x) & \text{si $0\leq x\leq 1$} \\
    0 & \text{de otro modo}
  \end{cases} \qquad  f(x)=\begin{cases}
    2x & \text{si $0\leq x\leq 1$} \\
    0 & \text{de otro modo}
  \end{cases}$$

 respectivamente.

---
title: "Getting Started with StatisticTeach1"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Getting Started with StatisticTeach1}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)
```

## Introduction

**StatisticTeach1** is an interactive Shiny application for teaching and
learning basic concepts in statistics and probability. It provides visual,
hands-on exploration of:

- Descriptive statistics for continuous and categorical variables
- Frequency tables
- Probability distributions (discrete and continuous)

## Installation

```{r eval=FALSE}
install.packages("StatisticTeach1")
```

## Launching the App

```{r eval=FALSE}
library(StatisticTeach1)
runStatisticTeach1()
```

This opens the Shiny interface in your default web browser.

## Standalone Functions

Two utility functions are also available outside the app:

### Frequency table for categorical variables

```{r}
library(StatisticTeach1)
ST_freq_factor(iris, Species)
```

### Frequency table for continuous variables

```{r}
ST_freq_numeric(mtcars, mpg, bins = 5)
```

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ST_freq_factor.R
\name{ST_freq_factor}
\alias{ST_freq_factor}
\title{Frequency table for categorical data
Frequency table for categorical data.}
\usage{
ST_freq_factor(data, variable)
}
\arguments{
\item{data}{A \code{data.frame} or a \code{tibble}.}

\item{variable}{Column (factor) in \code{data}.}
}
\value{
A \code{data.frame} with frequency, cumulative frequency, frequency percent and cumulative frequency
percent.
}
\description{
Frequency table for categorical data
Frequency table for categorical data.
}
\examples{
ST_freq_factor(iris,Species)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/runStatisticTeach1.R
\name{runStatisticTeach1}
\alias{runStatisticTeach1}
\title{Shiny GUI for StatisticTeach1 package}
\usage{
runStatisticTeach1(host = "127.0.0.1", port = NULL, launch.browser = TRUE)
}
\arguments{
\item{host}{The IPv4 address that the application should listen on.
Defaults to the shiny.host option, if set, or "127.0.0.1" if not.}

\item{port}{is the TCP port that the application should listen on.
If the port is not specified,
and the shiny.port option is set (with options(shiny.port = XX)),
then that port will be used.
Otherwise, use a random port.}

\item{launch.browser}{If true,
the system's default web browser will be launched automatically
after the app is started. Defaults to true in interactive sessions
only. This value of this parameter can also be a function to call with
the application's URL.}
}
\value{
No return value
}
\description{
runStatisticTeach1() loads interactive user interface built using R 'shiny'.
}
\details{
The interactive user interface to provide an easy way for to perform descriptive statistical analysis
}
\examples{
if(interactive()){
runStatisticTeach1()
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ST_freq_numeric.R
\name{ST_freq_numeric}
\alias{ST_freq_numeric}
\title{Frequency table for continuous data
Frequency table for continuous data.}
\usage{
ST_freq_numeric(data, variable, bins = 5)
}
\arguments{
\item{data}{A \code{data.frame} or a \code{tibble}.}

\item{variable}{Column in \code{data}.}

\item{bins}{Number of intervals into which the data must be split.}
}
\value{
A \code{data.frame} with frequency, cumulative frequency, frequency percent and cumulative frequency
percent.
}
\description{
Frequency table for continuous data
Frequency table for continuous data.
}
\examples{
ST_freq_numeric(mtcars, mpg,bins = 5)
}
